%bcond_with systemd
%bcond_without python3

# TODO: uses private copy of libedit, should be modified to use system one

Summary: IPMI (Intelligent Platform Management Interface) library and tools
Summary(ja): IPMI (Intelligent Platform Management Interface) ライブラリおよびツール
Name: OpenIPMI
Version: 2.0.31
Release: 1%{?_dist_release}%{?with_systemd:.systemd}
Group: admin-tools
Vendor: Project Vine
Distribution: Vine Linux

License: LGPLv2+ and GPLv2+ or BSD
URL: https://sourceforge.net/projects/openipmi/
Source: https://downloads.sourceforge.net/openipmi/%{name}-%{version}.tar.gz
Source1: openipmi.sysconf
Source2: openipmi.initscript
Source3: openipmigui.desktop
Source4: README.initscript
Source5: openipmi-helper
Source6: ipmi.service
Patch1: 0001-man.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: desktop-file-utils
BuildRequires: gdbm-devel
BuildRequires: glib2-devel
BuildRequires: readline-devel
BuildRequires: libxcrypt-devel
BuildRequires: ncurses-devel
BuildRequires: net-snmp-devel
BuildRequires: openssl-devel
BuildRequires: perl
BuildRequires: popt-devel
BuildRequires: swig
BuildRequires: tcl

BuildRequires: python-rpm-macros
%if %{with python3}
BuildRequires: python3-devel
BuildRequires: python3-rpm-macros
BuildRequires: python3-tkinter
%else
BuildRequires: python-devel
BuildRequires: python2-rpm-macros
BuildRequires: tkinter
%endif
%if %{with systemd}
BuildRequires:   systemd
%{?systemd_requires}
%else
Requires(post): chkconfig
Requires(preun): chkconfig
%endif

# Prevent bogus provides of private libs from perl
%global __provides_exclude_from %{?__provides_exclude_from:%{__provides_exclude_
from}|}^%{perl_vendorarch}/auto/.*\\.so$

%description
The Open IPMI project aims to develop an open code base to allow access to
platform information using Intelligent Platform Management Interface (IPMI).
This package contains the tools of the OpenIPMI project.


%package libs
Summary: The OpenIPMI runtime libraries
Summary(ja): OpenIPMI ランタイムライブラリ
Group: system

%description libs
The OpenIPMI-libs package contains the runtime libraries for shared binaries
and applications.


%package perl
Summary: IPMI Perl language bindings
Summary(ja): IPMI Perl 言語バインディング
Group: programming
Requires: perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description perl
The OpenIPMI-perl package contains the Perl language bindings for OpenIPMI.


%if %{with python3}
%package -n python3-openipmi
Summary: IPMI Python3 language bindings
Summary(ja): IPMI Python3 言語バインディング
Group: programming
Requires: python3
Obsoletes: %{name}-python < %{version}-%{release}
Provides: %{name}-python = %{version}-%{release}

%description -n python3-openipmi
The OpenIPMI-python3 package contains the Python3 language bindings for OpenIPMI.


%else
%package python
Summary: IPMI Python language bindings
Summary(ja): IPMI Python 言語バインディング
Group: programming
Requires: python

%description python
The OpenIPMI-python package contains the Python language bindings for OpenIPMI.
%endif


%package devel
Summary: The development environment for the OpenIPMI project
Summary(ja): OpenIPMI の開発キット
Group: programming
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
The OpenIPMI-devel package contains the development libraries and header files
of the OpenIPMI project.


%package gui
Summary: IPMI graphical user interface tool
Summary(ja): IPMI GUI ツール
Group: admin-tools
Requires: tix
Requires: tkinter
%if %{with python3}
Requires: python3-openipmi = %{version}-%{release}
%else
Requires: %{name}-python = %{version}-%{release}
%endif

%description gui
The OpenIPMI-gui package contains the graphical user interface to monitor
and control IPMI-enabled devices.


%debug_package


%prep
%autosetup -p1


%build
%configure \
  CFLAGS="-fPIC %{optflags} -z now -fno-strict-aliasing" \
  LDFLAGS="%{?__global_ldflags} -Wl,--as-needed" \
  --disable-dependency-tracking \
  --disable-static \
%if %{with python3}
  --with-python=%{__python3} \
  --with-pythoninstall=%{python3_sitearch} \
%else
  --with-pythoninstall=%{python_sitearch} \
%endif
  --with-tcl=no \
  --with-tkinter=yes
# get rid of rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make   # not %{?_smp_mflags} safe


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} \;

%if %{with systemd}
install -d %{buildroot}{%{_unitdir},%{_libexecdir}}
install -m 755 %{SOURCE5} %{buildroot}%{_libexecdir}/openipmi-helper
install -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/ipmi.service
%else
install -d ${RPM_BUILD_ROOT}%{_initrddir}
install -m 755 %SOURCE2 ${RPM_BUILD_ROOT}%{_initrddir}/ipmi
%endif
install -d ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig
install -m 644 %SOURCE1 ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/ipmi
install -d %{buildroot}%{_sysconfdir}/modprobe.d

# add missing documentation
echo ".so man1/openipmicmd.1" > %{buildroot}%{_mandir}/man1/ipmicmd.1
echo ".so man1/openipmish.1" > %{buildroot}%{_mandir}/man1/ipmish.1

desktop-file-install --vendor="fedora" --dir=${RPM_BUILD_ROOT}%{_datadir}/applications %{SOURCE3}

install -m 644 %SOURCE4 .


%post
%if %{with systemd}
%systemd_post ipmi.service
%else
/sbin/chkconfig --add ipmi
%endif

%preun
%if %{with systemd}
%systemd_preun ipmi.service
%else
if [ $1 = 0 -o -x /bin/systemctl ]; then
   service ipmi stop >/dev/null 2>&1
   /sbin/chkconfig --del ipmi
fi
%endif

%postun
%if %{with systemd}
%systemd_postun_with_restart ipmi.service
%else
if [ "$1" -ge "1" ]; then
    service ipmi condrestart >/dev/null 2>&1 || :
fi
%endif

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root)
%license COPYING COPYING.BSD COPYING.LIB
%doc CONFIGURING_FOR_LAN FAQ README README.Force README.MotorolaMXP README.initscript
%config(noreplace) %{_sysconfdir}/ipmi/ipmisim1.emu
%config(noreplace) %{_sysconfdir}/ipmi/lan.conf
%config(noreplace) %{_sysconfdir}/sysconfig/ipmi
%if %{with systemd}
%{_unitdir}/ipmi.service
%{_libexecdir}/openipmi-helper
%else
%{_initrddir}/ipmi
%endif
%{_bindir}/ipmicmd
%{_bindir}/ipmilan
%{_bindir}/ipmish
%{_bindir}/ipmi_sim
%{_bindir}/ipmi_ui
%{_bindir}/openipmicmd
%{_bindir}/openipmish
%{_bindir}/rmcp_ping
%{_bindir}/sdrcomp
%{_bindir}/solterm
%{_bindir}/openipmi_eventd
%{_mandir}/man1/ipmi_*
%{_mandir}/man1/ipmicmd.*
%{_mandir}/man1/ipmish.*
%{_mandir}/man1/openipmicmd*
%{_mandir}/man1/openipmish*
%{_mandir}/man1/rmcp_ping*
%{_mandir}/man1/solterm*
%{_mandir}/man5/ipmi_*
%{_mandir}/man1/openipmi_eventd*
%{_mandir}/man7/ipmi_cmdlang*
%{_mandir}/man7/openipmi_conparms*
%{_mandir}/man8/ipmilan*

%files perl
%defattr(-,root,root)
%attr(644,root,root) %{perl_vendorarch}/OpenIPMI.pm
%{perl_vendorarch}/auto/OpenIPMI/

%if %{with python3}
%files -n python3-openipmi
%defattr(-,root,root)
%{python3_sitearch}/*OpenIPMI*
%else
%files python
%defattr(-,root,root)
%{python_sitearch}/*OpenIPMI*
%endif

%files libs
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/OpenIPMI
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files gui
%defattr(-,root,root)
%{_bindir}/openipmigui
%{_mandir}/man1/openipmigui*
%if %{with python3}
%{python3_sitearch}/openipmigui
%else
%{python_sitearch}/openipmigui
%endif
%{_datadir}/applications/fedora-openipmigui.desktop


%changelog
* Tue Oct 05 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.31-1
- updated to 2.0.31.

* Tue Sep 08 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.29-1
- updated to 2.0.29.
- imported Source5-6 and Patch1 from rawhide.
- added systemd support (disabled as default).

* Mon May 13 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.27-1
- updated to 2.0.27.
- dropped Patch2 (fixed in upstream).
- added BR:libxcrypt-devel.
- switched to python3.

* Wed Nov 07 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.25-1
- updated to 2.0.25.
- dropped Patch1 (fixed in upstream).
- imported Patch2 from rawhide.
- added BR:libedit-devel.

* Fri May 06 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.0.21-3
- rebuild with openssl-1.0.2

* Sun May 10 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.0.21-2
- remove *.la files

* Sat Oct 11 2014 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 2.0.21-1
- updated to 2.0.21
- rebuilt with perl-5.16.3

* Wed Mar 07 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.0.18-5
- rebuild with net-snmp-5.7.1

* Sun Feb 19 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.0.18-4
- rebuild with python-2.7.2

* Sat May 21 2011 IWAI, Masaharu <iwai@alib.jp> 2.0.18-3
- build with perl 5.12.3
- add Vendor and Distribution tags

* Sun Mar 20 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.0.18-2
- rebuild with openssl-1.0.0d

* Sat Jul 10 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.0.18-1
- initial build for Vine Linux

* Tue Jun 01 2010 Marcela Maslanova <mmaslano@redhat.com> - 2.0.18-2
- Mass rebuild with perl-5.12.0

* Wed May  5 2010 Jan Safranek <jsafrane@redhat.com> - 2.0.18-1
- updated to OpenIPMI-2.0.18
- fixed OpenIPMIpthread pkgconfig file (#468067)

* Mon May  3 2010 Jan Safranek <jsafrane@redhat.com> - 2.0.17-1
- updated to OpenIPMI-2.0.17

* Thu Mar 18 2010 Jan Safranek <jsafrane@redhat.com> - 2.0.16-12
- implemented mandatory 'force-reload' command in ipmi service

* Thu Mar 11 2010 Jan Safranek <jsafrane@redhat.com> - 2.0.16-11
- rebuild against new gdbm

* Wed Mar  3 2010 Jan Safranek <jsafrane@redhat.com> - 2.0.16-10
- add README.initscript describing /etc/init.d/ipmi initscript exit codes
  (#562151)

* Mon Feb 22 2010 Jan Safranek <jsafrane@redhat.com> - 2.0.16-9
- fix package License: field, there *are* sources with BSD header
- distribute README files and COPYING in package

* Tue Jan  5 2010 Jan Safranek <jsafrane@redhat.com> - 2.0.16-8
- fix package License: field, there is no source with BSD header

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 2.0.16-7
- rebuild against perl 5.10.1

* Tue Dec  1 2009 Jan Safranek <jsafrane@redhat.com> - 2.0.16-6
- fix package compilation to remove rpmlint errors

* Wed Sep 30 2009 Jan Safranek <jsafrane@redhat.com> - 2.0.16-5
- rebuilt with new net-snmp

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 2.0.16-4
- rebuilt with new openssl

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.16-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Apr 15 2009 Jan Safranek <jsafrane@redhat.com> - 2.0.16-2
- fix compilation flags, debuginfo package is correctly generated now

* Thu Mar 19 2009 Jan Safranek <jsafrane@redhat.com> - 2.0.16-1
- new upstream release

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.14-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> - 2.0.14-10
- rebuild with new openssl

* Thu Dec 11 2008 Jan Safranek <jsafrane@redhat.com> - 2.0.14-9
- fix linking without rpath, prelink won't screw up the libraries
  anymore (#475265)

* Wed Dec 10 2008 Jan Safranek <jsafrane@redhat.com> - 2.0.14-8
- shorter probe interval is used in init script, making the service startup
  quicker in most situations (#475101)

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 2.0.14-7
- Rebuild for Python 2.6

* Thu Oct 30 2008 Jan Safranek <jsafrane@redhat.com> - 2.0.14-6
- removed static libraries from the -devel subpackage
- fixed openipmigui.desktop file

* Thu Oct 23 2008 Jan Safranek <jsafrane@redhat.com> - 2.0.14-5
- fixed typos in the descriptions
- added .desktop file for openipmigui tool

* Mon Oct 20 2008 Jan Safranek <jsafrane@redhat.com> - 2.0.14-4
- fixed description of the package

* Thu Oct 16 2008 Jan Safranek <jsafrane@redhat.com> - 2.0.14-3
- split ipmitool to separate package
- added 'reload' functionality to init script
- added seraparate -gui subpackage

* Wed Jul 30 2008 Phil Knirsch <pknirsch@redhat.com> - 2.0.14-2
- Fixed rpath problem in libOpenIPMIposix.so.0.0.1

* Tue Jul 29 2008 Phil Knirsch <pknirsch@redhat.com> - 2.0.14-1
- Fixed several specfile problems (#453751)
- Update to OpenIPMI-2.0.14

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 2.0.13-2
- Autorebuild for GCC 4.3

* Wed Dec 05 2007 Phil Knirsch <pknirsch@redhat.com> - 2.0.13-1
- Updated to OpenIPMI-2.0.13
- Rebuild due to new openssl

* Wed Oct 10 2007 Phil Knirsch <pknirsch@redhat.com> - 2.0.11-3
- Added missing perl-devel buildrequires

* Mon Sep 24 2007 Phil Knirsch <pknirsch@redhat.com> - 2.0.11-2
- Added missing popt-devel buildrequires

* Fri Aug 17 2007 Phil Knirsch <pknirsch@redhat.com> - 2.0.11-2
- Fix rebuild problems due to glibc change
- License review and fixes

* Tue Apr 24 2007 Phil Knirsch <pknirsch@redhat.com> - 2.0.11-1
- Update to OpenIPMI-2.0.11

* Tue Feb 27 2007 Phil Knirsch <pknirsch@redhat.com> - 2.0.6-8
- Update for ipmitool-1.8.9

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 2.0.6-7
- rebuild for python 2.5

* Tue Nov 28 2006 Phil Knirsch <pknirsch@redhat.com> - 2.0.6-6.fc7
- Update due to new net-snmp-5.4
- Some specfile updates

* Tue Jul 18 2006 Phil Knirsch <pknirsch@redhat.com> - 2.0.6-5
- Fixed check for udev in initscript (#197956)

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.0.6-4.1
- rebuild

* Fri Jun 16 2006 Bill Nottingham <notting@redhat.com> 2.0.6-4
- don't include <linux/compiler.h>

* Fri Jun 16 2006 Jon Masters <jcm@redhat.com> 2.0.6-3
- Fix a build requires (needs glibc-kernheaders)

* Thu Jun 15 2006 Jesse Keating <jkeating@redhat.com> 2.0.6-2
- Bump for new glib2

* Tue May 16 2006 Phil Knirsch <pknirsch@redhat.com> 2.0.6-1
- Fixed bug with type conversion in ipmitool (#191091)
- Added python bindings 
- Split off perl and python bindings in separate subpackages
- Dropped obsolete patches
- Added missing buildprereq on readline-devel
- Made it install the python bindings properly on 64bit archs

* Mon May 15 2006 Phil Knirsch <pknirsch@redhat.com>
- Updated ipmitool to 1.8.8
- Updated OpenIPMI to 2.0.6

* Fri Feb 17 2006 Phil Knirsch <pknirsch@redhat.com> 1.4.14-19
- Added missing PreReq for chkconfig

* Mon Feb 13 2006 Jesse Keating <jkeating@redhat.com> - 1.4.14-18.2.1
- rebump for build order issues during double-long bump

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.4.14-18.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.4.14-18.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Mon Feb 06 2006 Phil Knirsch <pknirsch@redhat.com> 1.4.14-18
- Updated ipmitool to latest upstream version.
- Removed 3 patches for already fixed bugs in latest ipmitool.
- Adapted warning message fix for ipmitool for latest version.

* Tue Jan 24 2006 Phil Knirsch <pknirsch@redhat.com> 1.4.14-17
- Fixed some minor things in initscripts.

* Mon Jan 09 2006 Phil Knirsch <pknirsch@redhat.com> 1.4.14-16
- Included FRU fix for displaying FRUs with ipmitool
- Included patch for new option to specify a BMC password for IPMI 2.0 sessions

* Tue Jan 03 2006 Radek Vokal <rvokal@redhat.com> 1.4.14-15
- Rebuilt against new libnetsnmp

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Nov 23 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-14
- Some more initscript and sysconfig updates from Dell.

* Wed Nov 09 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-13
- Rebuilt to link against latest openssl libs.
- Fixed ipmitool not setting session privilege level (#172312)

* Wed Nov 02 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-11
- Rebuild to link against new net-snmp libs.

* Tue Oct 11 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-10
- Updated initscript to fix missing redhat-lsb bug (#169901)

* Thu Sep 08 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-9
- Another update to latest initscripts from Dell
- Fixed some missing return statements for non-void functions (#164138)

* Thu Sep 01 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-8
- Updated initscript to latest version from Dell

* Fri Aug 12 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-7
- Fixed the unwanted output of failed module loading of the initscript. Behaves
  now like all our other initscripts (#165476)

* Fri Aug 05 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-6
- Fixed build problem on 64bit machines

* Fri Jul 15 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-5
- Fixed missing change to not autostart in the initscript

* Wed Jul 06 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-4
- Made the initscript a replacing configfile

* Mon Jul 04 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-3
- Updated versions of the initscripts and sysconf files
- Fixed typo in preun script and changelog

* Mon Jun 27 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.14-2
- Updated to OpenIPMI-1.4.14
- Split the main package into normal and libs package for multilib support
- Added ipmitool-1.8.2 to OpenIPMI and put it in tools package
- Added sysconf and initscript (#158270)
- Fixed oob subscripts (#149142)

* Wed Mar 30 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.11-5
- Correctly put libs in the proper packages

* Thu Mar 17 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.11-4
- gcc4 rebuild fixes
- Added missing gdbm-devel buildprereq

* Wed Mar 02 2005 Phil Knirsch <pknirsch@redhat.com> 1.4.11-3
- bump release and rebuild with gcc 4

* Tue Feb 08 2005 Karsten Hopp <karsten@redhat.de> 1.4.11-2 
- update

* Tue Oct 26 2004 Phil Knirsch <pknirsch@redhat.com>
- Initial version
