%define build_compat32 %{?_with_compat32:1}%{!?_with_compat32:0}

Summary: Utilities for managing filesystem extended attributes
Name: attr
Version: 2.4.48
Release: 2%{?_dist_release}
Group: system
Vendor: Project Vine
Distribution: Vine Linux

License: GPLv2+
URL: http://oss.sgi.com/projects/xfs/
Source: http://download.savannah.nongnu.org/releases/attr/attr-%{version}.tar.gz

# fix test-suite failure with perl-5.26.0 (#1473853)
Patch1:  0001-attr-2.4.48-test-suite-perl.patch

# fix conflict with fakechroot (https://github.com/dex4er/fakechroot/issues/57)
Patch2:  0002-attr-2.4.48-switch-back-to-syscall.patch

# xattr.conf: remove entries for NFSv4 ACLs namespaces (#1031423)
# https://lists.nongnu.org/archive/html/acl-devel/2019-03/msg00000.html
# https://lists.nongnu.org/archive/html/acl-devel/2019-03/msg00001.html
# https://lists.nongnu.org/archive/html/acl-devel/2019-05/msg00000.html
Patch3:  0003-attr-2.4.48-xattr-conf-nfs4-acls.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: gettext
BuildRequires: libtool
Requires: libattr = %{version}-%{release}

Conflicts: xfsdump < 2.0.0

%description
A set of tools for manipulating extended attributes on filesystem
objects, in particular getfattr(1) and setfattr(1).
An attr(1) command is also provided which is largely compatible
with the SGI IRIX tool of the same name.


%package -n libattr
Summary: Dynamic library for extended attribute support
Group: system
License: LGPLv2+

%description -n libattr
This package contains the libattr.so dynamic library which contains
the extended attribute system calls and library functions.


%package -n libattr-devel
Summary: Extended attribute static libraries and headers
Group: programming
License: LGPLv2+
Requires: libattr = %{version}-%{release}

%description -n libattr-devel
This package contains the libraries and header files needed to
develop programs which make use of extended attributes.
For Linux programs, the documented system call API is the
recommended interface, but an SGI IRIX compatibility interface
is also provided.

Currently only ext2, ext3 and XFS support extended attributes.
The SGI IRIX compatibility API built above the Linux system calls is
used by programs such as xfsdump(8), xfsrestore(8) and xfs_fsr(8).

You should install libattr-devel if you want to develop programs
which make use of extended attributes.  If you install libattr-devel,
you'll also want to install attr.


# compat32
%package -n compat32-libattr
Summary: Dynamic library for extended attribute support
Group: system,legacy
License: LGPLv2+

%description -n compat32-libattr
This package contains the libattr.so dynamic library which contains
the extended attribute system calls and library functions.

%package -n compat32-libattr-devel
Summary: Extended attribute static libraries and headers
Group: programming,legacy
License: LGPLv2+
Requires: libattr-devel = %{version}-%{release}
Requires: compat32-libattr = %{version}-%{release}

%description -n compat32-libattr-devel
This package contains the libraries and header files needed to
develop programs which make use of extended attributes.
For Linux programs, the documented system call API is the
recommended interface, but an SGI IRIX compatibility interface
is also provided.

Currently only ext2, ext3 and XFS support extended attributes.
The SGI IRIX compatibility API built above the Linux system calls is
used by programs such as xfsdump(8), xfsrestore(8) and xfs_fsr(8).

You should install libattr-devel if you want to develop programs
which make use of extended attributes.  If you install libattr-devel,
you'll also want to install attr.


%debug_package


%prep
%setup -q
%autopatch -p1


%build
# attr abuses libexecdir
%configure --libdir=/%{_lib} --libexecdir=%{_libdir}
%make_build


%install
rm -rf %{buildroot}
%make_install

# get rid of libattr.a and libattr.la
rm -f $RPM_BUILD_ROOT/%{_lib}/libattr.{l,}a
rm -f $RPM_BUILD_ROOT%{_libdir}/libattr.{l,}a

# fix links to shared libs and permissions
rm -f %{buildroot}%{_libdir}/libattr.so
mkdir -p %{buildroot}%{_libdir}
ln -sf ../../%{_lib}/libattr.so %{buildroot}%{_libdir}/libattr.so
chmod 0755 %{buildroot}/%{_lib}/libattr.so.*.*.*

# remove documents without version
rm -rf %{buildroot}%{_datadir}/doc/attr

mv -f %{buildroot}/%{_lib}/pkgconfig %{buildroot}%{_libdir}/

%find_lang %{name}


%check
if ./setfattr -n user.name -v value .; then
    make tests || exit $?
else
    echo '*** xattrs are probably not supported by the file system,' \
         'the test-suite will NOT run ***'
fi

%clean
rm -rf %{buildroot}


%files -f %{name}.lang
%defattr(-,root,root)
%doc doc/CHANGES
%license doc/COPYING*
%{_bindir}/attr
%{_bindir}/getfattr
%{_bindir}/setfattr
%{_mandir}/man1/attr.1*
%{_mandir}/man1/getfattr.1*
%{_mandir}/man1/setfattr.1*


%files -n libattr-devel
%defattr(-,root,root)
/%{_lib}/libattr.so
%{_includedir}/attr
%{_libdir}/libattr.*
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/attr_*.3.*

%files -n libattr
/%{_lib}/libattr.so.*
%config(noreplace) %{_sysconfdir}/xattr.conf

# compat32
%if %{build_compat32}
%files -n compat32-libattr-devel
%defattr(-,root,root)
/%{_lib}/libattr.so
%{_libdir}/libattr.*
%{_libdir}/pkgconfig/*.pc

%files -n compat32-libattr
/%{_lib}/libattr.so.*
%config(noreplace) %{_sysconfdir}/xattr.conf
%endif


%changelog
* Wed Mar 10 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.4.48-2
- dropped scriptlets.
- imported Patch1-3 from rawhide.

* Sun May 19 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.4.48-1
- new upstream release.
- dropped Patch1, 2.

* Fri Sep 11 2015 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.4.47-2
- removed a manpage (attr.5).

* Fri Jul  4 2014 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.4.47-1
- new upstream release.
- replaced patches to the newest rawhide's.

* Sat Apr  9 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.4.44-1
- new upstream release
- remove static library from devel package
- added Patch2-9
  * Tue Mar 29 2011 Kamil Dudka <kdudka@redhat.com> 2.2.44-8
  - fix typos in attr(1) man page (#669095)
  * Wed Dec 22 2010 Kamil Dudka <kdudka@redhat.com> 2.2.44-6
  - setfattr.1: document supported encodings of values (#587516)
  - getfattr: encode NULs properly with --encoding=text (#650539)
  - getfattr: return non-zero exit code on failure (#660619)
  - walk_tree: do not follow symlink to directory with -h (#660613)
  * Tue May 25 2010 Kamil Dudka <kdudka@redhat.com> 2.2.44-5
  - let attr depend on the same version of libattr (#595689)
  - silence compile-time warnings
  * Wed Feb 18 2009 Zdenek Prikryl <zprikryl@redhat.com> 2.4.43-2
  - Fixed memory leaks (#485473)

* Wed Jul 15 2009 NAKAMURA Kenta <kenta@vinelinux.org> 2.4.43-2
- added compat32 package for x86_64 arch support

* Wed Jul 15 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.4.43-1
- new upstream release

* Mon Jun 30 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.4.41-2
- initial build for Vine Linux

* Wed Feb 13 2008 Zdenek Prikryl <zprikryl@redhat.com> 2.4.41-1
- New version 2.4.41
- Removed useless attr-2.0.8-docperms.patch

* Wed Oct 31 2007 Zdenek Prikryl <zprikryl@redhat.com> 2.4.39-1
- New version 2.4.39
- Resolves #284121

* Tue Oct 30 2007 Zdenek Prikryl <zprikryl@redhat.com> 2.4.38-2
- Removed explicit Requires(post + postun)
- Resolves #225290

* Tue Jul 31 2007 Zdenek Prikryl <zprikryl@redhat.com> 2.4.38-1
- New version 2.4.38
- Resolves #245415

* Fri Feb 23 2007 Karsten Hopp <karsten@redhat.com> 2.4.32-2
- add disttag
- remove trailing dot from summary
- fix buildroot
- -devel package requires same libattr version
- change prereq to Requires(post)
- escape macro in changelog
- replace absolute link with relative link (libattr.so)
- use %%doc macro

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.4.32-1.1
- rebuild

* Wed Jul  5 2006 Thomas Woerner <twoerne@redhat.com> 2.4.32-1
- new version 2.4.32
- fixes segmentation fault in attr, which affects #189106

* Wed Jun  7 2006 Jeremy Katz <katzj@redhat.com> - 2.4.28-2
- rebuild for -devel deps

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 2.4.28-1.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 2.4.28-1.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Feb  3 2006 Thomas Woerner <twoerner@redhat.com> 2.4.28-1
- new version 2.4.28

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Tue Dec  6 2005 Thomas Woerner <twoerner@redhat.com> 2.4.24-2
- spec file cleanup
- mark po files as lang specific

* Sun Nov 06 2005 Florian La Roche <laroche@redhat.com>
- 2.4.24

* Wed Sep 28 2005 Than Ngo <than@redhat.com> 2.4.23-1
- update to 2.4.23

* Wed Sep 28 2005 Than Ngo <than@redhat.com> 2.4.16-6
- get rid of *.la files
- remove duplicate doc files

* Wed Feb  9 2005 Stephen C. Tweedie <sct@redhat.com> 2.4.16-4
- Rebuild

* Fri Sep 10 2004 Stephen C. Tweedie <sct@redhat.com> 2.4.16-3
- Build requires libtool >= 1.5

* Thu Aug 19 2004 Phil Knirsch <pknirsch@redhat.com> 2.4.16-2
- Make libattr.so.* executable.

* Thu Aug 19 2004 Phil Knirsch <pknirsch@redhat.com> 2.4.16-1
- Update to latest upstream version.

* Sun Aug  8 2004 Alan Cox <alan@redhat.com> 2.4.1-6
- Fix bug #125304 (Steve Grubb: build requires gettext)

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Wed Mar 31 2004 Stephen C. Tweedie <sct@redhat.com> 2.4.1-4
- Add missing %%defattr

* Tue Mar 30 2004 Stephen C. Tweedie <sct@redhat.com> 2.4.1-3
- Add /usr/include/attr to files manifest
- Fix location of doc files, add main doc dir to files manifest

* Tue Mar 02 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Aug  5 2003 Elliot Lee <sopwith@redhat.com> 2.4.1-2
- Fix libtool

* Tue Jun  3 2003 Stephen C. Tweedie <sct@redhat.com> 2.4.1-1
- update to attr-2.4.1

* Tue Jan 28 2003 Michael K. Johnson <johnsonm@redhat.com> 2.2.0-1
- update/rebuild

* Sat Jan  4 2003 Jeff Johnson <jbj@redhat.com> 2.0.8-6
- set execute bits on library so that requires are generated.

* Thu Nov 21 2002 Elliot Lee <sopwith@redhat.com> 2.0.8-5
- Redo multilib patch to work everywhere

* Wed Sep 11 2002 Than Ngo <than@redhat.com> 2.0.8-4
- Added fix to install libs in correct directory on 64bit machine 

* Thu Aug 08 2002 Michael K. Johnson <johnsonm@redhat.com> 2.0.8-3
- Made the package only own the one directory that is unique to it:
  /usr/include/attr

* Wed Jun 26 2002 Michael K. Johnson <johnsonm@redhat.com> 2.0.8-2
- get perl out of base with attr-2.0.8-docperms.patch

* Mon Jun 24 2002 Michael K. Johnson <johnsonm@redhat.com> 2.0.8-1
- Initial Red Hat package
  Made as few changes as possible relative to upstream packaging to
  make it easier to maintain long-term.  This means that some of
  the techniques used here are definitely not standard Red Hat
  techniques.  If you are looking for an example package to fit
  into Red Hat Linux transparently, this would not be the one to
  pick.
- attr-devel -> libattr-devel
