%bcond_with systemd

%define _libexecdir %{_libdir}
%define build_compat32 %{?_with_compat32:1}%{!?_with_compat32:0}
%define initdir %{_sysconfdir}/rc.d/init.d
%define use_alternatives 1

%define _unpackaged_files_terminate_build 1

Summary: Common Unix Printing System
Name: cups
Version: 2.3.3
Release: 1%{?_dist_release}%{?with_systemd:.systemd}
Group: servers
Vendor: Project Vine
Distribution: Vine Linux
Packager: daisuke, tomop

License: GPL
Url: https://github.com/OpenPrinting/cups
Source: https://github.com/OpenPrinting/cups/archive/v%{version}.tar.gz#/cups-%{version}.tar.gz
# Our initscript
Source1: cups.init
# Pixmap for desktop file
Source2: cupsprinter.png
# udev rules for libusb devices
Source3: cups-libusb.rules
# LSPP-required ps->pdf filter
Source4: pstopdf
# xinetd config file for cups-lpd service
Source5: cups-lpd
# Logrotate configuration
Source6: cups.logrotate
# Backend for NCP protocol
Source7: ncp.backend
# Cron-based tmpwatch for /var/spool/cups/tmp
Source8: cups.cron
# Filter and PPD for textonly printing
Source9: textonly.filter
Source10: textonly.ppd
Source11: macros.cups

Source101: http://www.openprinting.org/download/printing/dnssd
Source102: pstoraster
Source103: pstoraster.convs
Source104: postscript.ppd.gz
Source105: pdftops.conf

Source201: dvitops
Source202: dvitops.convs
Source203: dvitops.types
Source204: cjktexttops
Source206: pxlmono.ppd.gz
Source207: pxlcolor.ppd.gz
Source208: cups.conf

# PAM enablement, very old patch, not even git can track when or why
# the patch was added.
Patch1: cups-system-auth.patch
# cups-config from devel package conflicted on multilib arches,
# fixed hack with pkg-config calling for gnutls' libdir variable
Patch2: cups-multilib.patch
# if someone makes a change to banner files, then there will <banner>.rpmnew
# with next update of cups-filters - this patch makes sure the banner file 
# changed by user is used and .rpmnew or .rpmsave is ignored
# Note: This could be rewrite with use a kind of #define and send to upstream
Patch3: cups-banners.patch
# don't export ssl libs to cups-config - can't find the reason.
Patch4: cups-no-export-ssllibs.patch
# enables old uri usb:/dev/usb/lp0 - leave it here for users of old printers
Patch5: cups-direct-usb.patch
# fix for redhat dbus spooler - adding new dbus functions to backend/ipp.c
# -> initialize dbus connection and sending dbus broadcast about job queued
# on remote queue with QueueChanged type for PRINTER_CHANGED, JOB_STATE_CHANGED
# and PRINTER_STATE_CHANGED events 
Patch6: cups-eggcups.patch
# when system workload is high, timeout for cups-driverd can be reached -
# increase the timeout
Patch7: cups-driverd-timeout.patch
# cupsd implement its own logrotate, but when MaxLogSize 0 is used, logrotated
# takes care of it
Patch8: cups-logrotate.patch
# usb backend didn't get any notification about out-of-paper because of kernel 
Patch9: cups-usb-paperout.patch
# uri compatibility with old Fedoras
Patch10: cups-uri-compat.patch
# fixing snmp oid for hp printer - upstream doesn't want to support too much
# snmp backend, because it's deprecated
Patch11: cups-hp-deviceid-oid.patch
# same as HP OID
Patch12: cups-ricoh-deviceid-oid.patch
# change to notify type, because when it fails to start, it gives a error
# message + renaming org.cups.cupsd names, because we have cups units in
# in older Fedoras
Patch13: cups-systemd-socket.patch
# use IP_FREEBIND, because cupsd cannot bind to not yet existing IP address
# by default
Patch14: cups-freebind.patch
# add support of multifile
Patch15: cups-ipp-multifile.patch
# prolongs web ui timeout
Patch16: cups-web-devices-timeout.patch
# needs to be set to Yes to avoid race conditions
Patch17: cups-synconclose.patch
# ypbind must be started before cups if NIS configured
Patch18: cups-ypbind.patch
# failover backend for implementing failover functionality
# TODO: move it to the cups-filters upstream
Patch19: cups-failover-backend.patch

# reported upstream
# adds logs when job fails due bad conversion
Patch20: cups-filter-debug.patch
# add device id for dymo printer
Patch21: cups-dymo-deviceid.patch
# 1822154 - cups.service doesn't execute automatically on request
# https://github.com/apple/cups/issues/5708
Patch22: cups-autostart-when-enabled.patch

# selinux and audit enablement for CUPS - needs work and CUPS upstream wants
# to have these features implemented their way in the future
Patch100: cups-lspp.patch

# vine
Patch1000: cups-2.3.3-serverbin-compat.patch

BuildRoot: %{_tmppath}/%{name}-root
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
Requires: tmpwatch
Requires: ghostscript >= 8.71-4
BuildRequires: aspell-devel
BuildRequires: avahi-devel >= 0.6.20
BuildRequires: dbus-devel >= 0.90
BuildRequires: e2fsprogs-devel
BuildRequires: gnutls-devel
BuildRequires: krb5-devel
BuildRequires: libacl-devel
BuildRequires: libjpeg-devel
BuildRequires: libpng-devel
BuildRequires: libtiff-devel
BuildRequires: libusb1-devel
BuildRequires: openldap-devel
BuildRequires: pam-devel
BuildRequires: pkgconfig
BuildRequires: poppler-utils
BuildRequires: python-cups

Requires: avahi >= 0.6.20
Requires: avahi-tools
Requires: dbus >= 0.90
Requires: poppler-utils
Requires: cups-filters

%if %{with systemd}
BuildRequires: systemd-devel
%{?systemd_requires}
%else
Requires(pre): chkconfig initscripts perl
%endif

%description
CUPS printing system provides a portable printing layer for
UNIX® operating systems. It has been developed by Apple Inc.
to promote a standard printing solution for all UNIX vendors and users.
CUPS provides the System V and Berkeley command-line interfaces. 

%description -l ja
　CUPS printing systemはUNIX操作環境においてポータブルな印刷環境を提供
します。CUPSは全てのUNIXベンダーやユーザのために標準的な印刷ソリューショ
ンを提供するためにApple Inc.により開発されました。

　CUPSはSystem VやBerkeleyコマンドラインのインターフェースを提供します。


%package devel
Summary: Common Unix Printing System - development environment
Group: programming
Requires: %{name}-libs = %{version}-%{release}
Requires: e2fsprogs-devel
Requires: gnutls-devel
Requires: krb5-devel
Requires: zlib-devel
License: LGPL

%description devel
CUPS printing system provides a portable printing layer for
UNIX. operating systems. This is the development package for creating
additional printer drivers, and other CUPS services.

%description devel -l ja
　CUPS printing systemはUNIX操作環境においてポータブルな印刷環境を提供
します。

　このパッケージはプリンタドライバを追加したり他のCUPSサービスを開発す
るためのパッケージです。


%package libs
Summary: Common Unix Printing System - libraries
Group: system
License: LGPL

%description libs
CUPS printing system provides a portable printing layer for
UNIX® operating systems. It has been developed by Apple Inc.
to promote a standard printing solution for all UNIX vendors and users.
CUPS provides the System V and Berkeley command-line interfaces.
The cups-libs package provides libraries used by applications to use CUPS
natively, without needing the lp/lpr commands.

%description libs -l ja
　CUPS printing systemはUNIX操作環境においてポータブルな印刷環境を提供
します。CUPSは全てのUNIXベンダーやユーザのために標準的な印刷ソリューショ
ンを提供するためにApple Inc.により開発されました。

　CUPSはSystem VやBerkeleyコマンドラインのインターフェースを提供します。

　cups-libsパッケージはlp/lprコマンドを必要としないCUPSネイティブなアプ
リケーションから使われるライブラリ類です。


%package client
Summary: CUPS printing system - client programs
Group: publishing
License: GPLv2
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
%if %{use_alternatives}
Provides: /usr/bin/lpq /usr/bin/lpr /usr/bin/lp /usr/bin/cancel /usr/bin/lprm /usr/bin/lpstat
Requires(pre): alternatives
Requires(preun): alternatives
%endif
Provides: lpd lpr LPRng

%description client
CUPS printing system provides a portable printing layer for
UNIX® operating systems. This package contains command-line client
programs.

%description client -l ja
　CUPS printing systemはUNIX操作環境においてポータブルな印刷環境を
提供します。

　このパッケージはコマンドラインクライアントプログラムを含んでいま
す。


%package lpd
Summary: CUPS printing system - lpd emulation
Group: servers
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
Provides: lpd
%if %{with systemd}
%{?systemd_requires}
%else
Requires: xinetd
%endif

%description lpd
CUPS printing system provides a portable printing layer for
UNIX® operating systems. This is the package that provides standard
lpd emulation.

%description lpd -l ja
　CUPS printing systemはUNIX操作環境においてポータブルな印刷環境を
提供します。

　このパッケージは標準的なlpdエミュレーションを提供します。


%package -n compat32-%{name}-libs
Summary: Common Unix Printing System - libraries
Group: system

%description -n compat32-%{name}-libs
CUPS printing system provides a portable printing layer for
UNIX® operating systems. It has been developed by Apple Inc.
to promote a standard printing solution for all UNIX vendors and users.
CUPS provides the System V and Berkeley command-line interfaces.
The cups-libs package provides libraries used by applications to use CUPS
natively, without needing the lp/lpr commands.

%description -n compat32-%{name}-libs -l ja
　CUPS printing systemはUNIX操作環境においてポータブルな印刷環境を提供
します。CUPSは全てのUNIXベンダーやユーザのために標準的な印刷ソリューショ
ンを提供するためにApple Inc.により開発されました。

　CUPSはSystem VやBerkeleyコマンドラインのインターフェースを提供します。

　cups-libsパッケージはlp/lprコマンドを必要としないCUPSネイティブなアプリ
ケーションから使われるライブラリ類です。


%package -n compat32-%{name}-devel
Summary: Common Unix Printing System - development environment
Group: programming
Requires: compat32-%{name}-libs = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}
Requires: compat32-e2fsprogs-devel
Requires: compat32-gnutls-devel
Requires: compat32-krb5-devel
Requires: compat32-zlib-devel

%description -n compat32-%{name}-devel
CUPS printing system provides a portable printing layer for
UNIX. operating systems. This is the development package for creating
additional printer drivers, and other CUPS services.

%description -n compat32-%{name}-devel -l ja
　CUPS printing systemはUNIX操作環境においてポータブルな印刷環境を提供
します。

　このパッケージはプリンタドライバを追加したり他のCUPSサービスを開発す
るためのパッケージです。


%debug_package


%prep
%setup -q -n %{name}-%{version}
# Use the system pam configuration.
%patch1 -p1 -b .system-auth
# Prevent multilib conflict in cups-config script.
%patch2 -p1 -b .multilib
# Ignore rpm save/new files in the banners directory.
%patch3 -p1 -b .banners
# Don't export SSLLIBS to cups-config.
%patch4 -p1 -b .no-export-ssllibs
# Allow file-based usb device URIs.
%patch5 -p1 -b .direct-usb
# Increase driverd timeout to 70s to accommodate foomatic (bug #744715).
%patch7 -p1 -b .driverd-timeout
# Re-open the log if it has been logrotated under us.
%patch8 -p1 -b .logrotate
# Support for errno==ENOSPACE-based USB paper-out reporting.
%patch9 -p1 -b .usb-paperout
# Allow the usb backend to understand old-style URI formats.
%patch10 -p1 -b .uri-compat
# Add an SNMP query for HP's device ID OID (STR #3552).
%patch11 -p1 -b .hp-deviceid-oid
# Add an SNMP query for Ricoh's device ID OID (STR #3552).
%patch12 -p1 -b .ricoh-deviceid-oid
# Make cups.service Type=notify (bug #1088918).
%patch13 -p1 -b .systemd-socket
# Use IP_FREEBIND socket option when binding listening sockets (bug #970809).
%patch14 -p1 -b .freebind
# Fixes for jobs with multiple files and multiple formats.
%patch15 -p1 -b .ipp-multifile
# Increase web interface get-devices timeout to 10s (bug #996664).
%patch16 -p1 -b .web-devices-timeout
# Set the default for SyncOnClose to Yes.
%patch17 -p1 -b .synconclose
# CUPS may fail to start if NIS groups are used (bug #1494558)
%patch18 -p1 -b .ypbind
# Add failover backend (bug #1689209)
%patch19 -p1 -b .failover

%if %{?lspp}0
# LSPP support.
%patch100 -p1 -b .lspp
%endif

# Log extra debugging information if no filters are available.
%patch20 -p1 -b .filter-debug
# Added IEEE 1284 Device ID for a Dymo device (bug #747866).
%patch21 -p1 -b .dymo-deviceid
# 1822154 - cups.service doesn't execute automatically on request
%patch22 -p1 -b .autostart-when-enabled

# removed dbus patch - seems breaking things
# Fix implementation of com.redhat.PrinterSpooler D-Bus object.
#%%patch6 -p1 -b .eggcups

%patch1000 -p1 -b .serverbin-compat

# make to use cjktexttops instead texttops.
perl -pi -e 's/texttops$/cjktexttops/' conf/mime.convs.in

# if cupsd is set to log into /var/log/cups, then 'MaxLogSize 0' needs to be
# in cupsd.conf to disable cupsd logrotate functionality and use logrotated
sed -i -e '1iMaxLogSize 0' conf/cupsd.conf.in

%if %{with systemd}
# Add comment text mentioning syslog is systemd journal (bug #1358589)
sed -i -e 's,\"syslog\",\"syslog\" \(syslog means systemd journal by default\),' conf/cups-files.conf.in
%endif

perl -pi -e 's,^#(DefaultCharset\s)utf-8,$1notused,' conf/cupsd.conf.in
perl -pi -e 's,^#(Printcap\s+/etc/printcap),$1,' conf/cupsd.conf.in
perl -pi -e 's,exec_prefix/lib/cups,exec_prefix/%{_lib}/cups,' config-scripts/cups-directories.m4
autoconf

cp %{SOURCE5} cups-lpd.real
perl -pi -e "s,\@LIBDIR\@,%{_libdir},g" cups-lpd.real

# Add group wheel to SystemGroups (bug #1405669)
sed -i -e 's,^SystemGroup .*$, SystemGroup sys root wheel,' conf/cups-files.conf.in

# Let's look at the compilation command lines.
perl -pi -e "s,^.SILENT:,," Makedefs.in

f=CREDITS.md
mv "$f" "$f"~
iconv -f MACINTOSH -t UTF-8 "$f"~ > "$f"
rm "$f"~

# Rebuild configure script for --enable-avahi.
aclocal -I config-scripts
autoconf -I config-scripts

%build
export DSOFLAGS="$DSOFLAGS -L../cgi-bin -L../filter -L../ppdc -L../scheduler -Wl,-z,relro -Wl,-z,now -Wl,-z,relro,-z,now -fPIE -pie"
export CFLAGS="$RPM_OPT_FLAGS -fstack-protector-all -DLDAP_DEPRECATED=1"
# --enable-debug to avoid stripping binaries
%configure --with-docdir=%{_datadir}/%{name}/www --enable-debug \
	--with-exe-file-perm=0755 \
	--with-log-file-perm=0600 \
	--enable-relro \
	--with-pdftops=pdftops \
	--with-dbusdir=%{_sysconfdir}/dbus-1 \
	--with-php=/usr/bin/php-cgi \
	--enable-avahi \
	--enable-threads \
	--enable-gnutls \
	--enable-webif \
	--disable-slp \
%if %{with systemd}
	--with-rundir=/run/cups \
%endif
	localedir=%{_datadir}/locale

# If we got this far, all prerequisite libraries must be here.
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT

make BUILDROOT=$RPM_BUILD_ROOT install 

rm -rf	$RPM_BUILD_ROOT%{initdir} \
	$RPM_BUILD_ROOT%{_sysconfdir}/init.d \
	$RPM_BUILD_ROOT%{_sysconfdir}/rc?.d
%if %{with systemd}
mkdir -p %{buildroot}%{_unitdir}
mv %{buildroot}%{_unitdir}/org.cups.cupsd.path %{buildroot}%{_unitdir}/cups.path
mv %{buildroot}%{_unitdir}/org.cups.cupsd.service %{buildroot}%{_unitdir}/cups.service
mv %{buildroot}%{_unitdir}/org.cups.cupsd.socket %{buildroot}%{_unitdir}/cups.socket
mv %{buildroot}%{_unitdir}/org.cups.cups-lpd.socket %{buildroot}%{_unitdir}/cups-lpd.socket
mv %{buildroot}%{_unitdir}/org.cups.cups-lpd@.service %{buildroot}%{_unitdir}/cups-lpd@.service
/bin/sed -i -e "s,org.cups.cupsd,cups,g" %{buildroot}%{_unitdir}/cups.service
%else
mkdir -p $RPM_BUILD_ROOT%{initdir}
install -m 755 $RPM_SOURCE_DIR/cups.init $RPM_BUILD_ROOT%{initdir}/cups
%endif

find $RPM_BUILD_ROOT%{_datadir}/cups/model -name "*.ppd" |xargs gzip -n9f

%if %{use_alternatives}
pushd $RPM_BUILD_ROOT%{_bindir}
for i in cancel lp lpq lpr lprm lpstat; do
	mv $i $i.cups
done
cd $RPM_BUILD_ROOT%{_sbindir}
mv lpc lpc.cups
cd $RPM_BUILD_ROOT%{_mandir}/man1
for i in cancel lp lpq lpr lprm lpstat; do
	mv $i.1 $i-cups.1
done
cd $RPM_BUILD_ROOT%{_mandir}/man8
mv lpc.8 lpc-cups.8
popd
%endif

mkdir -p $RPM_BUILD_ROOT%{_datadir}/pixmaps $RPM_BUILD_ROOT%{_sysconfdir}/X11/sysconfig $RPM_BUILD_ROOT%{_sysconfdir}/X11/applnk/System $RPM_BUILD_ROOT%{_sysconfdir}/xinetd.d $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d $RPM_BUILD_ROOT%{_sysconfdir}/cron.daily
install -c -m 644 %{SOURCE2} $RPM_BUILD_ROOT%{_datadir}/pixmaps
%if !%{with systemd}
install -c -m 644 cups-lpd.real $RPM_BUILD_ROOT%{_sysconfdir}/xinetd.d/cups-lpd
%endif
install -c -m 644 %{SOURCE6} $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/cups
install -c -m 755 %{SOURCE7} $RPM_BUILD_ROOT%{_libdir}/cups/backend/ncp
install -c -m 755 %{SOURCE8} $RPM_BUILD_ROOT%{_sysconfdir}/cron.daily/cups
install -c -m 755 %{SOURCE9} $RPM_BUILD_ROOT%{_libdir}/cups/filter/textonly
install -c -m 644 %{SOURCE10} $RPM_BUILD_ROOT%{_datadir}/cups/model/textonly.ppd

#install -c -m 644 %{SOURCE105} $RPM_BUILD_ROOT%{_sysconfdir}/cups/pdftops.conf

# Ship an rpm macro for where to put driver executables.
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/rpm/
install -m 0644 %{SOURCE11} $RPM_BUILD_ROOT%{_sysconfdir}/rpm/

# Ship a printers.conf file, and a client.conf file.  That way, they get
# their SELinux file contexts set correctly.
touch $RPM_BUILD_ROOT%{_sysconfdir}/cups/printers.conf
touch $RPM_BUILD_ROOT%{_sysconfdir}/cups/classes.conf
touch $RPM_BUILD_ROOT%{_sysconfdir}/cups/client.conf
touch $RPM_BUILD_ROOT%{_sysconfdir}/cups/subscriptions.conf

# This is %%ghost'ed, but needs to be created in %%install anyway.
touch $RPM_BUILD_ROOT%{_sysconfdir}/cups/lpoptions

# Tell portreserve which port we want it to protect.
# mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/portreserve
# echo ipp > $RPM_BUILD_ROOT%{_sysconfdir}/portreserve/%{name}

# LSB 3.2 printer driver directory
mkdir -p $RPM_BUILD_ROOT%{_datadir}/ppd

# Remove unshipped files.
rm -rf $RPM_BUILD_ROOT%{_mandir}/cat? $RPM_BUILD_ROOT%{_mandir}/*/cat?
rm -f $RPM_BUILD_ROOT%{_datadir}/applications/cups.desktop
rm -rf $RPM_BUILD_ROOT%{_datadir}/icons

# Install the udev rules.
%{__mkdir_p} %{buildroot}/lib/udev/rules.d
install -m644 %{SOURCE3} \
	%{buildroot}/lib/udev/rules.d/70-cups-libusb.rules

# there are pdf-banners shipped with cups-filters (#919489)
rm -rf $RPM_BUILD_ROOT%{_datadir}/cups/banners
rm -f $RPM_BUILD_ROOT%{_datadir}/cups/data/testprint

%if %{with systemd}
# install /etc/tmpfiles.d/cups.conf (bug #656566)
mkdir -p ${RPM_BUILD_ROOT}%{_tmpfilesdir}
cat > ${RPM_BUILD_ROOT}%{_tmpfilesdir}/cups.conf <<EOF
# See tmpfiles.d(5) for details

d /run/cups 0755 root lp -
d /run/cups/certs 0511 lp sys -

d /var/spool/cups/tmp - - - 30d
EOF

# /usr/lib/tmpfiles.d/cups-lp.conf (bug #812641)
cat > ${RPM_BUILD_ROOT}%{_tmpfilesdir}/cups-lp.conf <<EOF
# Legacy parallel port character device nodes, to trigger the
# auto-loading of the kernel module on access.
#
# See tmpfiles.d(5) for details

c /dev/lp0 0660 root lp - 6:0
c /dev/lp1 0660 root lp - 6:1
c /dev/lp2 0660 root lp - 6:2
c /dev/lp3 0660 root lp - 6:3
EOF
%endif

# Ship a PCL XL/PCL 6 filter file from ESP gs-7.07.1
install -c -m 644 %{SOURCE206} $RPM_BUILD_ROOT%{_datadir}/cups/model
install -c -m 644 %{SOURCE207} $RPM_BUILD_ROOT%{_datadir}/cups/model

# Ship a dvitops
install -c -m 755 %{SOURCE201} $RPM_BUILD_ROOT%{_libdir}/cups/filter
install -c -m 644 %{SOURCE202} $RPM_BUILD_ROOT%{_sysconfdir}/cups
install -c -m 644 %{SOURCE203} $RPM_BUILD_ROOT%{_sysconfdir}/cups

# Ship a cjktexttops (import from mdv)
install -c -m 755 %{SOURCE204} $RPM_BUILD_ROOT%{_libdir}/cups/filter/

# disable imagetoraster.
perl -pi -e 's/^(image.+imagetoraster)/#$1/g' %{buildroot}/usr/share/cups/mime/mime.convs

#install -c -m 644 conf/mime.types $RPM_BUILD_ROOT%{_sysconfdir}/cups/mime.types
#install -c -m 644 conf/mime.convs $RPM_BUILD_ROOT%{_sysconfdir}/cups/mime.convs

# create directories for 32bit drivers on x86_64.
%ifarch x86_64
mkdir -p %{buildroot}/usr/lib/cups/{backend,cgi-bin,daemon,driver,filter,monitor,notifier}
%endif


%clean
rm -rf $RPM_BUILD_ROOT


%triggerpostun -- cups < 1.4.8
%ifarch x86_64

echo "moving 32bit binaries to /usr/lib ..."

if [ "$1" -gt 1 ]; then
  for f in `find /usr/lib64/cups/ -type f`; do
    file $f | grep ' ELF 32-bit ' >/dev/null 2>&1
    if [ "$?" = "0" ]; then
      DEST=`echo $f | sed -e 's/^\/usr\/lib64/\/usr\/lib/'`
      mv -f $f $DEST
    fi
  done
fi

%endif

%pre
%ifarch x86_64
if [ -L /usr/lib/cups ]; then
  rm -f /usr/lib/cups
fi
%endif

%post
%if %{with systemd}
%systemd_post %{name}.path %{name}.socket %{name}.service

# Previous migration script unnecessarily put PageLogFormat into cups-files.conf
# (see bug #1148995)
FILE=%{_sysconfdir}/cups/cups-files.conf
for keyword in PageLogFormat; do
    /bin/sed -i -e "s,^$keyword,#$keyword,i" "$FILE" || :
done

# Because of moving logs to journal, we need to create placeholder files
# at /var/log/cups for users, whose are going to install CUPS on new OS
# machine with info message
confignames=( "ErrorLog" "AccessLog" "PageLog" )
lognames=( "error_log" "access_log" "page_log" )
message="This CUPS log has been moved into journal by default unless changes have     been made in /etc/cups/cups-files.conf. Log messages can be got by \"$ journalctl -u  cups -e\""
for ((i=0;i<${#confignames[@]};i++));
do
  found=`/bin/grep -i "${confignames[i]} syslog" /etc/cups/cups-files.conf`
  if [ ! -z "$found" ]
  then
    if [ ! -f %{_localstatedir}/log/cups/${lognames[i]} ]
    then
      %{_bindir}/touch %{_localstatedir}/log/cups/${lognames[i]} || :
    fi
    perms=`%{_bindir}/ls -lah %{_localstatedir}/log/cups/${lognames[i]} | /bin/grep -v -e "\-rw-------" -e "root lp"`
    if [ ! -z "$perms" ]
    then
      # we need to set correct permissions and ownership because of possible
      # security issues
      # we need to have it here, because previous CUPS releases had the bug.
      # Checking permissions and ownership here fixes it.
      %{_bindir}/chown root:lp %{_localstatedir}/log/cups/${lognames[i]} || :
      %{_bindir}/chmod 600 %{_localstatedir}/log/cups/${lognames[i]} || :
    fi
    lastmessage=`%{_bindir}/tail -n 1 %{_localstatedir}/log/cups/${lognames[i]} | /bin/grep "$message"`
    if [ -z "$lastmessage" ]
    then
      %{_bindir}/echo $message >> %{_localstatedir}/log/cups/${lognames[i]} || :
    fi
  fi
done

%else
/sbin/chkconfig --del cupsd 2>/dev/null || true # Make sure old versions aren't there anymore
/sbin/chkconfig --add cups || true
%endif
# Remove old-style certs directory; new-style is /var/run
# (see bug #194581 for why this is necessary).
/bin/rm -rf /etc/cups/certs
rm -f %{_localstatedir}/cache/cups/*.ipp %{_localstatedir}/cache/cups/*.cache

%if !%{with systemd}
if [ $1 -eq 1 ]; then
  # First install.  Build ppds.dat.
  /sbin/service cups reload >/dev/null 2>&1 || :
fi
exit 0
%endif

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%post client
%if %{use_alternatives}
/sbin/update-alternatives --install %{_bindir}/lpr print %{_bindir}/lpr.cups 40 \
	 --slave %{_bindir}/lp print-lp %{_bindir}/lp.cups \
	 --slave %{_bindir}/lpq print-lpq %{_bindir}/lpq.cups \
	 --slave %{_bindir}/lprm print-lprm %{_bindir}/lprm.cups \
	 --slave %{_bindir}/lpstat print-lpstat %{_bindir}/lpstat.cups \
	 --slave %{_bindir}/cancel print-cancel %{_bindir}/cancel.cups \
	 --slave %{_sbindir}/lpc print-lpc %{_sbindir}/lpc.cups \
	 --slave %{_mandir}/man1/cancel.1.gz print-cancelman %{_mandir}/man1/cancel-cups.1.gz \
	 --slave %{_mandir}/man1/lp.1.gz print-lpman %{_mandir}/man1/lp-cups.1.gz \
	 --slave %{_mandir}/man8/lpc.8.gz print-lpcman %{_mandir}/man8/lpc-cups.8.gz \
	 --slave %{_mandir}/man1/lpq.1.gz print-lpqman %{_mandir}/man1/lpq-cups.1.gz \
	 --slave %{_mandir}/man1/lpr.1.gz print-lprman %{_mandir}/man1/lpr-cups.1.gz \
	 --slave %{_mandir}/man1/lprm.1.gz print-lprmman %{_mandir}/man1/lprm-cups.1.gz \
	 --slave %{_mandir}/man1/lpstat.1.gz print-lpstatman %{_mandir}/man1/lpstat-cups.1.gz
%endif

%if %{with systemd}
%post lpd
%systemd_post cups-lpd.socket
exit 0
%endif

%post -n compat32-%{name}-libs -p /sbin/ldconfig

%postun -n compat32-%{name}-libs -p /sbin/ldconfig

%preun
%if %{with systemd}
%systemd_preun %{name}.path %{name}.socket %{name}.service
%else
if [ "$1" = "0" -o -x /bin/systemctl ]; then
	/sbin/service cups stop > /dev/null 2>&1
	/sbin/chkconfig --del cups
fi
exit 0
%endif

%preun client
%if %{use_alternatives}
if [ $1 -eq 0 ] ; then
	/usr/sbin/alternatives --remove print %{_bindir}/lpr.cups
fi
%endif
exit 0

%if %{with systemd}
%preun lpd
%systemd_preun cups-lpd.socket
exit 0
%endif

%if %{with systemd}
%postun
%systemd_postun_with_restart %{name}.path %{name}.socket %{name}.service
%endif

if [ "$1" -ge "1" ]; then
	/sbin/service cups condrestart > /dev/null 2>&1
fi
exit 0

%if %{with systemd}
%postun lpd
%systemd_postun_with_restart cups-lpd.socket
exit 0
%endif

%triggerin -- samba-client
ln -sf ../../../bin/smbspool %{_libdir}/cups/backend/smb || :
exit 0

%triggerun -- samba-client
[ $2 = 0 ] || exit 0
rm -f %{_libdir}/cups/backend/smb


%files
%defattr(-,root,root)
%license LICENSE.txt
%doc README.md CREDITS.md CHANGES.md
%attr(0660,root,lp) %dev(char,6,0) /lib/udev/devices/lp0
%attr(0660,root,lp) %dev(char,6,1) /lib/udev/devices/lp1
%attr(0660,root,lp) %dev(char,6,2) /lib/udev/devices/lp2
%attr(0660,root,lp) %dev(char,6,3) /lib/udev/devices/lp3
/lib/udev/rules.d/70-cups-libusb.rules
%dir %attr(0755,root,lp) %{_sysconfdir}/cups
%config(noreplace) %attr(0640,root,lp) %{_sysconfdir}/cups/cupsd.conf
%attr(0640,root,lp) %{_sysconfdir}/cups/cupsd.conf.default
%config(noreplace) %attr(0600,root,lp) %{_sysconfdir}/cups/classes.conf
%config(noreplace) %attr(0644,root,lp) %{_sysconfdir}/cups/client.conf
%config(noreplace) %attr(0644,root,lp) %{_sysconfdir}/cups/cups-files.conf
%config(noreplace) %attr(0644,root,lp) %{_sysconfdir}/cups/cups-files.conf.default
#%config(noreplace) %attr(0644,root,lp) %{_sysconfdir}/cups/pdftops.conf
%config(noreplace) %attr(0600,root,lp) %{_sysconfdir}/cups/printers.conf
%config(noreplace) %attr(0644,root,lp) %{_sysconfdir}/cups/snmp.conf
%config(noreplace) %attr(0644,root,lp) %{_sysconfdir}/cups/snmp.conf.default
%config(noreplace) %attr(0644,root,lp) %{_sysconfdir}/cups/subscriptions.conf
#config(noreplace) %{_sysconfdir}/cups/mime.types
#config(noreplace) %{_sysconfdir}/cups/mime.convs
#%config(noreplace) %{_sysconfdir}/cups/pstoraster.convs
%config(noreplace) %{_sysconfdir}/cups/dvitops.types
%config(noreplace) %{_sysconfdir}/cups/dvitops.convs
%config(noreplace) %attr(0644,root,lp) %{_sysconfdir}/cups/lpoptions
%dir %attr(0755,root,lp) %{_sysconfdir}/cups/ppd
%dir %attr(0700,root,lp) %{_sysconfdir}/cups/ssl
%config(noreplace) %{_sysconfdir}/pam.d/cups
%config(noreplace) %{_sysconfdir}/logrotate.d/cups
%if %{with systemd}
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}.socket
%{_unitdir}/%{name}.path
%config(noreplace) %{_tmpfilesdir}/cups*.conf
%else
%config(noreplace) %{_sysconfdir}/xinetd.d/cups-lpd
%dir %attr(0755,root,lp) /var/run/cups
%dir %attr(0511,lp,sys) /var/run/cups/certs
%config(noreplace) %{initdir}/cups
%endif
%{_bindir}/cupstestppd
#{_bindir}/cupstestdsc
%{_bindir}/ippfind
%{_bindir}/ipptool
%{_bindir}/ppd*
%dir %{_libdir}/cups
%{_libdir}/cups/backend
%{_libdir}/cups/cgi-bin
%dir %{_libdir}/cups/daemon
%{_libdir}/cups/daemon/cups-exec
%{_libdir}/cups/daemon/cups-deviced
%{_libdir}/cups/daemon/cups-driverd
%{_libdir}/cups/notifier
%{_libdir}/cups/filter
%{_libdir}/cups/monitor
%{_libdir}/cups/driver
%ifarch x86_64
%dir %{_prefix}/lib/cups
%dir %{_prefix}/lib/cups/*
%endif
%{_mandir}/man1/cups.1*
%{_mandir}/man1/cupstest*
%{_mandir}/man1/ipp*
%{_mandir}/man1/ppd*
%{_mandir}/man[578]/*
%{_sbindir}/*
%exclude %{_sbindir}/lpc.cups
%{_datadir}/cups
%{_datadir}/locale/*/*
%{_datadir}/ppd
%dir %attr(1770,root,lp) /var/spool/cups/tmp
%dir %attr(0710,root,lp) /var/spool/cups
%dir %attr(0755,lp,sys) /var/log/cups
%{_datadir}/pixmaps/cupsprinter.png
%{_sysconfdir}/cron.daily/cups
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/cups.conf

%dir %{_libdir}/cups/command
%{_libdir}/cups/command/ippevepcl
%{_libdir}/cups/command/ippeveps
%{_mandir}/man7/ippevepcl.7.gz

%files libs
%defattr(-,root,root)
%doc LICENSE.txt
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_bindir}/cups-config
%{_libdir}/*.so
%{_includedir}/cups
%{_mandir}/man1/cups-config.1*
%{_sysconfdir}/rpm/macros.cups

%files client
%{_sbindir}/lpc.cups
%{_bindir}/cancel*
%{_bindir}/lp*
%{_mandir}/man1/lp*.1.gz
%{_mandir}/man1/cancel-cups.1.gz
%{_mandir}/man8/lpc-cups.8.gz

%{_bindir}/ippeveprinter
%{_mandir}/man1/ippeveprinter.1.gz

%files lpd
%defattr(-,root,root)
%if %{with systemd}
%{_unitdir}/cups-lpd.socket
%{_unitdir}/cups-lpd@.service
%endif
%{_libdir}/cups/daemon/cups-lpd
%{_mandir}/man8/cups-lpd.8.gz

%if %{build_compat32}
%files -n compat32-%{name}-devel
%defattr(-,root,root)
%{_libdir}/*.so

%files -n compat32-%{name}-libs
%doc LICENSE.txt
%defattr(-,root,root)
%{_libdir}/*.so.*
%endif


%changelog
* Sun Nov 08 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.3.3-2
- shifted to OpenPrinting version.

* Fri May 22 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.3.3-1
- new upstream release.
- added systemd support (disabled as default).
- splitted the main package into 3 subpackages: cups, cups-client, cups-lpd.

* Wed May 08 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.2.11-1
- new upstream release.

* Thu Jan 24 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.2.10-1
- new upstream release.
- dropped Patch10-11, 14, 17, 19-20, 27-28, 33-34 and 38.

* Wed Jan 03 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.2.6-1
- new upstream release.
- replaced all patches from rawhide.
- updated Patch102.

* Wed Jun 29 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.4-2
- rebuilt with new toolchain.

* Thu Jun 16 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.4-1
- new upstream release.

* Sat May 14 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.3-3
- changed R:openssl-devel in cups-devel to R:gnutls-devel.
- added R:e2fsprogs-devel to cups-devel.

* Tue May 10 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.3-2
- rebuilt with gnutls.

* Sat Feb  6 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.3-1
- new upstream release.

* Thu Dec  3 2015 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.2-1
- new upstream release.

* Wed Dec  2 2015 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.1-1
- new upstream release.

* Sun Oct  4 2015 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.0-1
- new upstream release.

* Tue Jun  9 2015 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.3-1
- new upstream release.

* Tue Feb 24 2015 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.2-1
- new upstream release.

* Sun Oct  5 2014 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.0-1
- new upstream release.

* Sun Jun  8 2014 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.7.3-1
- new upstream release.
- removed Patch100 (fixed in upstream).

* Tue Feb 11 2014 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.7.1-1
- new upstream release.

* Sat Jan 04 2014 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.7.0-1
- new upstream release.

* Tue Apr 17 2012 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.8-6
- modified initscript and added Patch104 to deal with wrong drivers.

* Sun Feb 12 2012 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.8-5
- fixed %%changelog.

* Sun Feb 12 2012 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.8-4
- removed /etc/cups/mime.{convs,types}.

* Fri Feb 10 2012 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.8-3
- replaced some patches.
- fixed to print splitted images (BTS:1217).

* Sat Sep 10 2011 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.8-2
- added Patch103 to detect printers with 32bit drivers.

* Thu Sep 08 2011 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.8-1
- new upstream release (against CVE-2011-2896).
- added str3914.patch (against CVE-2011-3170).
- updated patches.

* Sun May 29 2011 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.6-2
- added Patch101.

* Tue Mar 22 2011 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.6-1
- new upstream release.
- dropped old patches.
- shipped some patches from fedora development.

* Sun Jul  4 2010 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 1.3.11-6
- add --disable-slp option in configure

* Sun Jul  4 2010 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 1.3.11-5
- add Patch340 for fix CVE-2009-2820
- add Patch350 for fix CVE-2009-3553
- patch340,350 are from rhel5

* Sun Jul  4 2010 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 1.3.11-4
- fix changelog typo
- add Patch310 for fix CVE-2010-0540 (texttop)
- add Patch320 for fix CVE-2010-0542 (web IF CSRF)
- add Patch330 for fix CVE-2010-1748 (web IF uninit memory read)

* Sun Mar  7 2010 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 1.3.11-3
- setuid 0 to lppasswd binary

* Sat Mar  6 2010 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 1.3.11-2
- add Patch300 for fix CVE-2010-0393 (lppasswd)

* Fri Jul 10 2009 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.3.11-1
- new upstream release

* Sun Jun 28 2009 NAKAMURA Kenta <kenta@vinelinux.org> 1.3.10-2
- Build requires krb5-devel.
- The devel sub-package requires krb5-devel.

* Thu Jun 04 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.3.10-1
- new upstream release
- remove LC_ALL from cjktexttops

* Sat Apr 04 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.3.9-4
- rebuild with openldap-2.4.11

* Mon Mar 23 2009 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.3.9-3
- add /usr/lib/cups for 32bit binary drivers on x86_64.

* Sat Jan 17 2009 Toshiharu Kudoh <toshi.kd2@gmail.com> 1.3.9-2
- rebuild with gnutls-2.6.3

* Wed Oct 29 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.3.9-1
- new upstream release
- renumber fedora patches
- remove hal patch, hal backend module is now provided by hal-cups-utils

* Mon Apr 21 2008 Tomohiro 'Tomo-p' KATO <tomop@teamgedoh.net> 1.3.7-2
- remove libacl from dependency.

* Fri Apr 18 2008 Tomohiro 'Tomo-p' KATO <tomop@teamgedoh.net> 1.3.7-1
- new upstream release.
- ship some patches from Fedora development.

* Sun Aug 26 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 1.1.23-0vl13
- add Patch300 and Patch310 for CVE-2007-0104 and CVE-2007-3387 respectively
  (same fixes for 1.1.23-0vl7.1 for Vine-4.1)

* Sat May 26 2007 NAKAMURA Kenta <kenta@vinelinux.org> 1.1.23-0vl12
- enabled Patch20: cups-gcc4.patch

* Mon May 21 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 1.1.23-0vl11
- always do %%configure on all archs (due to autoconf upgrade)

* Thu May 17 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 1.1.23-0vl10
- rebuild with new openssl

* Thu May 03 2007 NAKAMURA Kenta <kenta@vinelinux.org> 1.1.23-0vl9
- added compat32 subpackage for x86_64 arch support.

* Sat Apr 28 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 1.1.23-0vl8
- rebuild with dbus-1.0

* Fri Oct 27 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 1.1.23-0vl7
- add Patch50, Source20 to support hal backend.

* Thu Jun 29 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 1.1.23-0vl6
- add cjktexttops to use mpage for text-ps filter
  (Source18, Patch210)
- mark mime.convs and mime.types as config file

* Sat Mar 11 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 1.1.23-0vl5
- add Patch43 for dbus support
- add Patch200 to support UTF-8 ppd files

* Wed Feb 15 2006 Shu KONNO <owa@bg.wakwak.com> 1.1.23-0vl4
- fixed cups-link.patch of missing "-L../cups"
- added %%configure for x86_64 architecture support

* Sat Jan 28 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 1.1.23-0vl3
- import some FC patches
  - fix several security bugs
    - CVS-2005-3625,CVS-2005-3626,CVS-2005-3627
    - CAN-2005-2097
    - CAN-2004-0888
    - CAN-2005-0064
  - apply upstream patches

* Sun Mar 27 2005 Satoshi MACHINO <machino@vinelinux.org> 1.1.23-0vl2
- added dvitops, dvitops.convs and dvitops.types

* Tue Jan 04 2005 Satoshi MACHINO <machino@vinelinux.org> 1.1.23-0vl1
- new upstream version(cups-1.1.23)
- removed unused patches

* Fri Dec 31 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.23-0vl0.1rc1
- added cups-1.1.23rc1-scheduler_client.patch
	-- special thanks to kmuto@debian.org

* Mon Dec 20 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.23-0vl0.0rc1
- new upstream version (cups-1.1.23rc1)

* Wed Nov 03 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.22-0vl1
- new upstream version (cups-1.1.22)
	-- updated cups-resource-ja-1.1.22

* Sun Oct 17 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.22-0vl0.0rc2
- new upstream version (cups-1.1.22rc2)

* Wed Oct 06 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.22-0vl0.0rc1
- new upstream version (cups-1.1.22rc1)

* Thu Sep 16 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.21-0vl1
- new upstream version (cups-1.1.21)

* Thu Aug 26 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.21-0vl0.1rc2
- added some txt files in docdir

* Wed Aug 25 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.21-0vl0.0rc2
- new upstream version (cups-1.1.21rc2)
- updated to cups-1.1.21rc2-makefile.patch(patch11)

* Sun May 30 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.21-0vl0.0rc1
- new upstream version (cups-1.1.21rc1)
- updated cups-resource-ja-1.1.21.tar.bz2
- updated ppdsdat.patch
- dropped system-auth.patch

* Fri Apr 23 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.20-0vl6
- updated pstorater to v1.6

* Sun Apr 18 2004 Satoshi MACHINO <machino@vinelinux.org> 1.1.20-0vl5
- removed README.vine

* Thu Apr 15 2004 KOBAYASHI R. Taizo <tkoba@vinelinux.org> 1.1.20-0vl4
- rebuild

* Wed Dec 10 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.20-0vl3
- fixed DefaultCharset in cupsd.conf

* Mon Dec 08 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.20-0vl2
- added PCL XL/PCL 6 PPD and filter from ESP gs-7.07.1
- updated pstoraster

* Sun Dec 07 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.20-0vl1
- new upstream version (cups-1.1.20)
	-- fixed resource-ja
	-- changed DefaultCharset in cupsd.conf
	-- removed patch100
- raised update-alternatives's priority to 50

* Sat Nov 15 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.19-0vl6
- added Patch11 (cups-1.1.19-makefile.patch)
	-- fixed makefile
- added resource-ja (imported from cups-1.2.x)
- added Patch100(cups-1.1.19-lang-adhoc.patch)
	-- fixed "DefaultCharset EUC-JP" in cupsd.conf
	-- Don't fallback to C locale in setlocale()

* Fri Nov 14 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.19-0vl5
- merged to 1.1.20rc6 patch
- dropped patches
	--cups-idefense-v2.patch, cups-1.1.17-sanity.patch
- deleted needless dependence in Obsoletes

* Thu Nov 13 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.19-0vl4
- fixed init script for logrotation

* Sun Oct 26 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.19-0vl3
- fixed coding system in spec file
- updated README.vine

* Mon Jul 07 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.19-0vl2
- added cups-1.1.17-sanity.patch
- added Japanese descriptions

* Fri Jun 06 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.19-0vl1
- fixed spec file

* Thu Jun 05 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.19-0vl0.1
- new upstream vrsion
- remade spec file

* Sun May 18 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.19-0.rc5vl1
	-- disable D-BUS.
- new upstream version
- added some fixes. from cups-1.1.19-0.rc5.2
	-- disable D-BUS. 
	-- Fix option parsing in lpq (bug #90823).
	-- No longer need error, sigchld patches.
	-- Ship cupstestppd.
	-- Mark banners as config files (bug #89069).

* Fri Apr 18 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.18-0vl2
- imported some patches from rawhide (cups-1.1.18-2)
	-- added cups-idefense-v2.patch
	-- added cups-1.1.17-pdftops.patch
	-- added cups-1.1.17-error.patch
	-- added cups-1.1.17-rcp.patch
	-- added cups-1.1.17-ppdsdat.patch
	-- added cups-1.1.17-sigchld.patch
- Fix translation in the init script
- Build ppds.dat on first install.
- Use pkg-config information to find SSL libraries
- Make 'service cups reload' update the configuration first
- added README.vine

* Sun Jan 05 2003 Satoshi MACHINO <machino@vinelinux.org> 1.1.18-0vl1
- fixed alternative path

* Fri Dec 27 2002 Satoshi MACHINO <machino@vinelinux.org> 1.1.18-0vl0
- New upstream version
- dropped patch4 (merged cups-1.1.18)
- dropped epoch tag

* Thu Dec 26 2002 Satoshi MACHINO <machino@vinelinux.org> 1.1.17-3vl0
- build on Vine Linux

* Tue Dec 10 2002 Tim Waugh <twaugh@redhat.com> 1.1.17-3
- Fix cupsd startup hang (bug #79346).

* Mon Dec  9 2002 Tim Waugh <twaugh@redhat.com> 1.1.17-2
- Fix parallel backend behaviour when cancelling jobs.

* Mon Dec  9 2002 Tim Waugh <twaugh@redhat.com> 1.1.17-1
- 1.1.17.
- No longer need libdir patch.
- Fix logrotate script (bug #76791).

* Wed Nov 20 2002 Tim Waugh <twaugh@redhat.com>
- Build requires XFree86-devel (bug #78362).

* Wed Nov 20 2002 Tim Waugh <twaugh@redhat.com>
- 1.1.16.
- Updated system-auth patch.
- Add ncp backend script.

* Wed Nov 13 2002 Tim Waugh <twaugh@redhat.com> 1.1.15-15
- Set alternatives priority to 40.

* Mon Nov 11 2002 Nalin Dahyabhai <nalin@redhat.com> 1.1.15-14
- Buildrequire pam-devel.
- Patch default PAM config file to remove directory names from module paths,
  allowing the configuration files to work equally well on multilib systems.
- Patch default PAM config file to use system-auth, require the file at build-
  time because that's what data/Makefile checks for.

* Fri Nov  8 2002 Tim Waugh <twaugh@redhat.com> 1.1.15-13
- Use logrotate for log rotation (bug #76791).
- No longer need cups.desktop, since redhat-config-printer handles it.

* Thu Oct 17 2002 Tim Waugh <twaugh@redhat.com> 1.1.15-12
- Revert to libdir for CUPS_SERVERBIN.

* Thu Oct 17 2002 Tim Waugh <twaugh@redhat.com> 1.1.15-11
- Use %%configure for multilib correctness.
- Use libexec instead of lib for CUPS_SERVERBIN.
- Ship translated man pages.
- Remove unshipped files.
- Fix file list permissions (bug #59021, bug #74738).
- Fix messy initscript output (bug #65857).
- Add 'reload' to initscript (bug #76114).

* Fri Aug 30 2002 Bernhard Rosenkraenzer <bero@redhat.de> 1.1.15-10
- Add generic postscript PPD file (#73061)

* Mon Aug 19 2002 Tim Waugh <twaugh@redhat.com> 1.1.15-9
- Fix prefix in pstoraster (bug #69573).

* Mon Aug 19 2002 Tim Waugh <twaugh@redhat.com> 1.1.15-8
- Disable cups-lpd by default (bug #71712).
- No need for fread patch now that glibc is fixed.

* Thu Aug 15 2002 Tim Waugh <twaugh@redhat.com> 1.1.15-7
- Really add cups-lpd xinetd file (bug #63919).
- Ship pstoraster (bug #69573).
- Prevent fread from trying to read from beyond EOF (fixes a segfault
  with new glibc).

* Sat Aug 10 2002 Elliot Lee <sopwith@redhat.com> 1.1.15-6
- rebuilt with gcc-3.2 (we hope)

* Mon Aug  5 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.15-5
- Add cups-lpd xinetd file (#63919)

* Tue Jul 23 2002 Florian La Roche <Florian.LaRoche@redhat.de> 1.1.15-4
- add a "exit 0" to postun script

* Tue Jul  2 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.15-3
- Add a symlink /usr/share/cups/doc -> /usr/share/doc/cups-devel-1.1.15
  because some applications expect to find the cups docs in
  /usr/share/cups/doc

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Fri Jun 21 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.15-1
- 1.1.15-1
- Fix up smb printing trigger (samba-client, not samba-clients)
- Start cupsd earlier, apparently it needs to be running before samba
  starts up for smb printing to work.

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Tue May  7 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.14-17
- Rebuild in current environment
- [-16 never existed because of build system breakage]

* Wed Apr 17 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.14-15
- Fix bug #63387

* Mon Apr 15 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.14-14
- Fix dangling symlink created by samba-clients trigger

* Wed Apr 10 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.14-13
- Add desktop file and icon for CUPS configuration

* Wed Apr  3 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.14-12
- Support SMB printing (#62407)
- Add HTML redirections to doc files to work around users mistaking
  /usr/share/doc/cups-1.1.14 for the web frontend (#62405)

* Tue Apr  2 2002 Bill Nottingham <notting@redhat.com> 1.1.14-11
- fix subsys in initscript (#59206)
- don't strip binaries

* Mon Mar 11 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.14-10
- Make initscript use killproc instead of killall

* Fri Mar  8 2002 Bill Nottingham <notting@redhat.com> 1.1.14-9
- use alternatives --initscript support

* Mon Mar  4 2002 Bill Nottingham <notting@redhat.com> 1.1.14-8
- use the right path for the lpc man page, duh

* Thu Feb 28 2002 Bill Nottingham <notting@redhat.com> 1.1.14-7
- lpc man page is alternative too
- run ldconfig in -libs %post/%postun, not main
- remove alternatives in %preun

* Wed Feb 27 2002 Bill Nottingham <notting@redhat.com> 1.1.14-6
- don't source /etc/sysconfig/network in cups.init, we don't use any
  values from it

* Tue Feb 26 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.14-4
- Fix bugs #60220 and #60352

* Thu Feb 21 2002 Tim Powers <timp@redhat.com>
- rebuild against correct version of openssl (0.9.6b)

* Wed Feb 20 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.14-2
- Add all man pages to alternatives (#59943)
- Update to real 1.1.14

* Tue Feb 12 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.14-1
- Update to almost-1.1.14

* Mon Feb 11 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.13-5
- Move cups-config to cups-devel subpackage
- Make alternatives usage a %%define to simplify builds for earlier
  releases
- Explicitly provide things we're supplying through alternatives
  to shut up kdeutils dependencies

* Tue Feb  5 2002 Tim Powers <timp@redhat.com>
- shut the alternatives stuff up for good

* Fri Feb  1 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.13-3
- Fix alternatives stuff
- Don't display error messages in %%post

* Wed Jan 30 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.13-2
- alternatives stuff

* Tue Jan 29 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.13-1
- 1.1.13
- Add patch for koi8-{r,u} and iso8859-8 encodings (#59018)
- Rename init scripts so we can safely "killall cupsd" from there

* Sat Jan 26 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.12-1
- Initial (conflicting, since alternatives isn't there yet) packaging for
  Red Hat Linux

* Sat Jan 19 2002 Bernhard Rosenkraenzer <bero@redhat.com>
- 1.1.12

* Mon Nov  5 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.10-3
- Compress PPD files
- Fix build with gcc 3.1
- Fix init script

* Tue Sep  4 2001 Bernhard Rosenkraenzer <bero@redhat.com> 1.1.10-2
- Fix URL
- Generate printcap
- s/Copyright/License/g

* Tue Sep  4 2001 Than Ngo <than@redhat.com> 1.1.10-1
- update to 1.1.10-1 for ExtraBinge 7.2

* Tue May 29 2001 Michael Stefaniuc <mstefani@redhat.com>
- update to 1.1.8
- changed cupsd.conf to generate /etc/printcap

* Tue May 15 2001 Than Ngo <than@redhat.com>
- update to 1.1.7, bugfixes

* Thu Dec 14 2000 Than Ngo <than@redhat.com>
- fixed package dependency with lpr and LPRng

* Wed Oct 25 2000 Than Ngo <than@redhat.com>
- remove man/cat

* Tue Oct 24 2000 Than Ngo <than@redhat.com>
- don't start cupsd service in level 0, fixed

* Thu Oct 19 2000 Than Ngo <than@redhat.com>
- update to 1.1.4
- fix CUPS_DOCROOT (Bug #18717)

* Fri Aug 11 2000 Than Ngo <than@redhat.de>
- update to 1.1.2 (Bugfix release)

* Fri Aug 4 2000 Than Ngo <than@redhat.de>
- fix, cupsd read config file under /etc/cups (Bug #15432)
- add missing cups filters

* Wed Aug 2 2000 Tim Powers <timp@redhat.com>
- rebuilt against libpng-1.0.8

* Tue Aug 01 2000 Than Ngo <than@redhat.de>
- fix permission, add missing ldconfig in %post and %postun (Bug #14963)

* Sat Jul 29 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 1.1.1 (this has some major bugfixes)
- Fix a typo in initscript (it's $?, not ?$)
- Fix /usr/etc vs. /etc trouble, don't insist on /usr/var (YUCK!)
- Create the spool dir

* Fri Jul 28 2000 Than Ngo <than@redhat.de>
- fix unclean code for building against gcc-2.96
- add missing restart function in startup script

* Fri Jul 28 2000 Tim Powers <timp@redhat.com>
- fixed initscript so that conrestart doesn't return 1 if the test fails

* Mon Jul 24 2000 Prospector <prospector@redhat.com>
- rebuilt

* Wed Jul 19 2000 Than Ngo <than@redhat.de>
- using service to fire them up
- fix Prereq section

* Mon Jul 17 2000 Tim Powers <timp@redhat.com>
- added defattr to the devel package

* Sun Jul 16 2000 Than Ngo <than@redhat.de>
- add cups config files

* Sat Jul 15 2000 Than Ngo <than@redhat.de>
- update to 1.1 release
- move back to /etc/rc.d/init.d
- fix cupsd.init to work with /etc/init.d and /etc/rc.d/init.d
- split cups

* Wed Jul 12 2000 Than Ngo <than@redhat.de>
- rebuilt

* Thu Jul 06 2000 Tim Powers <timp@redhat.com>
- fixed broken PreReq to now require /etc/init.d

* Tue Jun 27 2000 Tim Powers <timp@redhat.com>
- PreReq initscripts >= 5.20

* Mon Jun 26 2000 Tim Powers <timp@redhat.com>
- started changelog 
- fixed init.d script location
- changed script in init.d quite a bit and made more like the rest of our
  startup scripts 
