%bcond_with systemd

%define build_compat32 %{?_with_compat32:1}%{!?_with_compat32:0}

%global username    saslauth
%if %{with systemd}
%global homedir     /run/saslauthd
%else
%global homedir     /var/run/saslauthd
%endif

%define _plugindir2 %{_libdir}/sasl2

Summary: The Cyrus SASL library.
Summary(ja): Cyrus SASL ライブラリ
Name: cyrus-sasl
Version: 2.1.28
Release: 1%{?_dist_release}%{?with_systemd:.systemd}
Group: system
Vendor: Project Vine
Distribution: Vine Linux

License: BSD with advertising
URL: http://cyrusimap.org/
Source0: https://github.com/cyrusimap/cyrus-sasl/releases/download/cyrus-sasl-%{version}/cyrus-sasl-%{version}.tar.gz
Source4: saslauthd.init
Source5: README.RPM
Source9: saslauthd.sysconfig
Source10: saslauthd.service
## From upstream git, required for reconfigure after applying patches to configure.ac
# https://raw.githubusercontent.com/cyrusimap/cyrus-sasl/master/autogen.sh
Source11: autogen.sh

Patch11: cyrus-sasl-2.1.25-no_rpath.patch
Patch15: cyrus-sasl-2.1.20-saslauthd.conf-path.patch
Patch23: cyrus-sasl-2.1.23-man.patch
Patch24: cyrus-sasl-2.1.21-sizes.patch
# The 64 bit *INT8 type is not used anywhere and other types match
Patch49: cyrus-sasl-2.1.26-md5global.patch

Patch101: cyrus-sasl-2.1.27-Add-basic-test-infrastructure.patch
Patch102: cyrus-sasl-2.1.27-Add-Channel-Binding-support-for-GSSAPI-GSS-SPNEGO.patch
#https://github.com/simo5/cyrus-sasl/commit/ebd2387f06c84c7f9aac3167ec041bb01e5c6e48
Patch106: cyrus-sasl-2.1.27-nostrncpy.patch
# Upstream PR: https://github.com/cyrusimap/cyrus-sasl/pull/635
Patch107: cyrus-sasl-2.1.27-more-tests.patch
Patch108: cyrus-sasl-2.1.27-Add-support-for-setting-max-ssf-0-to-GSS-SPNEGO.patch
#Migration tool should be removed from Fedora 36
Patch109: cyrus-sasl-2.1.27-Migration-from-BerkeleyDB.patch
Patch500: cyrus-sasl-2.1.27-coverity.patch
Patch501: cyrus-sasl-2.1.27-cumulative-digestmd5.patch
Patch502: cyrus-sasl-2.1.27-cumulative-ossl3.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: autoconf, automake, libtool
# Note: berkeley db for sasl2, gdbm for sasl1.
BuildRequires: libdb-devel
BuildRequires: openssl-devel
BuildRequires: pam-devel
BuildRequires: libmariadb-devel
BuildRequires: libpq-devel
BuildRequires: openldap-devel
BuildRequires: zlib-devel
BuildRequires: pkgconfig
BuildRequires: krb5-devel
BuildRequires: groff
BuildRequires: libxcrypt-devel
%if %{with systemd}
%{?systemd_requires}
%else
Requires(post): chkconfig
Requires(postun): chkconfig
%endif

%description
The %{name} package contains the Cyrus implementation of SASL.
SASL is the Simple Authentication and Security Layer, a method for
adding authentication support to connection-based protocols.


%package devel
Summary: Files needed for developing applications with Cyrus SASL.
Summary(ja): Cyrus SASL を用いるアプリケーションの開発に必要なファイル
Group: programming
Requires: %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains files needed for developing and
compiling applications which use the Cyrus SASL library.


%package gssapi
Summary: GSSAPI support for Cyrus SASL.
Summary(ja): Cyrus SASL の GSSAPI 認証サポート
Group: system
Requires: %{name} = %{version}-%{release}

%description gssapi
The %{name}-gssapi package contains the Cyrus SASL plugins which
support GSSAPI authentication. GSSAPI is commonly used for Kerberos
authentication.


%package plain
Summary: PLAIN and LOGIN support for Cyrus SASL.
Summary(ja): Cyrus SASL の PLAIN, LOGIN 認証サポート
Group: system
Requires: %{name} = %{version}-%{release}

%description plain
The %{name}-plain package contains the Cyrus SASL plugins which support
PLAIN and LOGIN authentication schemes.


%package md5
Summary: CRAM-MD5 and DIGEST-MD5 support for Cyrus SASL.
Summary(ja): Cyrus SASL の CRAM-MD5, DIGEST-MD5 認証サポート
Group: system
Requires: %{name} = %{version}-%{release}

%description md5
The %{name}-md5 package contains the Cyrus SASL plugins which support
CRAM-MD5 and DIGEST-MD5 authentication schemes.


%package ntlm
Summary: NTLM support for Cyrus SASL.
Summary(ja): Cyrus SASL の NTLM 認証サポート
Group: system
Requires: %{name} = %{version}-%{release}

%description ntlm
The %{name}-ntlm package contains the Cyrus SASL plugin which supports
the NTLM authentication schemes.


# This would more appropriately be named cyrus-sasl-auxprop-sql.
%package sql
Summary: SQL auxprop support for Cyrus SASL
Summary(ja): Cyrus SASL の SQL auxprop サポート
Group: system
Requires: %{name} = %{version}-%{release}

%description sql
The %{name}-sql package contains the Cyrus SASL plugin which supports
using a RDBMS for storing shared secrets.


# This was *almost* named cyrus-sasl-auxprop-ldapdb, but that's a lot of typing.
%package ldap
Summary: LDAP auxprop support for Cyrus SASL
Summary(ja): Cyrus SASL の LDAP auxprop サポート
Group: system
Requires: %{name} = %{version}-%{release}

%description ldap
The %{name}-ldap package contains the Cyrus SASL plugin which supports using
a directory server, accessed using LDAP, for storing shared secrets.


%package scram
Summary: SCRAM auxprop support for Cyrus SASL
Summary(ja): Cyrus SASL の SCRAM auxprop サポート
Group: system
Requires: %{name} = %{version}-%{release}

%description scram
The %{name}-scram package contains the Cyrus SASL plugin which supports
the SCRAM authentication scheme.


%package gs2
Summary: GS2 support for Cyrus SASL
Summary(ja): Cyrus SASL の GS2 認証サポート
Group: system
Requires: %{name} = %{version}-%{release}

%description gs2
The %{name}-gs2 package contains the Cyrus SASL plugin which supports
the GS2 authentication scheme.


## to build compat32 for x86_64 architecture support
%package -n compat32-%{name}
Summary: The Cyrus SASL library.
Summary(ja): Cyrus SASL ライブラリ
Group: system,legacy

%description -n compat32-%{name}
The %{name} package contains the Cyrus implementation of SASL.
SASL is the Simple Authentication and Security Layer, a method for
adding authentication support to connection-based protocols.


%package -n compat32-%{name}-devel
Summary: Files needed for developing applications with Cyrus SASL.
Summary(ja): Cyrus SASL を用いるアプリケーションの開発に必要なファイル
Group: programming,legacy
Requires: compat32-%{name} = %{version}-%{release}

%description -n compat32-%{name}-devel
The %{name}-devel package contains files needed for developing and
compiling applications which use the Cyrus SASL library.


%package -n compat32-%{name}-gssapi
Summary: GSSAPI support for Cyrus SASL.
Summary(ja): Cyrus SASL の GSSAPI 認証サポート
Group: system,legacy
Requires: compat32-%{name} = %{version}-%{release}

%description -n compat32-%{name}-gssapi
The %{name}-gssapi package contains the Cyrus SASL plugins which
support GSSAPI authentication. GSSAPI is commonly used for Kerberos
authentication.


%package -n compat32-%{name}-plain
Summary: PLAIN and LOGIN support for Cyrus SASL.
Summary(ja): Cyrus SASL の PLAIN, LOGIN 認証サポート
Group: system,legacy
Requires: compat32-%{name} = %{version}-%{release}

%description -n compat32-%{name}-plain
The %{name}-plain package contains the Cyrus SASL plugins which support
PLAIN and LOGIN authentication schemes.


%package -n compat32-%{name}-md5
Summary: CRAM-MD5 and DIGEST-MD5 support for Cyrus SASL.
Summary(ja): Cyrus SASL の CRAM-MD5, DIGEST-MD5 認証サポート
Group: system,legacy
Requires: compat32-%{name} = %{version}-%{release}

%description -n compat32-%{name}-md5
The %{name}-md5 package contains the Cyrus SASL plugins which support
CRAM-MD5 and DIGEST-MD5 authentication schemes.


%package -n compat32-%{name}-ntlm
Summary: NTLM support for Cyrus SASL.
Summary(ja): Cyrus SASL の NTLM 認証サポート
Group: system,legacy
Requires: compat32-%{name} = %{version}-%{release}

%description -n compat32-%{name}-ntlm
The %{name}-ntlm package contains the Cyrus SASL plugin which supports
the NTLM authentication schemes.


# %package -n compat32-%{name}-sql
# Group: System Environment/Libraries
# Summary: SQL auxprop support for Cyrus SASL

# %description -n compat32-%{name}-sql
# The %{name}-sql package contains the Cyrus SASL plugin which supports
# using a RDBMS for storing shared secrets.


%package -n compat32-%{name}-ldap
Summary: LDAP auxprop support for Cyrus SASL
Summary(ja): Cyrus SASL の LDAP auxprop サポート
Group: system,legacy
Requires: compat32-%{name} = %{version}-%{release}

%description -n compat32-%{name}-ldap
The %{name}-ldap package contains the Cyrus SASL plugin which supports using
a directory server, accessed using LDAP, for storing shared secrets.


%package -n compat32-%{name}-scram
Summary: SCRAM auxprop support for Cyrus SASL
Summary(ja): Cyrus SASL の SCRAM auxprop サポート
Group: system,legacy
Requires: compat32-%{name} = %{version}-%{release}

%description -n compat32-%{name}-scram
The %{name}-scram package contains the Cyrus SASL plugin which supports
the SCRAM authentication scheme.


%package -n compat32-%{name}-gs2
Summary: GS2 support for Cyrus SASL
Summary(ja): Cyrus SASL の GS2 認証サポート
Group: system,legacy
Requires: compat32-%{name} = %{version}-%{release}

%description -n compat32-%{name}-gs2
The %{name}-gs2 package contains the Cyrus SASL plugin which supports
the GS2 authentication scheme.


%debug_package


%prep
%setup -q
chmod -x doc/legacy/*.html
chmod -x include/*.h
%patch11 -p1 -b .no_rpath
%if %{with systemd}
%patch15 -p1 -b .path
%else
sed -i -e 's|/usr/local/etc|/etc|g' saslauthd/saslauthd.mdoc
%endif
%patch23 -p1 -b .man
%patch24 -p1 -b .sizes
%patch49 -p1 -b .md5global.h
%patch101 -p1 -b .tests
%patch102 -p1 -b .gssapi_cbs
%patch106 -p1 -b .nostrncpy
%patch107 -p1 -b .moretests
%patch108 -p1 -b .maxssf0
%patch109 -p1 -b .frombdb
%patch500 -p1 -b .coverity
%patch501 -p1 -b .digestmd5
%patch502 -p1 -b .ossl3


%build
# reconfigure
cp %{SOURCE11} ./
rm configure aclocal.m4 config/ltmain.sh Makefile.in
export NOCONFIGURE=yes
sh autogen.sh

# Find Kerberos.
krb5_prefix=`krb5-config --prefix`
if test x$krb5_prefix = x%{_prefix} ; then
        krb5_prefix=
else
        CPPFLAGS="-I${krb5_prefix}/include $CPPFLAGS"; export CPPFLAGS
        LDFLAGS="-L${krb5_prefix}/%{_lib} $LDFLAGS"; export LDFLAGS
fi

# Find OpenSSL.
LIBS="-lcrypt"; export LIBS
if pkg-config openssl ; then
        CPPFLAGS="`pkg-config --cflags-only-I openssl` $CPPFLAGS"; export CPPFLAGS
        LDFLAGS="`pkg-config --libs-only-L openssl` $LDFLAGS"; export LDFLAGS
fi

# Find the MySQL libraries used needed by the SQL auxprop plugin.
INC_DIR="`mysql_config --include`"
if test x"$INC_DIR" != "x-I%{_includedir}"; then
        CPPFLAGS="$INC_DIR $CPPFLAGS"; export CPPFLAGS
fi
LIB_DIR="`mysql_config --libs | sed -e 's,-[^L][^ ]*,,g' -e 's,^ *,,' -e 's, *$,,' -e 's,  *, ,g'`"
if test x"$LIB_DIR" != "x-L%{_libdir}"; then
        LDFLAGS="$LIB_DIR $LDFLAGS"; export LDFLAGS
fi

# Find the PostgreSQL libraries used needed by the SQL auxprop plugin.
INC_DIR="-I`pg_config --includedir`"
if test x"$INC_DIR" != "x-I%{_includedir}"; then
        CPPFLAGS="$INC_DIR $CPPFLAGS"; export CPPFLAGS
fi
LIB_DIR="-L`pg_config --libdir`"
if test x"$LIB_DIR" != "x-L%{_libdir}"; then
        LDFLAGS="$LIB_DIR $LDFLAGS"; export LDFLAGS
fi

CFLAGS="$RPM_OPT_FLAGS $CFLAGS $CPPFLAGS -fPIC -pie -Wl,-z,relro -Wl,-z,now"; export CFLAGS

echo "$CFLAGS"
echo "$CPPFLAGS"
echo "$LDFLAGS"

%configure \
	--disable-static --enable-shared --disable-java \
	--with-plugindir=%{_plugindir2} \
	--with-configdir=%{_plugindir2}:%{_sysconfdir}/sasl2 \
	--disable-krb4 \
	--with-rc4 \
	--with-dblib=berkeley \
        --with-bdb=db \
	--with-saslauthd=%{homedir} --without-pwcheck \
	--with-ldap \
	--with-devrandom=/dev/urandom \
	--enable-anon \
	--enable-cram \
	--enable-digest \
	--enable-ntlm \
	--enable-plain \
	--enable-login \
        --disable-otp \
        --enable-ldapdb \
        --enable-sql --with-mysql=%{_prefix} --with-pgsql=%{_prefix} \
        --without-sqlite \
        "$@"
	# --enable-auth-sasldb -- EXPERIMENTAL
make %{?_smp_mflags} sasldir=%{_plugindir2}
make %{?_smp_mflags} -C saslauthd testsaslauthd
make -C sample

%install
test "$RPM_BUILD_ROOT" != "/" && rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT sasldir=%{_plugindir2}
make install DESTDIR=$RPM_BUILD_ROOT sasldir=%{_plugindir2} -C plugins

install -m755 -d $RPM_BUILD_ROOT%{_bindir}
./libtool --tag=CC --mode=install \
install -m755 sample/client $RPM_BUILD_ROOT%{_bindir}/sasl2-sample-client
./libtool --tag=CC --mode=install \
install -m755 sample/server $RPM_BUILD_ROOT%{_bindir}/sasl2-sample-server
./libtool --tag=CC --mode=install \
install -m755 saslauthd/testsaslauthd $RPM_BUILD_ROOT%{_sbindir}/testsaslauthd
./libtool --tag=CC --mode=install \
install -m755 utils/dbconverter-2 $RPM_BUILD_ROOT%{_sbindir}/dbconverter-2

# Install the saslauthd mdoc page in the expected location.  Sure, it's not
# really a man page, but groff seems to be able to cope with it.
install -m755 -d $RPM_BUILD_ROOT%{_mandir}/man8/
install -m644 saslauthd/saslauthd.mdoc $RPM_BUILD_ROOT%{_mandir}/man8/saslauthd.8

install -Dpm644 %{SOURCE9} $RPM_BUILD_ROOT/etc/sysconfig/saslauthd
%if %{with systemd}
install -Dpm644 %{SOURCE10} $RPM_BUILD_ROOT/%{_unitdir}/saslauthd.service
sed -i -e 's|/var/run|/run|g' $RPM_BUILD_ROOT/etc/sysconfig/saslauthd
%else
# Install the init script for saslauthd
install -m755 -d $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m755 -p %{SOURCE4} $RPM_BUILD_ROOT/etc/rc.d/init.d/saslauthd
# Create the saslauthd listening directory.
install -m755 -d $RPM_BUILD_ROOT/var/run/saslauthd
%endif

# Install the config dirs if they're not already there.
install -m755 -d $RPM_BUILD_ROOT/%{_sysconfdir}/sasl2
install -m755 -d $RPM_BUILD_ROOT/%{_plugindir2}

# Remove unpackaged files from the buildroot.
rm -f $RPM_BUILD_ROOT%{_libdir}/sasl2/libotp.*
rm -f $RPM_BUILD_ROOT%{_libdir}/sasl2/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/sasl2/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_mandir}/cat8/saslauthd.8


%clean
test "$RPM_BUILD_ROOT" != "/" && rm -rf $RPM_BUILD_ROOT


%if %{with systemd}
%pre
getent group %{username} >/dev/null || groupadd -g 76 -r %{username}
getent passwd %{username} >/dev/null || useradd -r -g %{username} -d %{homedir} -s /sbin/nologin -c "Saslauthd user" %{username}
%endif

%post
%if %{with systemd}
if [ -e %{_initdir}/saslauthd ]; then
  /bin/systemctl --no-reload preset saslauthd.service || :
fi
%systemd_post saslauthd.service
%else
/sbin/chkconfig --add saslauthd
%endif

%preun
%if %{with systemd}
%systemd_preun saslauthd.service
%else
if [ $1 = 0 -o -x /bin/systemctl ] ; then
	/sbin/service saslauthd stop 2>&1 > /dev/null ||:
	/sbin/chkconfig --del saslauthd
fi
exit 0
%endif

%postun
%if %{with systemd}
%systemd_postun_with_restart saslauthd.service
%else
if [ $1 != 0 ] ; then
	/sbin/service saslauthd condrestart 2>&1 > /dev/null ||:
fi
exit 0
%endif


%files
%defattr(-,root,root)
%license COPYING
%doc AUTHORS README doc/legacy/*.html
%doc $RPM_SOURCE_DIR/README.RPM
%dir %{_sysconfdir}/sasl2
%{_libdir}/libsasl*.so.*
%dir %{_plugindir2}/
%{_plugindir2}/*anonymous*.so*
%{_plugindir2}/*sasldb*.so*
%{_mandir}/man8/*
%{_sbindir}/cyrusbdb2current
%{_sbindir}/dbconverter-2
%{_sbindir}/saslpasswd2
%{_sbindir}/sasldblistusers2
%{_sbindir}/pluginviewer
%{_sbindir}/saslauthd
%{_sbindir}/testsaslauthd
%config(noreplace) /etc/sysconfig/saslauthd
%if %{with systemd}
%{_unitdir}/saslauthd.service
%ghost /run/saslauthd
%else
%config /etc/rc.d/init.d/saslauthd
/var/run/saslauthd
%endif

%files gssapi
%defattr(-,root,root)
%{_plugindir2}/*gssapi*.so*

%files plain
%defattr(-,root,root)
%{_plugindir2}/*plain*.so*
%{_plugindir2}/*login*.so*

%files md5
%defattr(-,root,root)
%{_plugindir2}/*crammd5*.so*
%{_plugindir2}/*digestmd5*.so*

%files ntlm
%defattr(-,root,root)
%{_plugindir2}/*ntlm*.so*

%files sql
%defattr(-,root,root)
%{_plugindir2}/*sql*.so*

%files ldap
%defattr(-,root,root)
%{_plugindir2}/*ldapdb*.so*

%files scram
%defattr(-,root,root)
%{_plugindir2}/libscram.so*

%files gs2
%defattr(-,root,root)
%{_plugindir2}/libgs2.so*

%files devel
%defattr(-,root,root)
%{_bindir}/sasl2-sample-client
%{_bindir}/sasl2-sample-server
%{_includedir}/*
%{_libdir}/libsasl*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*

## to build compat32 for x86_64 architecture support
%if %{build_compat32}
%files -n compat32-%{name}
%defattr(-,root,root)
%{_libdir}/libsasl*.so.*
%dir %{_plugindir2}/
%{_plugindir2}/*anonymous*.so*
%{_plugindir2}/*sasldb*.so*

%files -n compat32-%{name}-gssapi
%defattr(-,root,root)
%{_plugindir2}/*gssapi*.so*

%files -n compat32-%{name}-plain
%defattr(-,root,root)
%{_plugindir2}/*plain*.so*
%{_plugindir2}/*login*.so*

%files -n compat32-%{name}-md5
%defattr(-,root,root)
%{_plugindir2}/*crammd5*.so*
%{_plugindir2}/*digestmd5*.so*

%files -n compat32-%{name}-ntlm
%defattr(-,root,root)
%{_plugindir2}/*ntlm*.so*

# %files -n compat32-%{name}-sql
# %defattr(-,root,root)
# %{_plugindir2}/*sql*.so*

%files -n compat32-%{name}-ldap
%defattr(-,root,root)
%{_plugindir2}/*ldapdb*.so*

%files -n compat32-%{name}-scram
%defattr(-,root,root)
%{_plugindir2}/libscram.so*

%files -n compat32-%{name}-gs2
%defattr(-,root,root)
%{_plugindir2}/libgs2.so*

%files -n compat32-%{name}-devel
%defattr(-,root,root)
%{_libdir}/libsasl*.so
%endif


%changelog
* Tue Mar 01 2022 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.28-1
- new upstream release.
- re-imported patches from rawhide.

* Tue Oct 05 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.27-3
- rebuilt with openssl-3.0.0.
- dropped ldconfig scriptlets.
- dropped Patch102 and 1000.
- imported Patch60-500 from rawhide.

* Wed May 27 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.27-2
- added systemd support (disabled as default).

* Mon May 13 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.27-1
- new upstream release.
- updated Patch11, 15, 21, 49 and 102.
- dropped Patch44-48, 50-60 and 200.
- added BR:libxcrypt-devel.

* Tue Nov 06 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.26-7
- rebuilt with openssl-1.1.1.
- added Patch54-60.

* Wed Nov 02 2016 Toshiaki Ara <ara_t@384.jp> 2.1.26-6
- fix [BTS:0003006]
  - correct saslauthd.sysconfig

* Mon Mar 21 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.26-5
- rebuilt with openssl-1.0.2g.

* Sun Dec 14 2014 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 2.1.26-4
- built with libdb 5.3.28
- dropt Patch10
- added Patch44, 45, 49, 50, 52 and 53
- fixed typo of Require of compat32-cyrus-sasl-{scram, gs2}
- fixed %%doc of cyrus-sasl and cyrus-sasl-devel
- added Japanese summary

* Sun Jul 20 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.1.26-3
- rebuild with VineSeed environment
- change BuildRequires: libmysqlclient-devel instead of MySQL-devel
- change BuildRequires: libpq-devel instead of postgresql-devel

* Sat Feb 08 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.1.26-2
- add Patch46 (cyrus-sasl-2.1.26-size_t.patch) from fedora

* Thu Jan  9 2014 IWAI, Masaharu <iwaim.sub@gmail.com> 2.1.26-1
- update to 2.1.26
 - drop sig file (Source1): upstream isn't release.
- add cyrus-sasl-scram and cyrus-sasl-gs2 packages
- add pkgconfig file in cyrus-sasl-devel package
- fix License
- update URL
- update %%doc
- drop SASLv1
 - drop Source2,3
 - drop Patch0-5 for SASLv1 patches
- update patch from RHEL7 beta cyrus-sasl-2.1.26-12.1.el7
 - no rpath patch (Patch11)
 - keytab patch (Patch28)
 - db4 patch (Patch100)
 - gcc44 patch (Patch101)
- update CVE-2013-4122 patch (Patch200) from Gentoo Linux
- update configure patch (Patch102)
- drop unnecessary patch
 - automake 1.10 patch (Patch27)
 - upstream fixed
  - typo patch (Patch25)
  - digest commas patch (Patch26)

* Mon Sep 16 2013 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.1.23-11
- add patch200 for fix CVE-2013-4122 (NULL ptr. dereference)

* Mon Aug 22 2011 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.1.23-10
- add Vendor/Distri Tags

* Mon Aug 22 2011 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.23-9
- fixed pam support.
- fixed MySQL support.

* Tue Apr 12 2011 Shu KONNO <owa@bg.wakwak.com> 2.1.23-8
- rebuilt with postgresql-9.0.3

* Tue Mar 22 2011 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.1.23-7
- rebuild with krb5-libs-1.8.2 and openssl-1.0.0d

* Tue Jan 11 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.1.23-6
- rebuild with openssl-1.0.0c
- add BuildRequires: groff

* Thu Feb 11 2010 NAKAMURA Kenta <kenta@vinelinux.org> 2.1.23-5
- rebuilt with db4-4.8
- updated Patch100: cyrus-sasl-2.1.22-db4.patch
- added Patch101: cyrus-sasl-2.1.23-gcc44.patch

* Sun Jul 05 2009 Munehiro Yamamoto <munepi@cg8.so-net.ne.jp> 2.1.23-4
- dropped compat32-%%{name}-sql

* Sat Jul 04 2009 Munehiro Yamamoto <munepi@cg8.so-net.ne.jp> 2.1.23-3
- added compat32 subpackages

* Fri May 22 2009 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.23-2
- rebuilt with MySQL-5.1.34.

* Mon May 18 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 2.1.23-1
- new upstream release with security fix (CVE-2009-0688)
- add patch5 to fix CVE-2009-0688 issue in 1.5.28 side
  (No effect in Current VineSeed package)

* Sun Jan 04 2009 NAKAMURA Kenta <kenta@vinelinux.org> 2.1.22-5
- rebuilt with openldap-2.4.11

* Sun Oct 12 2008 Shu KONNO <owa@bg.wakwak.com> 2.1.22-4
- s/%%{name}-lib/%%{name}/ at requires of sql, ldap sub-packages

* Sun Oct  5 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> - 2.1.22-3
- added gssapi subpackage

* Fri Jun 20 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.1.22-2
- rebuilt against db-4.6.21 with Patch100
- import Patch27 from Fedora

* Sat Apr 19 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.1.22-1vl5
- updated to 2.1.22
- added Patches from Fedora
  * Tue Jun 20 2006 Nalin Dahyabhai <nalin@redhat.com> 2.1.22-2
  - fix a typo in sasl_client_start(3) (#196066)
  * Thu Apr 27 2006 Nalin Dahyabhai <nalin@redhat.com> 2.1.21-11
  - add unapplied patch which makes the DIGEST-MD5 plugin omit the realm
    argument when the environment has $CYRUS_SASL_DIGEST_MD5_OMIT_REALM set 
    to a non-zero value, for testing purposes
- added subpackages for the ldapdb auxprop support
- added --disable-static option to %%configure

* Tue May 22 2007 NAKAMURA Kenta <kenta@vinelinux.org> 2.1.18-0vl8
- added Patch17: cyrus-sasl-2.1.18-openssl-098.patch
- rebuilt with openssl-0.9.8

* Thu May 10 2007 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.1.18-0vl7
- disable version 1 now (no VineSeed package require version 1)
- enable ntlm subpackage now
- rebuilt with new toolchain and db4-4.3.x

* Sat Jul  1 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 2.1.18-0vl6
- rebuilt for VineSeed

* Fri Apr 28 2006 IWAI, Masaharu <iwai@alib.jp> 2.1.18-0vl5
- SECURITY FIX for Vine 3.2: CVE-2006-1721
   - add 23_CVE-2006-1721.diff ( Patch16 )
       from Debian Sarge cyrus-sasl2_2.1.19-1.5sarge1.diff.gz

* Mon Dec 26 2005 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 2.1.18-0vl4
- rebuild for VineSeed

* Sat Nov 27 2004 IKEDA Katsumi <ikeda@webmasters.gr.jp> 2.1.18-0vl3
- added security patch cyrus-sasl-CAN-2004-0884.patch for CAN-2004-0884
  from Mandrakelinux.

* Mon Oct 11 2004 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 2.1.18-0vl2
- rebuilt with db4-4.2.52

* Thu Aug 19 2004 Daisuke SUZUKI <daisuke@linux.or.jp> 2.1.18-0vl1
- new upstream release
- rebuild with openssl-0.9.7d
- import some patch from fedora package

* Sun Nov 23 2003 Daisuke SUZUKI <daisuke@linux.or.jp> 2.1.15-6vl1
- new upstream release
- remove prereq initscripts
- merged with fedora package
  * Thu Oct 23 2003 Nalin Dahyabhai <nalin@redhat.com> 2.1.15-6
  - use /dev/urandom instead of /dev/random for SASL2 (docs indicate that this is
  safe if you aren't using OTP or SRP, and we build neither); SASL1 appears to
  use it to seed the libc RNG only (#103378)
  * Mon Oct 20 2003 Nalin Dahyabhai <nalin@redhat.com>
  - obey RPM_OPT_FLAGS again when krb5_prefix != %%{_prefix}
  * Fri Oct 17 2003 Nalin Dahyabhai <nalin@redhat.com> 2.1.15-5
  - install saslauthd's mdoc page instead of the pre-formatted man page, which
    would get formatted again
  * Mon Sep 15 2003 Nalin Dahyabhai <nalin@redhat.com>
  - include testsaslauthd
  - note in the README that the saslauthd protocol is different for v1 and v2,
    so v1's clients can't talk to the v2 server
  * Thu Aug 21 2003 Nalin Dahyabhai <nalin@redhat.com> 2.1.15-3
  - add logic to build with gssapi libs in either /usr or /usr/kerberos
  * Tue Jul 15 2003 Nalin Dahyabhai <nalin@redhat.com> 2.1.15-1
  - update to 2.1.15
  * Mon Jul 14 2003 Nalin Dahyabhai <nalin@redhat.com> 2.1.14-1
  - update to 2.1.14

* Wed May 14 2003 Satoshi MACHINO <machino@vinelinux.org> 2.1.13-3vl1
- new upstream version
- merged with rawhide version
	-- * Fri May  9 2003 Nalin Dahyabhai <nalin@redhat.com> 2.1.13-3
	-- - change -m argument to saslauthd to be a directory instead of a path
	-- * Thu May  8 2003 Nalin Dahyabhai <nalin@redhat.com> 2.1.13-2
	-- - link libsasl2 with -lpthread to ensure that the sasldb plug-in
	     can always be loaded
	-- * Tue Apr 29 2003 Nalin Dahyabhai <nalin@redhat.com> 2.1.13-1
	-- - update to 2.1.13
- disable gssapi because Vine Linux don't support Kerberos

* Sun Dec  9 2001 IWAI Masaharu <iwaim@cc.mbn.or.jp> 1.5.27-17vl1
- upstream release
- obsoleted cyrus-sasl-1.5.21-des.patch ( upstream merged )
- obsoleted cyrus-sasl-1.5.24-external.patch ( upstream merged )
- added BuildPrereq: gdbm-devel, pam-devel

* Mon Jul 16 2001 MATSUBAYASHI 'Shaolin' Kohji <shaolin@vinelinux.org>
- 1.5.24-17vl2
- rebuilt with openssl-0.9.6b

* Wed Apr 11 2001 Satoshi MACHINO <machino@vinelinux.org> 1.5.24-17vl1
- merged Rawhide Package

* Sat Nov 18 2000 MACHINO, Satoshi <machino@vinelinux.org> 1.5.24-14vl1
- build for Vine Linux
- build with gcc-2.95.3
- removed kerberos and gssapi

* Fri Oct 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- enable static libraries, but always build with -fPIC

* Wed Oct 25 2000 Nalin Dahyabhai <nalin@redhat.com>
- make sure the version of 1.5.24 in the package matches the masters (#18968)

* Mon Oct  9 2000 Nalin Dahyabhai <nalin@redhat.com>
- re-add the libsasl.so symlink to the -devel package (oops)

* Fri Oct  6 2000 Nalin Dahyabhai <nalin@redhat.com>
- move .so files for modules to their respective packages -- they're not -devel
  links meant for use by ld anyway

* Thu Oct  5 2000 Nalin Dahyabhai <nalin@redhat.com>
- split off -devel subpackage
- add a -gssapi subpackage for the gssapi plugins

* Wed Aug 16 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix the summary text

* Sun Aug 13 2000 Nalin Dahyabhai <nalin@redhat.com>
- re-enable arcfour and CRAM

* Fri Aug  4 2000 Nalin Dahyabhai <nalin@redhat.com>
- force use of gdbm for database files to avoid DB migration weirdness
- enable login mechanism
- disable gssapi until it can coexist peacefully with non-gssapi setups
- actually do a make in the build section (#15410)

* Fri Jul 21 2000 Nalin Dahyabhai <nalin@redhat.com>
- update to 1.5.24

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Tue Jun 27 2000 Nalin Dahyabhai <nalin@redhat.com>
- rebuild in new environment (release 3)

* Mon Jun 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- don't muck with syslogd in post
- remove patch for db-3.0 wackiness, no longer needed

* Thu Jun  8 2000 Nalin Dahyabhai <nalin@redhat.com>
- FHS cleanup
- don't strip anything by default

* Fri Feb 11 2000 Tim Powers <timp@redhat.com>
- fixed man pages not being gzipped

* Tue Nov 16 1999 Tim Powers <timp@redhat.com>
- incorporated changes from Mads Kiilerich
- release number is 1, not mk1

* Wed Nov 10 1999 Mads Kiilerich <mads@kiilerich.com>
- updated to sasl 1.5.11
- configure --disable-krb4 --without-rc4 --disable-cram 
  because of missing libraries and pine having cram as default...
- handle changing libsasl.so versions

* Mon Aug 30 1999 Tim Powers <timp@redhat.com>
- changed group

* Fri Aug 13 1999 Tim Powers <timp@redhat.com>
- first build for Powertools
