%bcond_with systemd

# Basic Information
Name:		dconf
Summary:	dconf is a low-level configuration system.
Summary(ja):	dconfは、低レベル設定システムです。
Version:	0.40.0
Release:	1%{?_dist_release}%{?with_systemd:.systemd}
Group:		system
Vendor:		Project Vine
Distribution:	Vine Linux
Packager:	yasumichi

License:	LGPL
%global         shortver %(echo %{version} | cut -d . -f 1-2)
Source0:        https://download.gnome.org/sources/%{name}/%{shortver}/%{name}-%{version}.tar.xz
BuildRoot:	%{_tmppath}/%{name}-%{version}-root

# Dependency
Requires:	dbus

BuildRequires:	meson, ninja
BuildRequires:	glib2-devel
BuildRequires:	libxml2-devel
BuildRequires:	dbus-devel
BuildRequires:	libxslt-devel
BuildRequires:	vala
BuildRequires:	docbook-style-xsl
BuildRequires:	bash-completion
BuildRequires:	gtk-doc

%description
dconf is a low-level configuration system. Its main purpose is to provide
a backend to GSettings on platforms that don't already have configuration
storage systems. 

%description -l ja
dconfは、低レベル設定システムです。その主要な目的は、まだ設定保存システムを
有していないプラットフォーム上にGSettingsのバックエンドを提供することです。


%package	devel
Summary:	Headers for developing programs that will use %{name}
Summary(ja):	%{name} の開発用ファイル
Group:		programming
Requires:	%{name} = %{version}-%{release}
Requires:	glib2-devel
Requires:	libxml2-devel
Requires:	dbus-devel

%description devel
This package contains the headers that programmers will need to develop
applications which will use %{name}.


%package	docs
Summary:	Documentation for %{name}
Summary(ja):	%{name} 用のドキュメント
Group:		documentation
BuildArch:	noarch

%description  docs
This package contains documentation for %{name}.


%package	vala
Summary:	Vala bindings for %{name}
Summary(ja):	%{name} の Vala バインディング
Group:		programming
Requires:	%{name} = %{version}-%{release}
Requires:	vala

%description  vala
Vala bindings for %{name}.


%debug_package


%prep
%setup -q


%build
%meson -Dgtk_doc=true
%meson_build


%install
%{__rm} -rf %{buildroot}
%meson_install
%if ! %{with systemd}
rm -rf %{buildroot}/usr/lib/systemd
%endif

mkdir -p %{buildroot}%{_sysconfdir}/dconf/profile
cat << EOF > %{buildroot}%{_sysconfdir}/dconf/profile/user
user-db:user
system-db:local
system-db:site
system-db:distro
EOF

mkdir -p %{buildroot}%{_sysconfdir}/dconf/db/local.d/locks
mkdir -p %{buildroot}%{_sysconfdir}/dconf/db/site.d/locks
mkdir -p %{buildroot}%{_sysconfdir}/dconf/db/distro.d/locks


%clean
%{__rm} -rf %{buildroot}


%posttrans
dconf update ||:
exit 0

%if %{with systemd}
%post
%systemd_user_post dconf.service

%preun
%systemd_user_preun dconf.service

%postun
%systemd_user_postun_with_restart dconf.service
%endif


%files
%defattr(-,root,root,-)
%license COPYING
%doc NEWS
%dir %{_sysconfdir}/dconf
%dir %{_sysconfdir}/dconf/db
%dir %{_sysconfdir}/dconf/db/local.d
%dir %{_sysconfdir}/dconf/db/local.d/locks
%dir %{_sysconfdir}/dconf/db/site.d
%dir %{_sysconfdir}/dconf/db/site.d/locks
%dir %{_sysconfdir}/dconf/db/distro.d
%dir %{_sysconfdir}/dconf/db/distro.d/locks
%dir %{_sysconfdir}/dconf/profile
%config(noreplace) %{_sysconfdir}/dconf/profile/user
%{_bindir}/dconf
%{_libdir}/gio/modules/libdconfsettings.so
%{_libdir}/libdconf*.so.*
%{_libexecdir}/dconf-service
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/dconf
%{_datadir}/dbus-1/services/ca.desrt.dconf.service
%{_mandir}/man1/dconf.1.gz
%{_mandir}/man1/dconf-service.1.gz
%{_mandir}/man7/dconf.7.gz
%if %{with systemd}
%{_userunitdir}/*
%endif

%files devel
%defattr(-,root,root,-)
%{_includedir}/dconf/
%{_libdir}/libdconf*.so
%{_libdir}/pkgconfig/*.pc

%files docs
%defattr(-,root,root,-)
%{_datadir}/gtk-doc/html/dconf/

%files vala
%defattr(-,root,root,-)
%{_datadir}/vala/vapi/dconf.deps
%{_datadir}/vala/vapi/dconf.vapi


%changelog
* Wed Apr 07 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.40.0-1
- new upstream release.
- dropped ldconfig scriptlets.
- added /etc/dconf structures.

* Wed Mar 18 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.36.0-1
- new upstream release.

* Sun Jul 17 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.26.0-1
- new upstream release

* Sun Mar 29 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.24.0-1
- new upstream release
- remove dconf-editor subpackage
- create %%{name}-docs,vala subpackages

* Sun Oct 26 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.22.0-1
- new upstream release

* Wed Jun 18 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 0.20.0-3
- move some post/postun scripts to dconf-editor:
  - glib-compile-schemas, gtk-update-icon-cache, update-desktop-database

* Mon Jun 16 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 0.20.0-2
- split dconf-editor to subpackage.
- drop libgee dependency(R,BR)
- remove unneeded dependency(Requires)

* Sat Mar 29 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.20.0-1
- new upstream release

* Sat Jan 04 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.18.0-2
- rebuild with VineSeed environment

* Sat Oct 26 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.18.0-1
- new upstream release

* Sun Aug 11 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.16.1-1
- new upstream release

* Sun Apr 21 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.16.0-1
- new upstream release
- add BuildRequires: vala

* Fri Nov 02 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.14.1-1
- new upstream release

* Sat Sep 29 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.14.0-1
- new upstream release
- add BuildRequires: libxslt-devel, docbook-style-xsl

* Sun May 06 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.12.1-1
- new upstream release

* Sun Apr 08 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.12.0-1
- new upstream release

* Thu Sep 29 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.10.0-1
- new upstream release

* Fri Sep 23 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.9.1-1
- new upstream release

* Mon Aug 15 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.8.0-1
- new upstream release
- add BuildRequires: dbus-devel
- change BuildRequires: gtk3-devel instead of gtk2-devel

* Sun Oct 17 2010 Yasumichi Akahoshi <yasumichi@vinelinux.org> 0.5.1-1
- new package. 

