%bcond_with systemd

Summary:        A modular geoinformation service
Summary(ja):    モジュール型地理情報サービス
Name:           geoclue2
Version:        2.5.7
Release:        1%{?_dist_release}%{?with_systemd:.systemd}
Group:          system
Vendor:         Project Vine
Distribution:   Vine Linux

License:        GPLv2+
URL:            https://www.freedesktop.org/wiki/Software/GeoClue/
Source0:        https://gitlab.freedesktop.org/geoclue/geoclue/-/archive/%{version}/geoclue-%{version}.tar.bz2

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: geocode-glib-devel
BuildRequires: json-glib-devel
BuildRequires: libsoup-devel
BuildRequires: ModemManager-glib-devel
BuildRequires: NetworkManager-libnm-devel
BuildRequires: gobject-introspection-devel
BuildRequires: avahi-glib-devel
BuildRequires: libnotify-devel
BuildRequires: vala
BuildRequires: gtk-doc
BuildRequires: itstool
BuildRequires: meson
%if %{with systemd}
%{?systemd_requires}
%endif

%description
Geoclue is a modular geoinformation service built on top of the D-Bus 
messaging system. The goal of the Geoclue project is to make creating 
location-aware applications as simple as possible. 

%package devel
Summary: Development package for geoclue
Summary(ja): geoclue の開発パッケージ
Group: programming
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
Files for development with geoclue.


%debug_package


%prep
%setup -q -n geoclue-%{version}


%build
%meson \
	-Ddbus-srv-user=geoclue \
	-Dgtk-doc=false \
	-Ddemo-agent=false \
%if %{with systemd}
	-Dsystemd-system-unit-dir=%{_unitdir} \
%endif
	%{nil}
%meson_build


%install
rm -rf $RPM_BUILD_ROOT
%meson_install
# Home directory for the 'geoclue' user
mkdir -p $RPM_BUILD_ROOT/var/lib/geoclue

%clean
rm -rf $RPM_BUILD_ROOT


%pre
# Update the home directory for existing users
getent passwd geoclue >/dev/null && \
    usermod -d /var/lib/geoclue geoclue &>/dev/null
# Create a new user and group if they don't exist
getent group geoclue >/dev/null || groupadd -r geoclue
getent passwd geoclue >/dev/null || \
    useradd -r -g geoclue -d /var/lib/geoclue -s /sbin/nologin \
    -c "User for geoclue" geoclue
exit 0


%if %{with systemd}
%post
%systemd_post geoclue.service

%preun
%systemd_preun geoclue.service

%postun
%systemd_postun_with_restart geoclue.service
%endif


%files
%defattr(-,root,root,-)
%license COPYING
%doc README.md
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.GeoClue2.Agent.conf
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.GeoClue2.conf
%{_sysconfdir}/geoclue/geoclue.conf
%{_libdir}/girepository-1.0/Geoclue-2.0.typelib
%{_libdir}/libgeoclue-2.so.*
%{_libexecdir}/geoclue
%{_libexecdir}/geoclue-2.0/demos/where-am-i
%{_datadir}/applications/geoclue-where-am-i.desktop
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.Agent.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.Client.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.Location.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.GeoClue2.Manager.xml
%{_datadir}/dbus-1/system-services/org.freedesktop.GeoClue2.service
%{_mandir}/man5/*
%attr(755,geoclue,geoclue) %dir /var/lib/geoclue
%if %{with systemd}
%{_unitdir}/*
%endif

%files devel
%defattr(-,root,root,-)
%{_includedir}/libgeoclue-2.0
%{_libdir}/libgeoclue-2.so
%{_libdir}/pkgconfig/geoclue-2.0.pc
%{_libdir}/pkgconfig/libgeoclue-2.0.pc
%{_datadir}/gir-1.0/Geoclue-2.0.gir
%{_datadir}/vala/vapi/libgeoclue-*.deps
%{_datadir}/vala/vapi/libgeoclue-*.vapi


%changelog
* Fri Apr 02 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.5.7-1
- new upstream release.

* Sun Aug 09 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.5.6-1
- new upstream release.

* Sat Sep 21 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.5.3-1
- new upstream release.
- enabled vala vapi.

* Sun Jul 17 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.4.3-1
- new upstream release
- add BuildRequires: gobject-introspection-devel, avahi-glib-devel

* Mon Apr 13 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.2.0-1
- new upstream release

* Sun Oct 26 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.1.10-1
- new upstream release

* Sun Mar 30 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.1.7-1
- new upstream release
- add BuildRequires: ModemManager-glib-devel, NetworkManager-glib-devel

* Sat Oct 26 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.0.0-1
- initial build

