%define libtoolize :

%define src_ver 0.21
%define so_ver 0.21
%define short_ver 0.21

Summary: GNU libraries and utilities for producing multi-lingual messages.
Summary(ja): マルチリンガルメッセージを生成するためのGNU ライブラリ/ユーティリティ
Name: gettext
Version: %{src_ver}
Release: 1%{?_dist_release}
Group: programming
Packager: daisuke
Vendor: Project Vine
Distribution: Vine Linux

License: GPLv3+ and LGPLv2+ and GFDL
Source: https://ftp.gnu.org/gnu/gettext/%{name}-%{version}.tar.xz
URL: http://www.gnu.org/software/gettext/
Source2: msghack.py
Source3: msghack.1

Patch1: gettext-msgmerge-for-msgfmt.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-root

BuildRequires: libtool, bison, gcc-c++
# following suggested by DEPENDENCIES:
BuildRequires: ncurses-devel
BuildRequires: libxml2-devel
BuildRequires: glib2-devel
BuildRequires: libacl-devel
BuildRequires: libunistring-devel
# ensure 'ARCHIVE_FORMAT=dirxz'
BuildRequires: xz

Requires(post): /sbin/install-info
Requires(preun): /sbin/install-info

%description
The GNU gettext package provides a set of tools and documentation for
producing multi-lingual messages in programs.  Tools include a set of
conventions about how programs should be written to support message
catalogs, a directory and file naming organization for the message
catalogs, a runtime library which supports the retrieval of translated
messages, and stand-alone programs for handling the translatable and
the already translated strings.  Gettext provides an easy to use
library and tools for creating, using, and modifying natural language
catalogs and is a powerful and simple method for internationalizing
programs.

%description -l ja
GNU gettext パッケージはプログラム中でマルチリンガルメッセージを生成する
ためのツールと文書を提供します. ツールはメッセージカタログをサポートするために
プログラムがどのように書かれるべきかの申し合わせと, メッセージカタログのための
ディレクトリとファイル名の組織化と, 翻訳されたメッセージの埋め合わせを
サポートするためのランタイムライブラリと, 翻訳可能でかつすでに翻訳された文字列
を取り扱う独立したプログラムを含みます. gettext は簡単に使えるライブラリ
と自然言語のカタログを生成, 使用, 修正するツールと, 国際化プログラム
のための強力かつシンプルな方法を提供します.


%package devel
Summary: Development files for gettext
Summary(ja): gettext 用開発ファイル
Group: programming
# autopoint is GPLv3+
# libasprintf is LGPLv2+
# libgettextpo is GPLv3+
License: LGPLv2+ and GPLv3+ and GFDL
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
Requires: xz
Requires: diffutils
Requires(post): /sbin/install-info
Requires(preun): /sbin/install-info

%description devel
This package contains all development related files necessary for
developing or compiling applications/libraries that needs
internationalization capability. You also need this package if you
want to add gettext support for your project.

%description devel -l ja
このパッケージには、マルチリンガル機能を持つアプリケーションや
ライブラリを開発・コンパイルするのに必要な開発関連ファイルが収録
されています。


%package libs
Summary: Libraries for gettext
Summary(ja): gettext 用共有ライブラリ
Group: system
# libasprintf is LGPLv2+
# libgettextpo is GPLv3+
License: LGPLv2+ and GPLv3+

%description libs
This package contains libraries used internationalization support.

%description libs -l ja
このパッケージには国際化サポートに必要な共有ライブラリが収録されています。


%prep
%setup -q

# Defeat libtextstyle attempt to bundle libxml2.  The comments
# indicate this is done because the libtextstyle authors do not want
# applications using their code to suffer startup delays due to the
# relocations.  This is not a sufficient reason for Fedora.
sed -e 's/\(gl_cv_libxml_force_included=\)yes/\1no/' \
    -i libtextstyle/configure


%build
## running autoreconf for automake-1.11.1
autoreconf -fi
[ -f  /usr/share/automake/depcomp ] && cp -f /usr/share/automake/{depcomp,ylwrap} . || :

# libxml2-devel package has an extra "libxml2" path component.
export CPPFLAGS="-I%{_includedir}/libxml2"
# Side effect of unbundling libxml2 from libtextstyle.
export LIBS="-lxml2"

%configure --without-included-gettext --enable-nls \
	--enable-shared --disable-static --disable-rpath \
	--with-pic=yes \
	--disable-csharp --disable-java \
    --with-xz

# Eliminate hardcoded rpaths; workaround libtool reordering -Wl,--as-needed
# after all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC=.g..|& -Wl,--as-needed|' \
    -i $(find . -name libtool)

make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT

# Fix busted no-emacs install for $lispdir/po-mode.el
%makeinstall lispdir=%{buildroot}/usr/share/emacs/site-lisp \
    aclocaldir=%{buildroot}/usr/share/aclocal

# delete po-mode
%{__rm} -rf %{buildroot}/usr/share/emacs/site-lisp

mkdir -p %{buildroot}/bin
mv %{buildroot}/%{_bindir}/gettext %{buildroot}/bin
ln -s ../../bin/gettext %{buildroot}/%{_bindir}/gettext
install -m 755 %{SOURCE2} $RPM_BUILD_ROOT/%{_bindir}/msghack
install -pm 644 %SOURCE3 ${RPM_BUILD_ROOT}/%{_mandir}/man1/msghack.1

pushd %{buildroot}
rm -f .%{_infodir}/dir .%{_includedir}/libintl.h
popd

%find_lang %{name}-runtime
%find_lang %{name}-tools
cat %{name}-*.lang > %{name}.lang

# remove unpackaged files from the buildroot
rm -rf $RPM_BUILD_ROOT/usr/share/doc
rm -f $RPM_BUILD_ROOT%{_libdir}/*.{a,la}
rm -f $RPM_BUILD_ROOT%{_datadir}/locale/locale.alias

%__rm -rf %{buildroot}%{_docdir}/%{name}


%clean
rm -rf $RPM_BUILD_ROOT


%post
/sbin/ldconfig
/sbin/install-info %{_infodir}/gettext.info.gz %{_infodir}/dir || :


%preun
if [ "$1" = 0 ]; then
    /sbin/install-info --delete %{_infodir}/gettext.info.gz %{_infodir}/dir || :
fi
exit 0

%postun -p /sbin/ldconfig


%post devel
/sbin/ldconfig
/sbin/install-info %{_infodir}/autosprintf.info %{_infodir}/dir || :
/sbin/install-info %{_infodir}/libtextstyle.info %{_infodir}/dir || :

%preun devel
if [ "$1" = 0 ]; then
    /sbin/install-info --delete %{_infodir}/autosprintf.info %{_infodir}/dir || :
    /sbin/install-info --delete %{_infodir}/libtextstyle.info %{_infodir}/dir || :
fi

%postun devel -p /sbin/ldconfig


%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig


%files -f gettext.lang
%defattr(-,root,root,-)
%license COPYING
%doc gettext-runtime/ABOUT-NLS AUTHORS gettext-runtime/BUGS 
%doc ChangeLog* gettext-tools/misc/DISCLAIM README
%doc NEWS THANKS 
%doc gettext-runtime/man/*.1.html
%doc gettext-runtime/intl/COPYING*
/bin/*
%{_bindir}/*
%{_libdir}/libgettextlib-%{so_ver}.so
%{_libdir}/libgettextsrc-%{so_ver}.so
%{_infodir}/gettext*
%{_mandir}/man1/*
%{_libdir}/gettext
%{_datadir}/gettext/archive.dir.tar.xz
%{_datadir}/gettext/styles
%{_datadir}/gettext-%{short_ver}

%files devel
%defattr(-,root,root,-)
%doc gettext-runtime/man/*.3.html ChangeLog
%{_datadir}/gettext/ABOUT-NLS
%{_datadir}/gettext/projects/
%{_datadir}/gettext/config.rpath
%{_datadir}/gettext/*.h
%{_datadir}/gettext/po
%{_datadir}/gettext/msgunfmt.tcl
%{_datadir}/aclocal/*
%{_includedir}/*
%{_infodir}/autosprintf*
%{_infodir}/libtextstyle*
%{_libdir}/libasprintf.so
%{_libdir}/libgettextpo.so
%{_libdir}/libgettextlib.so
%{_libdir}/libgettextsrc.so
%{_libdir}/libtextstyle.so
%{_libdir}/preloadable_libintl.so
%{_mandir}/man3/*
%{_datadir}/%{name}/javaversion.class
%doc gettext-runtime/intl-java/javadoc*


%files libs
%defattr(-,root,root,-)
%{_libdir}/libasprintf.so.*
%{_libdir}/libgettextpo.so.*
%{_libdir}/libtextstyle.so.*


%changelog
* Sun Sep 06 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 0.21-1
- new upstream release.
- updated Source2 and 3 for python3.
- dropped Patch1.

* Tue Sep 17 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 0.20.1-2
- moved libtextstyle.so.* to gettext-libs.

* Mon Sep 16 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 0.20.1-1
- new upstream release.
- imported Patch1 from rawhide.

* Thu Jun 30 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> - 0.19.8.1-2
- rebuild with gcc-5.4.0

* Wed Jun 15 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> - 0.19.8.1-1
- new upstream release

* Thu May 19 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> - 0.19.7-1
- new upstream release

* Sat Oct 31 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> - 0.19.6-1
- new upstream release

* Sun Nov  2 2014 Ryoichi INAGAKI <ryo1@toki.waseda.jp> - 0.18.3.2-2
- moved devel package to Development/Libraries Group

* Tue Jan 14 2014 NAKAMURA Kenta <kenta@vinelinux.org> - 0.18.3.2-1
- new upstream release

* Sun Jul 14 2013 Toshiharu Kudoh <toshi.kd2@gmail.com> - 0.18.3-1
- new upstream release

* Thu Mar 07 2013 Toshiharu Kudoh <toshi.kd2@gmail.com> - 0.18.2.1-1
- new upstream release

* Tue Nov  9 2010 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> - 0.18.1.1-1
- new upstream release 
- drop old patches
- update msghack.py from fc14
- add BRs: libacl-devel, libcroco-devel
- fix files list

* Wed Feb 24 2010 IWAI, Masaharu <iwai@alib.jp> - 0.17-5
- split to po-mode package: [VineSeed:20076]
- update Packager value: update format
- running autoreconf for automake-1.11.1 in %%build

* Tue Dec 22 2009 Munehiro Yamamoto <munepi@vinelinux.org> - 0.17-4
- correct some output messages on po-mode-install.sh
- use %%emacsen_pkgdir

* Sun May 10 2009 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 0.17-3
- we better not to use BuildConflicts very often :-P
  instead we pass --disable-java to configure here
- add --enable-shared --disable-static --without-included-gettext to configure
- remove .la files
- add -devel and --libs subpackages

* Wed May  6 2009 IWAI, Masaharu <iwai@alib.jp> 0.17-2
- apply vine-default
  - update po-mode-init.el (Source1)
  - update po-mode-install.sh (Source3)
  - update po-mode-remove.sh (Source4)
  - add vine-default-po-mode.el (Source5): based 0.17-1's po-mode-init.el
- update %%doc: gettext-runtime/libasprintf/autosprintf_all.html

* Sat Aug 23 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 0.17-1
- new upstream release

* Fri Aug 15 2008 Shu KONNO <owa@bg.wakwak.com> 0.16.1-1vl5
- applied new versioning policy, spec in utf-8

* Wed Jan 31 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 0.16.1-0vl2
- changelog update missing

* Tue Jan 30 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 0.16.1-0vl1
- new upstream release

* Tue Sep 12 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 0.14.5-0vl6
- changed po-mode Group to Appliations/Editors/Emacs <BTS:VineLinux:163>

* Mon Aug 21 2006 KAZUKI SHIMURA <kazuki@ma.ccnw.ne.jp> 0.14.5-0vl5
- add BuildConflicts: libgcj34-devel not to depend on libgcj34

* Fri Aug 18 2006 KAZUKI SHIMURA <kazuki@ma.ccnw.ne.jp> 0.14.5-0vl4
- add BuildConflicts: libgcj-devel not to depend on libgcj
- add BuildRequires: emacsen (if emacsen_pkg is enabled)
- remove unneeded files at the %%install

* Mon Aug 07 2006 NAKAMURA Kenta <kenta@vinelinux.org> 0.14.5-0vl3
- rebuilt without libgcj package

* Sat Aug 05 2006 NAKAMURA Kenta <kenta@vinelinux.org> 0.14.5-0vl2
- modified emacsen-common path

* Wed Jun 15 2005 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 0.14.5-0vl1
- new upstream release
- updated Source3
- added --disable-csharp 

* Wed Apr  7 2004 Daisuke SUZUKI <daisuke@linux.or.jp> 0.14.1-0vl2
- remove dependency to libgcj

* Wed Apr  7 2004 Daisuke SUZUKI <daisuke@linux.or.jp> 0.14.1-0vl1
- new upstream release

* Mon Sep 22 2003 IWAI, Masaharu <iwai@alib.jp> 0.12.1-1vl2
- build without libgcj package
- create po-mode package for Emacsen

* Sun Sep 21 2003 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 0.12.1-1vl1
- based on Redhat Rawhide 0.12.1-1
- dropped all patches (Rawhide does so)
- Source100(ja.po) is much older than source, dropped
- s/Copyright/License/

* Sun Sep 29 2002 Daisuke SUZUKI <daisuke@linux.or.jp> 0.11.5-0vl1
- new upstream release

* Mon Jun 10 2002 KOBAYASHI R. Taizo <tkoba@vinelinux.org>
- sync with rawhide 0.11.2-2 and Mandrake 0.11.2-4mdk

* Wed Jun  7 2000 Yasuyuki Furukawa <furukawa@vinelinux.org>
- sync with RH6.2

* Fri Apr 28 2000 Bill Nottingham <notting@redhat.com>
- minor configure tweaks for ia64

* Sun Feb 27 2000 Cristian Gafton <gafton@redhat.com>
- add --comments to msghack

* Thu Feb 10 2000 Cristian Gafton <gafton@redhat.com>
- fix bug #9240 - gettextize has the right aclocal patch

* Wed Jan 12 2000 Cristian Gafton <gafton@redhat.com>
- add the --diff and --dummy options

* Wed Oct 06 1999 Cristian Gafton <gafton@redhat.com>
- add the --missing option to msghack

* Wed Sep 22 1999 Cristian Gafton <gafton@redhat.com>
- updated msghack not to merge in fuzzies in the master catalogs

* Sat Sep 18 1999 Norihito Ohmori <ohmori@flatout.org>
- update ja.po

* Tue Sep 14 1999 Jun Nishii <jun@flatout.org>
- use message.c.diff-2

* Thu Aug 26 1999 Cristian Gafton <gafton@redhat.com>
- updated msghack to understand --append

* Wed Aug 11 1999 Cristian Gafton <gafton@redhat.com>
- updated msghack to correctly deal with sorting files

* Tue Jun 29 1999 Norihito Ohmori <ohmori@flatout.org>
- added multibyte patch for msgmerge

* Sun Jun 27 1999 Norihito Ohmori <ohmori@flatout.org>
- ja locale support from JaPO Project

* Thu May 06 1999 Cristian Gafton <gafton@redhat.com>
- msghack updates

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 8)

* Mon Mar 08 1999 Cristian Gafton <gafton@redhat.com>
- added patch for misc hacks to facilitate rpm translations

* Thu Dec 03 1998 Cristian Gafton <gafton@redhat.com>
- patch to allow to build on ARM

* Wed Sep 30 1998 Jeff Johnson <jbj@redhat.com>
- add Emacs po-mode.el files.

* Sun Sep 13 1998 Cristian Gafton <gafton@redhat.com>
- include the aclocal support files

* Fri Sep  4 1998 Bill Nottingham <notting@redhat.com>
- remove devel package (functionality is in glibc)

* Tue Sep  1 1998 Jeff Johnson <jbj@redhat.com>
- update to 0.10.35.

* Mon Jun 29 1998 Jeff Johnson <jbj@redhat.com>
- add gettextize.
- create devel package for libintl.a and libgettext.h.

* Mon Apr 27 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Sun Nov 02 1997 Cristian Gafton <gafton@redhat.com>
- added info handling
- added misc-patch (skip emacs-lisp modofications)

* Sat Nov 01 1997 Erik Troan <ewt@redhat.com>
- removed locale.aliases as we get it from glibc now
- uses a buildroot

* Mon Jun 02 1997 Erik Troan <ewt@redhat.com>
- Built against glibc
