%global major 5
%global minor 4
%global patchlevel 0

%global x11_app_defaults_dir %{_datadir}/X11/app-defaults

Summary: A program for plotting mathematical expressions and data.
Summary(ja):  数学系の関数やデータのプロット・プログラム
Name: gnuplot
Version: %{major}.%{minor}.%{patchlevel}
Release: 2%{?_dist_release}
Group: graphics,science
Vendor: Project Vine
Distribution: Vine Linux
Packager: daisuke, inagaki, shaolin

# MIT .. term/PostScript/aglfn.txt
License: gnuplot and MIT
URL: http://www.gnuplot.info/
# Need to remove non-free lena files
# rm -rf demo/lena*
# Source0: https://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Source: %{name}-%{version}-clean.tar.gz

#Patch0: gnuplot-4.2.0-refers_to.patch
#Patch1: gnuplot-4.2.0-fonts.patch
# resolves: #812225
# submitted upstream: http://sourceforge.net/tracker/?func=detail&aid=3558973&group_id=2055&atid=302055
Patch3: gnuplot-4.6.1-plot-sigsegv.patch
Patch4: gnuplot-4.6.4-singlethread.patch
Patch5: gnuplot-5.0.0-lua_checkint.patch
Patch6: gnuplot-5.4.0-no-lena.patch
Patch7: gnuplot-5.2.2-doc.patch
Patch8: gnuplot-5.2.8-cmd-opts.patch
Patch9: gnuplot-config.patch

# Vine Patches (replaces Patch1)
Patch70: gnuplot-5.4.0-fonts.patch

Patch1000: CVE-2020-25559.patch
Patch1001: CVE-2020-25412.patch

BuildRoot: %{_tmppath}/%{name}-root
#libedit-devel can not handle utf8, readline-devel is not legal with gnuplot, stick to builtin
BuildRequires: cairo-devel
BuildRequires: gd-devel >= 2.0.27
BuildRequires: giflib-devel
BuildRequires: libX11-devel
BuildRequires: libXt-devel
BuildRequires: libXpm-devel
BuildRequires: libjpeg-turbo-devel
BuildRequires: libpng-devel
BuildRequires: lua-devel
BuildRequires: m17n-lib
BuildRequires: pango-devel
BuildRequires: wxGTK-devel
BuildRequires: zlib-devel

BuildRequires: texlive
BuildRequires: texlive-collection-latexextra
BuildRequires: texlive-collection-formatsextra
BuildRequires: texlive-collection-langchinese
BuildRequires: texlive-collection-langcjk
BuildRequires: texlive-collection-langcyrillic
BuildRequires: texlive-collection-langczechslovak
BuildRequires: texlive-collection-langenglish
BuildRequires: texlive-collection-langeuropean
BuildRequires: texlive-collection-langfrench
BuildRequires: texlive-collection-langgerman
BuildRequires: texlive-collection-langgreek
BuildRequires: texlive-collection-langitalian
BuildRequires: texlive-collection-langjapanese
BuildRequires: texlive-collection-langother
BuildRequires: texlive-collection-langpolish
BuildRequires: texlive-collection-langportuguese
BuildRequires: texlive-collection-langspanish
BuildRequires: texinfo
BuildRequires: latex2html
BuildRequires: emacs

Requires: TrueType-dejavu
Requires(post): install-info
Requires(preun): install-info

%description
Gnuplot is a command-line driven, interactive function plotting
program especially suited for scientific data representation.  Gnuplot
can be used to plot functions and data points in both two and three
dimensions and in many different formats.

Install gnuplot if you need a graphics package for scientific data
representation.

%description -l ja
Gnuplotはとりわけ科学データ・プレゼンテーションに適した、コマンド
操作によるインタラクティブな関数プロット・プログラムです。
Gnuplotは関数や座標データを同時にプロットしたり、3次元化やさまざ
まな形式で表現するのに利用することができます。

科学データプレゼンテーション用のグラフィック・パッケージが必要な
場合、gnuplotをインストールしてください。


%package doc
Summary: Documentation for the gnuplot main application
Group: documentation
BuildArch: noarch
Requires: %{name} = %{version}-%{release}

%description doc
The gnuplot-doc package contains the documentation related to gnuplot
plotting tool


%package latex
Summary: Configuration for LaTeX typesetting using gnuplot
Group: publishing
BuildArch: noarch
Requires: %{name} = %{version}-%{release}
Requires: texlive-collection-latexextra
Requires: texlive-collection-fontsrecommended

%description latex
The gnuplot-latex package contains LaTeX configuration file related to gnuplot
plotting tool.


%debug_package


%prep
%setup -q
#patch0 -p1 -b .refto
#patch1 -p1 -b .font
%patch3 -p1 -b .plot-sigsegv
%patch4 -p1 -b .isinglethread
%patch5 -p1 -b .checkint
%patch6 -p1 -b .nolena
%patch7 -p1 -b .doc
%patch8 -p1 -b .cmd-opts
%patch9 -p1 -b .config
sed -i -e 's:"/usr/lib/X11/app-defaults":"%{x11_app_defaults_dir}":' src/gplt_x11.c
chmod 644 src/getcolor.h
chmod 644 demo/html/webify.pl
chmod 644 demo/html/webify_svg.pl
chmod 644 demo/html/webify_canvas.pl

%patch70 -p1 -b .font
%patch1000 -p1 -b .CVE-2020-25559
%patch1001 -p1 -b .CVE-2020-25412


%build
#remove binaries from source tarball
rm -rf demo/plugin/*.so demo/plugin/*.o
rm -rf docs_to_include
mkdir -p docs_to_include
cp -pr demo docs_to_include

%configure \
  --with-texdir=%{_datadir}/texmf/texmf-dist/tex/latex/gnuplot \
  --with-readline=builtin \
  --without-linux-vga \
  --enable-history-file \
  --without-qt

make %{?_smp_mflags}

make -C docs html info
export GNUPLOT_PS_DIR=../../term/PostScript
make -C docs/psdoc ps_symbols.ps ps_fontfile_doc.pdf
rm -rf docs/htmldocs/images.idx


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
make -C docs install-info DESTDIR=%{buildroot} INSTALL='install -p'
make -C share/LaTeX install DESTDIR=%{buildroot} INSTALL='install -p'

#rm -f demo/Makefile* tutorial/Makefile*
#packaged by info package, updated by post-installation script, do not package here
rm -f $RPM_BUILD_ROOT%{_infodir}/dir

mkdir -p $RPM_BUILD_ROOT%{x11_app_defaults_dir}
mv $RPM_BUILD_ROOT%{_datadir}/gnuplot/%{major}.%{minor}/app-defaults/Gnuplot $RPM_BUILD_ROOT%{x11_app_defaults_dir}/Gnuplot
rm -rf $RPM_BUILD_ROOT%{_libdir}/

mkdir -p $RPM_BUILD_ROOT/%{_mandir}/ja/man1
install -p -m644 man/gnuplot-ja_JP.UTF-8 $RPM_BUILD_ROOT/%{_mandir}/ja/man1/gnuplot.1


%clean
rm -rf %{buildroot}


%post
if [ -f %{_infodir}/gnuplot.info* ]; then
    /sbin/install-info %{_infodir}/gnuplot.info %{_infodir}/dir || :
fi

%preun
if [ $1 = 0 ] ; then
    if [ -f %{_infodir}/gnuplot.info* ]; then
        /sbin/install-info --delete %{_infodir}/gnuplot.info %{_infodir}/dir || :
    fi
fi


%files
%defattr(-,root,root)
%license Copyright
%doc BUGS NEWS README
%{_bindir}/gnuplot
%dir %{_libexecdir}/gnuplot/%{major}.%{minor}
%{_libexecdir}/gnuplot/%{major}.%{minor}/gnuplot_x11
%dir %{_datadir}/gnuplot/%{major}.%{minor}
%dir %{_datadir}/gnuplot/%{major}.%{minor}/PostScript
%dir %{_datadir}/gnuplot/%{major}.%{minor}/js
%dir %{_datadir}/gnuplot/%{major}.%{minor}/lua
%{_datadir}/gnuplot/%{major}.%{minor}/PostScript/*.ps
%{_datadir}/gnuplot/%{major}.%{minor}/PostScript/aglfn.txt
%{_datadir}/gnuplot/%{major}.%{minor}/js/*
%{_datadir}/gnuplot/%{major}.%{minor}/lua/gnuplot-tikz.lua
%{_datadir}/gnuplot/%{major}.%{minor}/colors_*
%{_datadir}/gnuplot/%{major}.%{minor}/gnuplot.gih
%{_datadir}/gnuplot/%{major}.%{minor}/gnuplotrc
%{x11_app_defaults_dir}/Gnuplot
%{_infodir}/gnuplot.info.gz
%{_mandir}/man1/gnuplot.*
%{_mandir}/ja/man1/gnuplot.*

%files doc
%defattr(-,root,root)
%license Copyright
%doc docs/psdoc/ps_guide.ps docs/psdoc/ps_symbols.ps
%doc docs/psdoc/ps_file.doc
%doc docs/psdoc/ps_fontfile_doc.pdf docs/htmldocs
%doc docs_to_include/demo

%files latex
%defattr(-,root,root)
%license Copyright
%{_datadir}/texmf/texmf-dist/tex/latex/gnuplot


%changelog
* Wed Sep 23 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 5.4.0-2
- imported Patch1001 to fix CVE-2020-25412.

* Tue Sep 22 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 5.4.0-1
- new upstream release.
- imported Patch6-9 from rawhide.
- dropped Patch0.
- updated Patch70.
- added Patch1000 to fix CVE-2020-25559.

* Sat Nov 19 2016 Toshiaki Ara <ara_t@384.jp> - 5.0.5-1
- new upstream release

* Thu Sep 01 2016 Toshiaki Ara <ara_t@384.jp> - 5.0.1-2
- rebuild with gcc-5.4.0

* Mon Aug 24 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> - 5.0.1-1
- new upstream release

* Thu May  7 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> - 5.0.0-1
- new upstream release
- libedit-devel can not handle utf8, readline-devel is not legal with gnuplot, stick to builtin
  https://bugzilla.redhat.com/show_bug.cgi?id=1039102
- split documents and latex-related files into subpackages

* Sun Jan 25 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> - 4.6.6-1
- update to 4.6.6

* Thu Jan 16 2014 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 4.6.4-1
- new upstream release
- add Patch0, Patch1 and Patch2 (font paths, upstream fixes)
- modify spec to build/install docs correctly

* Wed Jul 11 2012 Toshiharu Kudoh <toshi.kd2@gmail.com> - 4.4.3-2
- changed BuildRequires: wx-gtk2-devel >= 2.8.12 to wxGTK-devel >= 2.8.12
- added BuildRequires: libXpm-devel libjpeg-turbo-devel texlive-common

* Sat Apr 16 2011 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 4.4.3-1
- update to gnuplot-4.4.3
- use BR: texlive instead of tetex

* Sun May 31 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 4.2.5-1
- update to gnuplot-4.2.5
- drop plus patch (merged in upstream)
- update URL: to new upstream homepage
- fix License:
- build with wxGTK
- add BR: libX11-devel, libXt-devel, wx-gtk2-devel

* Sat Aug 16 2008 Shu KONNO <owa@bg.wakwak.com> 4.0.0-1vl5
- applied new versioning policy, spec in utf-8

* Tue Aug 22 2006 KAZUKI SHIMURA <kazuki@ma.ccnw.ne.jp> 4.0.0-0vl6
- add BuildRequires: texinfo, emacsen

* Sun Mar 19 2006 KAZUKI SHIMURA <kazuki@ma.ccnw.ne.jp> 4.0.0-0vl5
- rebuild with readline-5.1

* Wed Jun 15 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 4.0.0-0vl4
- update Patch0 to fix 'Invalid char in eps file'
  (thanks to HANAWA Toshihiro)
- add BuildRequires: autoconf, automake

* Sat Nov 20 2004 Satoshi MACHINO <machino@vinelinux.org> 4.0.0-0vl2
- enabled history-file

* Wed Jul 14 2004 KOBAYASHI R. Taizo <tkoba@vinelinux.org> 4.0.0-0vl1
- source update

* Wed Jul 14 2004 KOBAYASHI R. Taizo <tkoba@vinelinux.org> 3.8k.3-0vl1
- source update
- patch update and modified
- add info

* Wed Mar 10 2004 KOBAYASHI R. Taizo <tkoba@vinelinux.org> 3.7.3-2vl3
- rebuild
- fix license
- remove -DUSE_SYSTEM_TIME ([VinePlus:01805])

* Wed Apr 02 2003 KOBAYASHI R. Taizo <tkoba@vinelinux.org> 3.7.3-2vl2
- rebuild with readline-4.3

* Thu Feb 20 2003 KOBAYASHI R. Taizo <tkoba@vinelinux.org> 3.7.3-2vl1
- syncd with RH 3.7.3-2
- modified Yamaga-san's gnuplot3.7.2+1.2.0rc2.patch for 3.7.3

* Fri Jan 25 2002 KOBAYASHI R. Taizo <tkoba@vinelinux.org> 16vl1
- added pathes (patch1,2) from RH

* Sat Aug 25 2001 KOBAYASHI R. Taizo <tkoba@vinelinux.org> 12vl1
- syncd rawhide
- updated to 3.7.1-1.2.0

* Mon Jun  5 2000 Yasuyuki Furukawa <furukawa@vinelinux.org>
- updated to 3.7.1
- updated gnuplot+ patch to 1.1.9 for gnuplot 3.7.1.
- remake SPEC from rawhide.

* Fri May 19 2000 Nalin Dahyabhai <nalin@redhat.com>
- rebuild with new gd, changing gif terminal to jpeg terminal (release 7)

* Mon May 08 2000 Preston Brown <pbrown@redhat.com>
- build for 7.0

* Thu Apr  6 2000 Bill Nottingham <notting@redhat.com>
- use gnu readline, not built-in version

* Mon Apr  3 2000 Bill Nottingham <notting@redhat.com>
- add latex tutorial, demo files, other docs (#10508)

* Wed Mar  1 2000 Bill Nottingham <notting@redhat.com>
- update to 3.7.1. Oops.

* Thu Feb  3 2000 Bill Nottingham <notting@redhat.com>
- handle compressed man pages

* Thu Nov  4 1999 Bill Nottingham <notting@redhat.com>
- update to 3.7.1

* Mon Oct 11 1999 Bill Nottingham <notting@redhat.com>
- ship some docs.

* Wed Aug 18 1999 Bill Nottingham <notting@redhat.com>
- add a patch to fix postscript output from Bernd Kischnick
 (kisch@die-herrmanns.de)

* Fri Jul 30 1999 Bill Nottingham <notting@redhat.com>
- fix license

* Thu Jul 15 1999 Bill Nottingham <notting@redhat.com>
- rebuild without svgalib

* Tue Jun 15 1999 Bill Nottingham <notting@redhat.com>
- update to 3.7.0.1

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 2)

* Tue Feb  2 1999 Jeff Johnson <jbj@redhat.com>
- update to 3.7.

* Thu Dec 17 1998 Michael Maher <mike@redhat.com>
- built package for 6.0

* Fri Sep 11 1998 Jeff Johnson <jbj@redhat.com>
- update to 2.6beta347

* Sat Aug 15 1998 Jeff Johnson <jbj@redhat.com>
- build root

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Mon Oct 20 1997 Donnie Barnes <djb@redhat.com>
- spec file cleanups

* Thu Jul 10 1997 Erik Troan <ewt@redhat.com>
- built against glibc
