%define ver 3.0

Summary: A C++ interface for the GTK+ (a GUI library for X).
Summary(ja): GTK+ の C++ インターフェイス
Name: gtkmm3
Version: 3.24.4
Release: 1%{?_dist_release}
Group: system
Vendor: Project Vine
Distribution: Vine Linux

License: LGPL
URL: https://www.gtkmm.org/
%global shortver %(echo %{version} | sed -e 's/\.[0-9]*$//')
Source: https://download.gnome.org/sources/gtkmm/%{shortver}/gtkmm-%{version}.tar.xz

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: meson
BuildRequires: glibmm-devel >= 2.33.13
BuildRequires: cairomm-devel
BuildRequires: pangomm-devel >= 2.27.1
BuildRequires: atkmm-devel
BuildRequires: gtk3-devel >= 3.6.0
BuildRequires: libsigc++-devel >= 2.0.0
BuildRequires: doxygen
Requires: glibmm >= 2.33.13
Requires: pangomm >= 2.27.1
Requires: atk >= 1.9.0
Requires: gtk3 >= 3.6.0

%description
gtkmm (previously known as Gtk--) is the official C++ interface for the
popular GUI library GTK+. Highlights include typesafe callbacks, widgets
extensible via inheritance and a comprehensive set of widget classes that
can be freely combined to quickly create complex user interfaces.

The gtkmm devel package contains the static libraries and header files
needed for developing GTK+ (GIMP ToolKit) applications in C++.


%package        devel
Summary:        Development tools for gtkmm applications.
Summary(ja):    gtkmm アプリケーションの開発用ファイル
Group:          programming
Requires:       %{name} = %{version}
Requires:       gtk3-devel >= 3.6.0
Requires:       glibmm-devel >= 2.33.13
Requires:       cairomm-devel
Requires:       pangomm-devel >= 2.27.1

%description devel
This package contains the headers that programmers will need to develop
applications which will use Gtk--, the C++ interface to the GTK+
(the Gimp ToolKit) GUI library.


%debug_package


%prep
%setup -q -n gtkmm-%{version}


%build
%meson \
	-Dmaintainer-mode=false \
	-Dbuild-documentation=true \
	-Dbuild-demos=false \
	-Dbuild-tests=false

%meson_build


%install
[ -n "%{buildroot}" -a "%{buildroot}" != / ] && rm -rf %{buildroot}

%meson_install

find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'

# Fix documentation installation, put everything under gtk-doc
mkdir -p %{buildroot}%{_datadir}/gtk-doc/html/gtkmm-%{ver}
mv ${RPM_BUILD_ROOT}%{_docdir}/gtkmm-%{ver}/* %{buildroot}%{_datadir}/gtk-doc/html/gtkmm-%{ver}/

# devhelp path fix
sed -i 's:doc/gtkmm-%{ver}:gtk-doc/html/gtkmm-%{ver}:g' %{buildroot}%{_datadir}/devhelp/books/gtkmm-%{ver}/gtkmm-%{ver}.devhelp2

# remove demos, examples
rm -rf %{buildroot}%{_datadir}/gtkmm-%{ver}/demo
rm -rf %{buildroot}%{_datadir}/gtkmm-%{ver}/examples


%clean
[ -n "%{buildroot}" -a "%{buildroot}" != / ] && rm -rf %{buildroot}


%files
%defattr(-, root, root)
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/lib*.so.*

%files  devel
%defattr(-, root, root)
%{_includedir}/*
#{_libdir}/*.la
#{_libdir}/*.a
%{_libdir}/*.so
%{_libdir}/gtkmm-*
%{_libdir}/gdkmm-*
%{_libdir}/pkgconfig/*.pc

%{_datadir}/gtk-doc/html/*
%{_datadir}/devhelp/books/*


%changelog
* Thu May 13 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 3.24.4-1
- new upstream release.
- dropped ldconfig scriptlets.

* Fri Feb 12 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 3.24.3-1
- new upstream release.

* Sun Aug 02 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 3.24.2-1
- new upstream release.

* Fri Dec 28 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 3.22.3-1
- new upstream release.

* Fri Jul 15 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.20.1-1
- new upstream release

* Wed Jun 29 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.18.1-1
- new upstream release

* Sat Oct 31 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.18.0-1
- new upstream release

* Sun Mar 29 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.16.0-1
- new upstream release

* Sun Oct 26 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.14.0-1
- new upstream release

* Sat Apr 19 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.12.0-1
- new upstream release

* Sat Nov 09 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.10.1-1
- new upstream release

* Sat May 18 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.8.1-1
- new upstream release

* Mon Oct 22 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.6.0-1
- new upstream release

* Sat Oct 13 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.5.13-1
- new upstream release

* Thu Sep 27 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.5.12-1
- new upstream release
- add BuildRequires: doxygen

* Sun Apr 22 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.4.0-1
- new upstream release

* Wed Sep 28 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.2.0-1
- new upstream release

* Fri Sep 23 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.1.90.1-1
- new upstream release

* Sat Sep 03 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.1.16-1
- new upstream release

* Sun Aug 14 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.1.10-1
- initial build for Vine Linux

