%bcond_with systemd

Summary: Backends for the gio framework in GLib
Summary(ja): GLib の GIO フレームワークのバックエンド
Name: gvfs
Version: 1.48.1
Release: 1%{?_dist_release}%{?with_systemd:.systemd}
Group: desktop-gnome,system
Vendor: Project Vine
Distribution: Vine Linux

License: LGPLv2+
URL: https://wiki.gnome.org/Projects/gvfs
%global shortver %(echo %{version} | sed -e 's/\.[0-9]*$//')
Source0: https://download.gnome.org/sources/%{name}/%{shortver}/%{name}-%{version}.tar.xz

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: meson
BuildRequires: pkgconfig
BuildRequires: glib2-devel >= 2.24.0
BuildRequires: gtk3-devel
BuildRequires: dbus-glib-devel 
BuildRequires: /usr/bin/ssh
BuildRequires: libcdio-paranoia-devel
BuildRequires: libsoup-devel >= 2.30.0
BuildRequires: avahi-glib-devel >= 0.6
BuildRequires: libgnome-keyring-devel
BuildRequires: intltool
BuildRequires: gettext
BuildRequires: perl-XML-Parser
BuildRequires: udisks2-devel
BuildRequires: libsecret-devel
BuildRequires: libmtp-devel
BuildRequires: gnome-online-accounts-devel
BuildRequires: gcr-devel
BuildRequires: gsettings-desktop-schemas-devel
BuildRequires: libgudev-devel
BuildRequires: fuse3-devel
BuildRequires: libplist-devel
%if %{with systemd}
BuildRequires: systemd-devel
%{?systemd_requires}
%else
BuildRequires: elogind-devel
%endif

Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils

Provides: gnome-mount < 0.9
Obsoletes: gnome-mount < 0.9

Obsoletes: %{name}-obexftp < 1.24.0

%description
The gvfs package provides backend implementations for the gio 
framework in GLib. It includes ftp, sftp, cifs. 


%package devel
Summary: Development files for gvfs
Group: programming
Requires: %{name} = %{version}-%{release}

%description devel
The gvfs-devel package contains headers and other files that are
required to develop applications using gvfs.


%package fuse
Summary: FUSE support for gvfs
Group: desktop-gnome,system
Requires: %{name} = %{version}-%{release}
BuildRequires: fuse-devel
Requires: fuse

%description fuse
This package provides support for applications not using gio
to access the gvfs filesystems.


%package smb
Summary: Windows fileshare support for gvfs
Group: desktop-gnome,system
Requires: %{name} = %{version}-%{release}
BuildRequires: libsmbclient-devel

%description smb
This package provides support for reading and writing files on windows
shares (SMB) to applications using gvfs.


%package archive
Summary: Archiving support for gvfs
Group: desktop-gnome,system
Requires: %{name} = %{version}-%{release}
BuildRequires: libarchive-devel

%description archive
This package provides support for accessing files inside Zip and Tar archives,
as well as ISO images, to applications using gvfs.


%package gphoto2
Summary: gphoto2 support for gvfs
Group: desktop-gnome,system
Requires: %{name} = %{version}-%{release}
BuildRequires: libgphoto2-devel
BuildRequires: libusb-devel
BuildRequires: libexif-devel

%description gphoto2
This package provides support for reading and writing files on
PTP based cameras (Picture Transfer Protocol) and MTP based
media players (Media Transfer Protocol) to applications using gvfs.


%package afc
Summary: AFC support for gvfs
Group: desktop-gnome,system
Requires: %{name} = %{version}-%{release}
Requires: usbmuxd
BuildRequires: libimobiledevice-devel >= 0.9.7

%description afc
This package provides support for reading files on mobile devices
including phones and music players to applications using gvfs.


%package mtp
Summary: MTP support for gvfs
Group: desktop-gnome,system
Requires: %{name}%{?_isa} = %{version}-%{release}
BuildRequires: libmtp-devel >= 1.1.0

%description mtp
This package provides support for reading and writing files on
MTP based devices (Media Transfer Protocol) to applications using gvfs.


%package goa
Summary: GOA support for gvfs
Group: desktop-gnome,system
Requires: %{name}%{?_isa} = %{version}-%{release}
BuildRequires: gnome-online-accounts-devel >= 3.7.1

%description goa
This package provides seamless integration with gnome-online-accounts
file services.


%package admin
Summary: Admin support for gvfs
Group: desktop-gnome,system
Requires: %{name}%{?_isa} = %{version}-%{release}
BuildRequires: libcap-devel
BuildRequires: polkit-devel

%description admin
This package provides admin access for local filesystem.


%package google
Summary: Google support for gvfs
Group: desktop-gnome,system
Requires: %{name}%{?_isa} = %{version}-%{release}
BuildRequires: libgdata-devel

%description google
This package provides seamless integration with Google Drive.


%debug_package


%prep
%autosetup -p1


%build
%meson \
%if !%{with systemd}
  -Dsystemduserunitdir=no \
  -Dtmpfilesdir=no \
%endif
  -Dman=true \
  -Dnfs=false \
  -Dbluray=false \
  -Dlogind=true

%meson_build


%install
rm -rf $RPM_BUILD_ROOT
%meson_install

%if !%{with systemd}
rm -rf $RPM_BUILD_ROOT%{_prefix}/lib/systemd
%endif

%find_lang gvfs


%clean
rm -rf $RPM_BUILD_ROOT


%post
# Reload .mount files:
killall -USR1 gvfsd >&/dev/null || :

# Reload .mount files when single subpackage is installed:
%post smb
killall -USR1 gvfsd >&/dev/null || :
%post archive
killall -USR1 gvfsd >&/dev/null || :
%post gphoto2
killall -USR1 gvfsd >&/dev/null || :
%post afc
killall -USR1 gvfsd >&/dev/null || :


%files -f gvfs.lang
%defattr(-, root, root, -)
%license COPYING
%doc AUTHORS NEWS README
%dir %{_datadir}/gvfs
%dir %{_datadir}/gvfs/mounts
%{_datadir}/gvfs/mounts/afp.mount
%{_datadir}/gvfs/mounts/afp-browse.mount
%{_datadir}/gvfs/mounts/sftp.mount
%{_datadir}/gvfs/mounts/trash.mount
%{_datadir}/gvfs/mounts/cdda.mount
%{_datadir}/gvfs/mounts/computer.mount
%{_datadir}/gvfs/mounts/dav.mount
%{_datadir}/gvfs/mounts/dav+sd.mount
%{_datadir}/gvfs/mounts/http.mount
%{_datadir}/gvfs/mounts/localtest.mount
%{_datadir}/gvfs/mounts/burn.mount
%{_datadir}/gvfs/mounts/dns-sd.mount
%{_datadir}/gvfs/mounts/network.mount
%{_datadir}/gvfs/mounts/ftp.mount
%{_datadir}/gvfs/mounts/ftpis.mount
%{_datadir}/gvfs/mounts/ftps.mount
%{_datadir}/gvfs/mounts/recent.mount
%{_datadir}/dbus-1/services/org.gtk.vfs.UDisks2VolumeMonitor.service
%{_datadir}/dbus-1/services/org.gtk.vfs.Daemon.service
%{_datadir}/dbus-1/services/org.gtk.vfs.Metadata.service
%{_datadir}/gvfs/remote-volume-monitors/udisks2.monitor
%{_datadir}/GConf/gsettings/gvfs-dns-sd.convert
%{_datadir}/glib-2.0/schemas/org.gnome.system.dns_sd.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.system.gvfs.enums.xml
%{_datadir}/polkit-1/actions/org.gtk.vfs.file-operations.policy
%{_datadir}/polkit-1/rules.d/org.gtk.vfs.file-operations.rules
%{_libdir}/gio/modules/libgioremote-volume-monitor.so
%{_libdir}/gio/modules/libgvfsdbus.so
%{_libdir}/%{name}/libgvfscommon.so
%{_libdir}/%{name}/libgvfsdaemon.so
%{_libexecdir}/gvfsd
%{_libexecdir}/gvfsd-afp
%{_libexecdir}/gvfsd-afp-browse
%{_libexecdir}/gvfsd-ftp
%{_libexecdir}/gvfsd-sftp
%{_libexecdir}/gvfsd-trash
%{_libexecdir}/gvfsd-cdda
%{_libexecdir}/gvfsd-computer
%{_libexecdir}/gvfsd-dav
%{_libexecdir}/gvfsd-http
%{_libexecdir}/gvfsd-localtest
%{_libexecdir}/gvfsd-burn
%{_libexecdir}/gvfsd-dnssd
%{_libexecdir}/gvfsd-network
%{_libexecdir}/gvfsd-metadata
%{_libexecdir}/gvfsd-recent
%{_libexecdir}/gvfs-udisks2-volume-monitor
%{_mandir}/man1/gvfsd-metadata.1.gz
%{_mandir}/man1/gvfsd.1.gz
%{_mandir}/man7/gvfs.7.gz
%if %{with systemd}
%{_userunitdir}/gvfs-daemon.service
%{_userunitdir}/gvfs-metadata.service
%{_userunitdir}/gvfs-udisks2-volume-monitor.service
%{_tmpfilesdir}/*
%endif

%files devel
%defattr(-, root, root, -)
%dir %{_includedir}/gvfs-client
%dir %{_includedir}/gvfs-client/gvfs
%{_includedir}/gvfs-client/gvfs/gvfsurimapper.h
%{_includedir}/gvfs-client/gvfs/gvfsuriutils.h

%files fuse
%defattr(-, root, root, -)
%{_libexecdir}/gvfsd-fuse
%{_mandir}/man1/gvfsd-fuse.1.gz

%files smb
%defattr(-, root, root, -)
%{_libexecdir}/gvfsd-smb
%{_libexecdir}/gvfsd-smb-browse
%{_datadir}/gvfs/mounts/smb-browse.mount
%{_datadir}/gvfs/mounts/smb.mount
%{_datadir}/GConf/gsettings/gvfs-smb.convert
%{_datadir}/glib-2.0/schemas/org.gnome.system.smb.gschema.xml

%files archive
%defattr(-, root, root, -)
%{_libexecdir}/gvfsd-archive
%{_datadir}/gvfs/mounts/archive.mount

%files gphoto2
%defattr(-, root, root, -)
%{_libexecdir}/gvfsd-gphoto2
%{_datadir}/gvfs/mounts/gphoto2.mount
%{_libexecdir}/gvfs-gphoto2-volume-monitor
%{_datadir}/dbus-1/services/org.gtk.vfs.GPhoto2VolumeMonitor.service
%{_datadir}/gvfs/remote-volume-monitors/gphoto2.monitor
%if %{with systemd}
%{_userunitdir}/gvfs-gphoto2-volume-monitor.service
%endif

%files afc
%defattr(-, root, root, -)
%{_libexecdir}/gvfsd-afc
%{_datadir}/gvfs/mounts/afc.mount
%{_libexecdir}/gvfs-afc-volume-monitor
%{_datadir}/dbus-1/services/org.gtk.vfs.AfcVolumeMonitor.service
%{_datadir}/gvfs/remote-volume-monitors/afc.monitor
%if %{with systemd}
%{_userunitdir}/gvfs-afc-volume-monitor.service
%endif

%files mtp
%defattr(-, root, root, -)
%{_libexecdir}/gvfsd-mtp
%{_datadir}/gvfs/mounts/mtp.mount
%{_libexecdir}/gvfs-mtp-volume-monitor
%{_datadir}/dbus-1/services/org.gtk.vfs.MTPVolumeMonitor.service
%{_datadir}/gvfs/remote-volume-monitors/mtp.monitor
%if %{with systemd}
%{_userunitdir}/gvfs-mtp-volume-monitor.service
%endif

%files goa
%defattr(-, root, root, -)
%{_libexecdir}/gvfs-goa-volume-monitor
%{_datadir}/dbus-1/services/org.gtk.vfs.GoaVolumeMonitor.service
%{_datadir}/gvfs/remote-volume-monitors/goa.monitor
%if %{with systemd}
%{_userunitdir}/gvfs-goa-volume-monitor.service
%endif

%files admin
%defattr(-, root, root, -)
%{_libexecdir}/gvfsd-admin
%{_datadir}/gvfs/mounts/admin.mount

%files google
%defattr(-, root, root, -)
%{_libexecdir}/gvfsd-google
%{_datadir}/gvfs/mounts/google.mount


%changelog
* Tue May 11 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.48.1-1
- new upstream release.

* Sat Apr 03 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.48.0-1
- new upstream release.

* Mon Sep 14 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.46.0-1
- new upstream release.
- dropped Patch0: fixed in upstream.

* Tue Aug 04 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.44.1-1
- new upstream release.
- dropped Patch1-7.
- imported Patch0 from upstream.

* Fri Oct 25 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.39.4-1
- new upstream release.
- imported Patch1-7 from upstream.

* Sat Dec 29 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.39.3-1
- new upstream release.
- dropped Patch1.

* Sun Jul 17 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.28.2-1
- new upstream release

* Fri Nov 13 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.26.2-1
- new upstream release

* Sun Nov 01 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.26.0-1
- new upstream release
- add BuildRequires: gcr-devel

* Sun Aug 30 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.24.2-1
- new upstream release

* Thu May 21 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 1.24.1-2
- rebuilt with libimobiledevice 1.2.0

* Sun Apr 19 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.24.1-1
- new upstream release

* Sun Mar 29 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.24.0-1
- new upstream release
- remove %%{name}-obexftp subpackage

* Mon Feb 09 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.22.3-2
- rebuild with libgphoto2-2.5.7

* Mon Jan 12 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.22.3-1
- new upstream release

* Wed Nov 19 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.22.2-1
- new upstream release

* Sun Oct 26 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.22.1-1
- new upstream release

* Sun Aug 31 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.20.3-1
- new upstream release

* Sun Jul 13 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.20.2-5
- change BuildRequires: libcdio-paranoia-devel instead of libcdio-devel

* Wed Jul 09 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.20.2-4
- rebuild with libplist-1.11

* Sun Jul 06 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.20.2-3
- rebuild with libarchive-3.1.2

* Tue Jun 17 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.20.2-2
- change BuildRequires: eudev-libgudev1-devel instead of libgudev1-devel

* Sat May 17 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.20.2-1
- new upstream release

* Sun Apr 13 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.20.1-1
- new upstream release

* Sun Mar 30 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.20.0-1
- new upstream release

* Thu Feb 20 2014 NAKAMURA Kenta <kenta@vinelinux.org> 1.18.3-2
- rebuilt with libgcrypt-1.6

* Sat Nov 09 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.18.3-1
- new upstream release

* Sat Oct 26 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.18.2-1
- new upstream release

* Mon Jul 15 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.16.3-1
- new upstream release

* Sun May 19 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.16.2-1
- new upstream release

* Sun Apr 21 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.16.1-1
- new upstream release
- update Patch1 (gvfs-1.16.0-archive-integration.patch)
- add BuildRequires: libmtp-devel, gnome-online-accounts
- create %%{name}-mtp and %%{name}-goa subpackages

* Sun Mar 24 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.14.2-3
- rebuild with libimobiledevice-1.1.5

* Fri Jan 11 2013 IWAI, Masaharu <iwai@alib.jp> 1.14.2-2
- build with libgphoto2 2.5.0-1

* Wed Nov 14 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.14.2-1
- new upstream release

* Tue Oct 16 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.14.1-1
- new upstream release

* Sat Sep 29 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.14.0-1
- new upstream release
- add BuildRequires: libsecret-devel, gtk3-devel
- remove BuildRequires: GConf2-devel

* Sun Jun 10 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.12.3-2
- rebuild with libarchive-3.0.4

* Sun May 20 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.12.3-1
- new upstream release

* Mon Apr 30 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.12.2-1
- new upstream release

* Sat Apr 28 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.12.1-1
- new upstream release
- add BuildRequires: udisks2-devel
- remove BuildRequires: gnome-disk-utility-devel

* Sat Oct 22 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.10.1-1
- new upstream release

* Thu Sep 29 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.10.0-1
- new upstream release

* Fri Sep 23 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.9.5-1
- new upstream release

* Sat Sep 03 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.9.4-1
- new upstream release

* Sun Aug 21 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.9.3-1
- new upstream release

* Tue Aug 16 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.9.2-1
- new upstream release
- add Provides: and Obsoletes: gnome-mount

* Thu May 05 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.6.7-1
- new upstream release

* Sat Nov 20 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.6.6-1
- new upstream release
- drop Patch2

* Sun Oct 17 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.6.4-2
- add Patch2 (gvfs-1.6.4-sftp-timeout.patch)

* Sun Oct 03 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.6.4-1
- new upstream release

* Sat Jul 24 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.6.3-1
- new upstream release

* Tue Jun 29 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.6.2-1
- new upstream release

* Sat May 22 2010 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.6.1-3
- rebuilt with libcdio-0.82

* Wed May 12 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.6.1-2
- add configure option --enable-gdu
- add BR: gnome-disk-utility-devel
- add afc subpackage for new AFC backend, 
  providing access to Apple's iPhone, and iPod Touch devices

* Sat May 01 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.6.1-1
- new upstream release

* Sun Apr 11 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.6.0-1
- new upstream release
- change BuildRequires: gnome-keyring-devel -> libgnome-keyring-devel
- change BuildRequires: hal-devel -> ibgudev1-devel
- add configure option (--disable-hal)

* Sun Mar 14 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.4.3-1
- new upstream release

* Sat Oct 31 2009 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.4.1-1
- new upstream release

* Thu May 28 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.3-2
- new upstream release

* Sat Apr 25 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.2-1
- new upstream release

* Sat Apr 04 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.0-2
- new upstream release

* Thu Oct 23 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.2-1
- new upstream release
- BR: bluez-libs-devel >= 4.15

* Thu Oct 23 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 1.0.1-2
- rebuild with bluez-libs-devel-4.15

* Fri Sep 26 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.1-1
- new upstream release

* Mon Sep 22 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.0-1
- new upstream release

* Sat Sep 06 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 0.99.6-1
- new upstream release
- split out backends to sub packages

* Thu Jul 03 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 0.99.1-1
- new upstream release

* Thu Apr 10 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> - 0.2.3-1vl5
- new upstream release

* Wed Apr  2 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> - 0.2.2-1vl5
- Initial build for Vine Linux

* Fri Mar 28 2008 Tomas Bzatek <tbzatek@redhat.com> - 0.2.2-1
- Update to 0.2.2

* Tue Mar 25 2008 Tomas Bzatek <tbzatek@redhat.com> - 0.2.1-4
- Moved fuse stuff to a dedicated package

* Thu Mar 20 2008 Alexander Larsson <alexl@redhat.com> - 0.2.1-3
- Add patch with simple archive backend UI integration

* Wed Mar 19 2008 Tomas Bzatek <tbzatek@redhat.com> - 0.2.1-2
- Added libarchive dependency for archive backend
- Require new libsmbclient in order to get smb backend working again

* Tue Mar 18 2008 Tomas Bzatek <tbzatek@redhat.com> - 0.2.1-1
- Update to 0.2.1 (archive backend temporarily disabled)

* Mon Mar 17 2008 Matthias Clasen  <mclasen@redhat.com> - 0.2.0.1-2
- Silence %%post

* Mon Mar 10 2008 Matthias Clasen  <mclasen@redhat.com> - 0.2.0.1-1
- Update to 0.2.0.1

* Thu Mar  6 2008 Tomas Bzatek <tbzatek@redhat.com> - 0.1.11-2
- Add patch that fixes a deadlock when foreign volume is removed

* Tue Mar  4 2008 Matthias Clasen  <mclasen@redhat.com> - 0.1.11-1
- Update to 0.1.11

* Tue Mar 04 2008 Tomas Bzatek <tbzatek@redhat.com> - 0.1.10-1
- Update to 0.1.10

* Mon Feb 25 2008 Alexander Larsson <alexl@redhat.com> - 0.1.8-1
- Update to 0.1.8

* Thu Feb 14 2008 Alexander Larsson <alexl@redhat.com> - 0.1.7-3
- Add patch that fixes a smb bug that can cause short reads when copying files

* Tue Feb 12 2008 Alexander Larsson <alexl@redhat.com> - 0.1.7-2
- Fix double free in hal volume monitor
- Ensure gconf module is built by adding build dep

* Mon Feb 11 2008 Matthias Clasen <mclasen@redhat.com> - 0.1.7-1
- Update to 0.1.7

* Tue Jan 29 2008 Matthias Clasen <mclasen@redhat.com> - 0.1.6-1
- Update to 0.1.6

* Mon Jan 28 2008 Matthias Clasen <mclasen@redhat.com> - 0.1.5-1
- Update to 0.1.5
- Reenable http/dav 

* Mon Jan 21 2008 Alexander Larsson <alexl@redhat.com> - 0.1.4-2 
- Remove the http/dav stuff for now, as we don't have the latest libsoup

* Mon Jan 21 2008 Alexander Larsson <alexl@redhat.com> - 0.1.4-1
- Update to 0.1.4
- Send USR1 in post to reload config

* Mon Jan 14 2008 Matthias Clasen <mclasen@redhat.com> 0.1.2-1
- Update to 0.1.2

* Tue Jan  8 2008 Matthias Clasen <mclasen@redhat.com> 0.1.1-1
- Update to 0.1.1

* Thu Dec 20 2007 Matthias Clasen <mclasen@redhat.com> 0.1.0-1
- Initial packaging
