%bcond_with test

Summary: A general purpose library and file format for storing scientific data
Name:		 hdf5
Version:	1.12.1
Release:	1%{?_dist_release}
Group:		system
Vendor:		Project Vine
Distribution:	Vine Linux

License: BSD
URL:     http://www.hdfgroup.org/HDF5/

%define shortver %(echo %{version} | cut -d . -f 1-2)
Source0: https://support.hdfgroup.org/ftp/HDF5/releases/hdf5-%{shortver}/hdf5-1.12.1/src/hdf5-%{version}.tar.bz2

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: zlib-devel, gcc-gfortran, time


%description
HDF5 is a general purpose library and file format for storing scientific data.
HDF5 can store two primary objects: datasets and groups. A dataset is
essentially a multidimensional array of data elements, and a group is a
structure for organizing objects in an HDF5 file. Using these two basic
objects, one can create and store almost any kind of scientific data
structure, such as images, arrays of vectors, and structured and unstructured
grids. You can also mix and match them in HDF5 files according to your needs.


%package devel
Summary: HDF5 development files
Group: programming
Requires: %{name} = %{version}-%{release}

%description devel
HDF5 development headers and libraries.


%package static
Summary: HDF5 static libraries
Group: programming
Requires: %{name}-devel = %{version}-%{release}

%description static
HDF5 static libraries.


%debug_package


%prep
%setup -q


%build
export CC=gcc
export CXX=g++
export F9X=gfortran
%{configure} \
             --enable-build-mode=production \
             --with-ssl --enable-cxx --enable-fortran \
             --disable-dependency-tracking \
             --enable-hl --enable-shared
%{__make} %{?_smp_mflags}

%install
%{__rm} -rf ${RPM_BUILD_ROOT}
%{makeinstall} docdir=${RPM_BUILD_ROOT}%{_docdir}
%{__rm} -rf ${RPM_BUILD_ROOT}/%{_libdir}/*.la ${RPM_BUILD_ROOT}/%{_libdir}/*.settings


%if %{with test}
%check
%{__make} check
%endif


%clean
%{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root,-)
%doc COPYING MANIFEST README.txt release_docs/RELEASE.txt
%doc release_docs/HISTORY*.txt
%{_bindir}/gif2h5
%{_bindir}/h52gif
%{_bindir}/h5clear
%{_bindir}/h5copy
%{_bindir}/h5debug
%{_bindir}/h5diff
%{_bindir}/h5dump
%{_bindir}/h5format_convert
%{_bindir}/h5import
%{_bindir}/h5jam
%{_bindir}/h5ls
%{_bindir}/h5mkgrp
%{_bindir}/h5perf_serial
%{_bindir}/h5repack
%{_bindir}/h5repart
%{_bindir}/h5stat
%{_bindir}/h5unjam
%{_bindir}/h5watch
%{_bindir}/mirror_server
%{_bindir}/mirror_server_stop
%attr(0755,root,root) %{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%{_bindir}/h5c++
%{_bindir}/h5cc
%{_bindir}/h5fc
%{_bindir}/h5redeploy
%{_includedir}/*.h
%{_libdir}/*.so
%{_includedir}/*.mod
%{_datadir}/hdf5_examples/

%files static
%defattr(-,root,root,-)
%{_libdir}/*.a


%changelog
* Wed Sep 01 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.12.1-1
- new upstream release.
- dropped ldconfig scriptlets.

* Sat Dec 12 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.12.0-1
- new upstream release.

* Fri Jan 25 2019 Toshiaki Ara <ara_t@384.jp> 1.8.20-2
- rebuild with gfortran-8.2.0

* Sat Jun 30 2018 Toshiaki Ara <ara_t@384.jp> 1.8.20-1
- update to 1.8.20

* Sat Jul 09 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.8.14-2
- rebuild with gcc-5.4.0

* Mon Jan 12 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.8.14-1
- new upstream release

* Sun Oct 28 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.8.9-1
- new upstream release

* Wed Nov 30 2011 NAKAMURA Kenta <kenta@vinelinux.org> 1.8.8-1
- new upstream release
- drop obsolete patches

* Sun Feb 06 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.6.10-1
- new upstream release
- drop Patch1,3,10
- remove BuildRequires: openssl-devel

* Tue Oct 14 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.6.6-2
- applied new versioning policy

* Thu Jan 03 2008 NAKAMURA Kenta <kenta@vinelinux.org> 1.6.6-1vl1
- Removed krb5-devel from BuildRequires:
- Rebuild for VineSeed

* Wed Oct 17 2007 Orion Poplawski <orion@cora.nwra.com> 1.6.6-1
- Update to 1.6.6, drop upstreamed patches
- Explicitly set compilers

* Fri Aug 24 2007 Orion Poplawski <orion@cora.nwra.com> 1.6.5-9
- Update license tag to BSD
- Rebuild for BuildID

* Wed Aug  8 2007 Orion Poplawski <orion@cora.nwra.com> 1.6.5-8
- Fix memset typo
- Pass mode to open with O_CREAT

* Mon Feb 12 2007 Orion Poplawski <orion@cora.nwra.com> 1.6.5-7
- New project URL
- Add patch to use POSIX sort key option
- Remove useless and multilib conflicting Makefiles from html docs
  (bug #228365)
- Make hdf5-devel own %{_docdir}/%{name}

* Tue Aug 29 2006 Orion Poplawski <orion@cora.nwra.com> 1.6.5-6
- Rebuild for FC6

* Wed Mar 15 2006 Orion Poplawski <orion@cora.nwra.com> 1.6.5-5
- Change rpath patch to not need autoconf
- Add patch for libtool on x86_64
- Fix shared lib permissions

* Mon Mar 13 2006 Orion Poplawski <orion@cora.nwra.com> 1.6.5-4
- Add patch to avoid HDF setting the compiler flags

* Mon Feb 13 2006 Orion Poplawski <orion@cora.nwra.com> 1.6.5-3
- Rebuild for gcc/glibc changes

* Wed Dec 21 2005 Orion Poplawski <orion@cora.nwra.com> 1.6.5-2
- Don't ship h5perf with missing library

* Wed Dec 21 2005 Orion Poplawski <orion@cora.nwra.com> 1.6.5-1
- Update to 1.6.5

* Wed Dec 21 2005 Orion Poplawski <orion@cora.nwra.com> 1.6.4-9
- Rebuild

* Wed Nov 30 2005 Orion Poplawski <orion@cora.nwra.com> 1.6.4-8
- Package fortran files properly
- Move compiler wrappers to devel

* Fri Nov 18 2005 Orion Poplawski <orion@cora.nwra.com> 1.6.4-7
- Add patch for fortran compilation on ppc

* Wed Nov 16 2005 Orion Poplawski <orion@cora.nwra.com> 1.6.4-6
- Bump for new openssl

* Tue Sep 20 2005 Orion Poplawski <orion@cora.nwra.com> 1.6.4-5
- Enable fortran since the gcc bug is now fixed

* Tue Jul 05 2005 Orion Poplawski <orion@cora.nwra.com> 1.6.4-4
- Make example scripts executable

* Fri Jul 01 2005 Orion Poplawski <orion@cora.nwra.com> 1.6.4-3
- Add --enable-threads --with-pthreads to configure
- Add %check
- Add some %docs
- Use %makeinstall
- Add patch to fix test for h5repack
- Add patch to fix h5diff_attr.c

* Mon Jun 27 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.6.4-2
- remove szip from spec, since szip license doesn't meet Fedora standards

* Sun Apr 3 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.6.4-1
- inital package for Fedora Extras
