%bcond_with systemd

Summary: Utility to administer the Linux Virtual Server
Summary(ja): Linux Virtual Server を管理するためのユーティリティ
Name: ipvsadm
Version: 1.31
Release: 1%{?_dist_release}%{?with_systemd:.systemd}
Group: system,network
Vendor: Project Vine
Distribution: Vine Linux

License: GPLv2+
URL: https://kernel.org/pub/linux/utils/kernel/ipvsadm/
Source0: https://kernel.org/pub/linux/utils/kernel/ipvsadm/%{name}-%{version}.tar.xz
Source1: ipvsadm.init
Source2: ipvsadm-config
Patch3: 0003-ipvsadm-use-CFLAGS-and-LDFLAGS-environment-variables.patch

BuildRoot: %{_tmppath}/%{name}-%{PACKAGE_VERSION}-buildroot
BuildRequires: libnl3-devel
BuildRequires: popt-devel
%if %{with systemd}
%{?systemd_requires}
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
%endif

%description
ipvsadm is a utility to administer the IP Virtual Server services
offered by the Linux kernel.


%debug_package


%prep
%setup -q
%patch3 -p1


%build
CFLAGS="${RPM_OPT_FLAGS}" %__make


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p ${RPM_BUILD_ROOT}/{sbin,%{_mandir}/man8,etc/rc.d/init.d}
%__make install BUILD_ROOT=${RPM_BUILD_ROOT} MANDIR=%{_mandir}
# Install config file which controls the service behavior
install -D -p -m 0600 %{SOURCE2} %{buildroot}/etc/sysconfig/ipvsadm-config
%if %{with systemd}
%{__rm} -f %{buildroot}%{_sysconfdir}/rc.d/init.d/%{name}
%{__install} -p -D -m 0644 %{SOURCE10} %{buildroot}%{_unitdir}/%{name}.service
%else
# Overwrite the provided init script with our flexible and LSB compliant one
%{__install} -p -m 0755 %{SOURCE1} %{buildroot}/etc/rc.d/init.d/ipvsadm
%endif


%clean
rm -rf $RPM_BUILD_DIR/%{name}
rm -rf $RPM_BUILD_ROOT


%post
%if %{with systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add ipvsadm
%endif

%preun
%if %{with systemd}
%systemd_preun %{name}.service
%else
/sbin/chkconfig --del ipvsadm
%endif

%if %{with systemd}
%postun
%systemd_postun_with_restart %{name}.service
%endif


%files
%defattr(-,root,root)
%doc README
%config(noreplace) /etc/sysconfig/ipvsadm-config
/sbin/ipvsadm*
%{_mandir}/man8/ipvsadm*
%if %{with systemd}
%{_unitdir}/%{name}.service
%else
%config /etc/rc.d/init.d/ipvsadm
%endif


%changelog
* Tue Feb 23 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.31-1
- updated to 1.31.
- dropped Patch1 and 2.

* Thu Nov 29 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.29-1
- updated to 1.29
- dropped Patch0.
- imported Patch1-3 from rawhide.
- dropped BR: libnl-devel.
- added BR: libnl3-devel.

* Wed Apr 11 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 1.26-1
- update to 1.26
- update init scripts

* Sun Sep 28 2008 Shu KONNO <owa@bg.wakwak.com> 1.24-1vl5
- applied new versioning policy, spec in utf-8

* Sun Oct 22 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 1.24-0vl1
- initial build for Vine Linux

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.24-8.1
- rebuild

* Mon May 15 2006 Phil Knirsch <pknirsch@redhat.com> - 1.24-8
- Added missing prereq to chkconfig

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.24-7.2.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.24-7.2
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Mon Mar 14 2005 Lon Hohberger <lhh@redhat.com> 1.24-7
- rebuilt

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Tue Mar 16 2004 Mike McLean <mikem@redhat.com> 1.24-4.2.ipvs120
- bump release

* Tue Mar 02 2004 Mike McLean <mikem@redhat.com> 1.24-4.1.ipvs120
- update to new version for 2.6 kernel

* Thu Jan 08 2004 Mike McLean <mikem@redhat.com> 1.21-10.ipvs108
- fixing a minor bug/typo in output format processing

* Wed Aug 06 2003 Mike McLean <mikem@redhat.com> 1.21-9.ipvs108
- Dropping kernel-source BuildRequires and including a local copy of 
  net/ip_vs.h to compensate.
- Incorporating some upstream changes, most notably the --sort option.

* Fri Jun 13 2003 Mike McLean <mikem@redhat.com> 1.21-8
- dropping ppc from excluded arches

* Fri Apr 4 2003 Mike McLean <mikem@redhat.com> 1.21-7
- changing %%ExcludeArch

* Fri Apr 4 2003 Mike McLean <mikem@redhat.com> 1.21-6
- added BuildRequires: kernel-source
- escaped all %% characters in %%changelog

* Mon Dec 2 2002 Mike McLean <mikem@redhat.com> 1.21-5
- Improved the description in the ipvsadm initscript.
- fixed Buildroot to use _tmppath

* Wed Aug 21 2002 Philip Copeland <bryce@redhat.com> 1.21-4
- Argh,.. %%docdir was defined which overrode what I'd
  intended to happen

* Thu Aug 1 2002 Philip Copeland <bryce@redhat.com>
- Ah... the manuals were being pushed into /usr/man
  instead of /usr/share/man. Fixed.

* Tue Jul 16 2002 Philip Copeland <bryce@redhat.com>
- Minor Makefile tweak so that we do a minimal hunt for to find
  the ip_vs.h file location

* Sun Dec 16 2001 Wensong Zhang <wensong@linuxvirtualserver.org>
- Changed to install ipvsadm man pages according to the %%{_mandir}

* Sat Dec 30 2000 Wensong Zhang <wensong@linuxvirtualserver.org>
- update the %%file section

* Sun Dec 17 2000 Wensong Zhang <wensong@linuxvirtualserver.org>
- Added a if-condition to keep both new or old rpm utility building
  the package happily.

* Tue Dec 12 2000 P.opeland <bryce@redhat.com>
- Small modifications to make the compiler happy in RH7 and the Alpha
- Fixed the documentation file that got missed off in building
  the rpm
- Made a number of -pedantic mods though popt will not compile with
  -pedantic

* Wed Aug 9 2000 Horms <horms@vergenet.net>
- Removed Obseletes tag as ipvsadm is back in /sbin where it belongs 
  as it is more or less analogous to both route and ipchains both of
  which reside in /sbin.
- Create directory to install init script into. Init scripts won't install
  into build directory unless this is done

* Thu Jul  6 2000 Wensong Zhang <wensong@linuxvirtualserver.org>
- Changed to build rpms on the ipvsadm tar ball directly

* Wed Jun 21 2000 P.Copeland <copeland@redhat.com>
- fixed silly install permission settings

* Mon Jun 19 2000 P.Copeland <copeland@redhat.com>
- Added 'dist' and 'rpms' to the Makefile
- Added Obsoletes tag since there were early versions
  of ipvsadm-*.rpm that installed in /sbin
- Obsolete tag was a bit vicious re: piranha

* Mon Apr 10 2000 Horms <horms@vergenet.net>
- created for version 1.9
