%bcond_with systemd

Summary:        Daemon to balance irq's across multiple CPUs/Cores.
Summary(ja):    複数の CPU 間で IRQ をバランスさせるためのデーモン
Name:           irqbalance
Version:        1.7.0
Release:        1%{?_dist_release}%{?with_systemd:.systemd}
Group:          system
Vendor:         Project Vine
Distribution:   Vine Linux

License:        GPLv3
URL:            https://irqbalance.github.io/irqbalance/
Source0:        https://github.com/Irqbalance/irqbalance/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:	%{name}.init
Source2:	%{name}.sysconfig
Source100:	%{name}.sysconfig.systemd

Patch1:         %{name}-1.7.0-env-file-path.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-root
BuildRequires:	autoconf automake libtool
BuildRequires:	glib2-devel pkgconfig libcap-ng-devel
BuildRequires:	ncurses-devel
%if %{with systemd}
%{?systemd_requires}
%else
Requires(post): chkconfig initscripts
Requires(preun): chkconfig initscripts
Requires(postun): initscripts
%endif

%description
irqbalance is a daemon that evenly distributes IRQ load across
multiple CPUs for enhanced performance.


%debug_package


%prep
%setup -q
%patch1 -p1


%build
./autogen.sh
%configure
CFLAGS="%{optflags}" %__make %{?_smp_mflags}


%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}
mkdir -p %{buildroot}%{_sbindir}
install irqbalance %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_mandir}/man1
install irqbalance.1 %{buildroot}%{_mandir}/man1/

%if %{with systemd}
install -Dpm0644 ./misc/irqbalance.service %{buildroot}/%{_unitdir}/irqbalance.service
install -Dpm644 %{SOURCE100} %{buildroot}%{_sysconfdir}/sysconfig/irqbalance
%else
install -Dpm755 %{SOURCE1} $RPM_BUILD_ROOT%{_initdir}/irqbalance
install -Dpm644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/irqbalance
%endif


%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}


%post
%if %{with systemd}
%systemd_post irqbalance.service
%else
if [ $1 = 1 ]; then
    /sbin/chkconfig --add irqbalance
fi
%endif

%preun
%if %{with systemd}
%systemd_preun irqbalance.service
%else
if [ $1 = 0 -o -x /bin/systemctl ]; then
    /sbin/service irqbalance stop > /dev/null 2>&1
    /sbin/chkconfig --del irqbalance
fi
%endif

%postun
%if %{with systemd}
%systemd_postun_with_restart irqbalance.service
%else
if [ $1 -ge 1 ]; then
    /sbin/service irqbalance condrestart > /dev/null 2>&1 ||:
fi
%endif


%files
%defattr(-,root,root)
%license COPYING
%doc AUTHORS
%config(noreplace) %{_sysconfdir}/sysconfig/*
%{_sbindir}/*
%{_mandir}/*/*
%if %{with systemd}
%{_unitdir}/irqbalance.service
%else
%config(noreplace) %{_sysconfdir}/rc.d/init.d/*
%endif

%changelog
* Mon Mar 01 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.7.0-1
- updated to 1.7.0.
- updated Patch1.
- add systemd support (disabled as default).

* Mon Mar 30 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.4.0-1
- updated to 1.4.0.

* Sat Feb 24 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.3.0-1
- updated to 1.3.0.

* Mon Jan 12 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.0.8-1
- update to 1.0.8

* Fri Mar 22 2013 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.5-1
- update to 1.0.5

* Tue Apr 19 2011 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 0.55-3
- add missing BuildRequires: imake

* Sun Apr 17 2011 Shu KONNO <owa@bg.wakwak.com> 0.55-2
- rebuilt with rpm-4.8.1-3

* Fri Aug 15 2008 Shu KONNO <owa@bg.wakwak.com> 0.55-1vl5
- applied new versioning policy, spec in utf-8

* Sat Dec 16 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 0.55-0vl1
- update to irqbalance 0.55 from www.irqbalance.org
- add patch0 from svn trunk(rev.19)

* Fri Dec 15 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 0.13-0vl2
- update irqbalance.init
  - do not start irqbalance on non-SMP system.
  - do not "killproc" if irqbalance is not running.

* Thu Nov 16 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 0.13-0vl1
- new upstream release
- change Group to System Environment/Base
- add manpage

* Mon Jan 17 2005 Daisuke SUZUKI <daisuke@linux.or.jp> 0.12-0vl1
- new upstream release

* Sun Aug 29 2004 Daisuke SUZUKI <daisuke@linux.or.jp> 0.09-0vl1
- initial build for Vine Linux

* Tue Jun 01 2004 Marcel Pol <mpol@mandrake.org> 0.09-1mdk
- 0.09

* Tue Sep 09 2003 Marcel Pol <mpol@gmx.net> 0.06-1mdk
- initial mandrake contrib
Patch2: irqbalance-norebalance-zeroints.patch
Patch3: irqbalance-classes.patch
Patch4: irqbalance-oneshot.patch
