%bcond_with systemd

Summary: HA monitor built upon LVS, VRRP and services poller
Name: keepalived
Version: 2.2.4
Release: 3%{?_dist_release}%{?with_systemd:.systemd}
Group: network
Vendor: Project Vine
Distribution: Vine Linux

License: GPL
URL: http://www.keepalived.org/
Source0: https://www.keepalived.org/software/keepalived-%{version}.tar.gz
Source1: keepalived.service
Patch1000: CVE-2021-44225.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: openssl-devel
BuildRequires: libnl3-devel
BuildRequires: ipset-devel
BuildRequires: iptables-devel
BuildRequires: libnfnetlink-devel
BuildRequires: net-snmp-devel

%if %{with systemd}
BuildRequires: systemd-units
%{?systemd_requires}
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/service, /sbin/chkconfig
Requires(postun): /sbin/service
%endif

%description
The main goal of the keepalived project is to add a strong & robust keepalive
facility to the Linux Virtual Server project. This project is written in C with
multilayer TCP/IP stack checks. Keepalived implements a framework based on
three family checks : Layer3, Layer4 & Layer5/7. This framework gives the
daemon the ability to check the state of an LVS server pool. When one of the
servers of the LVS server pool is down, keepalived informs the linux kernel via
a setsockopt call to remove this server entry from the LVS topology. In
addition keepalived implements an independent VRRPv2 stack to handle director
failover. So in short keepalived is a userspace daemon for LVS cluster nodes
healthchecks and LVS directors failover.


%debug_package


%prep
%setup
%autopatch -p1


%build
%configure \
%if %{with systemd}
        --with-init=systemd \
%else
        --with-init=SYSV \
%endif
        --enable-snmp  --enable-snmp-rfc \
        --enable-sha1
%{__make} %{?_smp_mflags} STRIP=/bin/true


%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR=%{buildroot}

# Remove "samples", as we include them in %%doc
%{__rm} -rf %{buildroot}%{_sysconfdir}/keepalived/samples/

%{__rm} -rf %{buildroot}%{_docdir}/keepalived

mkdir -p %{buildroot}%{_libexecdir}/keepalived

%if %{with systemd}
rm -rf %{buildroot}%{_initrddir}/
%{__install} -p -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/keepalived.service
%endif


%clean
%{__rm} -rf %{buildroot}


%post
%if %{with systemd}
%systemd_post keepalived.service
%else
/sbin/chkconfig --add keepalived
%endif

%preun
%if %{with systemd}
%systemd_preun keepalived.service
%else
if [ $1 -eq 0 -o -x /bin/systemctl ]; then
    /sbin/service keepalived stop &>/dev/null || :
    /sbin/chkconfig --del keepalived
fi
%endif

%postun
%if %{with systemd}
%systemd_postun_with_restart keepalived.service
%else
if [ $1 -ge 1 ]; then
    /sbin/service keepalived condrestart &>/dev/null || :
fi
%endif


%files
%defattr(-, root, root, -)
%license COPYING
%doc AUTHOR ChangeLog CONTRIBUTORS README TODO
%doc doc/keepalived.conf.SYNOPSIS doc/samples/keepalived.conf.*
%attr(0755,root,root) %{_bindir}/genhash
%attr(0755,root,root) %{_sbindir}/keepalived
%attr(0644, root, root) %config(noreplace) %{_sysconfdir}/keepalived/keepalived.conf
%attr(0644, root, root) %config(noreplace) %{_sysconfdir}/sysconfig/keepalived
%if %{with systemd}
%{_unitdir}/keepalived.service
%else
%{_sysconfdir}/rc.d/init.d/keepalived
%endif
%dir %{_sysconfdir}/keepalived/
%dir %{_libexecdir}/keepalived/
%{_datadir}/snmp/mibs/*
%{_mandir}/man1/genhash.1*
%{_mandir}/man5/keepalived.conf.5*
%{_mandir}/man8/keepalived.8*


%changelog
* Tue Dec 07 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.2.4-3
- imported Patch1000 from upstream to fix CVE-2021-44225.

* Sat Oct 09 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.2.4-2
- rebuilt with openssl-3.0.0.

* Thu Aug 26 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.2.4-1
- new upstream release.

* Fri Feb 26 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.2.1-1
- new upstream release.

* Tue Sep 08 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.1.5-1
- new upstream release.

* Sun Apr 05 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.20-1
- new upstream release.
- added systemd stuff (disabled as default).

* Sun Sep 08 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.18-1
- new upstream release.

* Thu Nov 08 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.0.8-1
- new upstream release.

* Tue Mar 15 2016 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.2.19-1
- new upstream release.

* Mon Apr 08 2013 Daisuke SUZUKI <daisuke@linux.or.jp> 1.2.7-1
- initial build for Vine Linux

* Thu Sep 13 2007 Alexandre Cassen <acassen@linux-vs.org> 1.1.14
- Merge work done by freshrpms.net... Thanks guys !!! ;)

* Wed Feb 14 2007 Matthias Saou <http://freshrpms.net/> 1.1.13-5
- Add missing scriplet requirements.

* Tue Feb 13 2007 Matthias Saou <http://freshrpms.net/> 1.1.13-4
- Add missing \n to the kernel define, for when multiple kernels are installed.
- Pass STRIP=/bin/true to "make" in order to get a useful debuginfo package.

* Tue Feb 13 2007 Matthias Saou <http://freshrpms.net/> 1.1.13-3
- Add %%check section to make sure any build without LVS support will fail.

* Mon Feb  5 2007 Matthias Saou <http://freshrpms.net/> 1.1.13-2
- Use our own init script, include a sysconfig entry used by it for options.

* Thu Jan 25 2007 Matthias Saou <http://freshrpms.net/> 1.1.13-1
- Update to 1.1.13.
- Change mode of configuration file to 0600.
- Don't include all of "doc" since it meant re-including all man pages.
- Don't include samples in the main configuration path, they're in %%doc.
- Include patch to add an optional label to interfaces.

* Sat Apr 08 2006 Dries Verachtert <dries@ulyssis.org> - 1.1.12-1.2
- Rebuild for Fedora Core 5.

* Sun Mar 12 2006 Dag Wieers <dag@wieers.com> - 1.1.12-1
- Updated to release 1.1.12.

* Fri Mar 04 2005 Dag Wieers <dag@wieers.com> - 1.1.11-1
- Updated to release 1.1.11.

* Wed Feb 23 2005 Dag Wieers <dag@wieers.com> - 1.1.10-2
- Fixed IPVS/LVS support. (Joe Sauer)

* Tue Feb 15 2005 Dag Wieers <dag@wieers.com> - 1.1.10-1
- Updated to release 1.1.10.

* Mon Feb 07 2005 Dag Wieers <dag@wieers.com> - 1.1.9-1
- Updated to release 1.1.9.

* Sun Oct 17 2004 Dag Wieers <dag@wieers.com> - 1.1.7-2
- Fixes to build with kernel IPVS support. (Tim Verhoeven)

* Fri Sep 24 2004 Dag Wieers <dag@wieers.com> - 1.1.7-1
- Updated to release 1.1.7. (Mathieu Lubrano)

* Mon Feb 23 2004 Dag Wieers <dag@wieers.com> - 1.1.6-0
- Updated to release 1.1.6.

* Mon Jan 26 2004 Dag Wieers <dag@wieers.com> - 1.1.5-0
- Updated to release 1.1.5.

* Mon Dec 29 2003 Dag Wieers <dag@wieers.com> - 1.1.4-0
- Updated to release 1.1.4.

* Fri Jun 06 2003 Dag Wieers <dag@wieers.com> - 1.0.3-0
- Initial package. (using DAR)

