%global sse  -DBUILD_FOR_SSE:BOOL=OFF
%global sse2 -DBUILD_FOR_SSE2:BOOL=OFF
%ifarch x86_64
%global sse  -DBUILD_FOR_SSE:BOOL=ON
%global sse2 -DBUILD_FOR_SSE2:BOOL=ON
%endif

Name: lensfun
Version: 0.3.0
Release: 2%{?_dist_release}
Summary: Library to rectify defects introduced by photographic lenses

License: LGPLv3 and CC-BY-SA
Group: System Environment/Libraries
URL: http://lensfun.sourceforge.net/

Source0: http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2

## upstreamable patches
# install manpages only when INSTALL_HELPER_SCRIPTS=ON
Patch1: lensfun-0.3.0-INSTALL_HELPER_SCRIPTS.patch
# install manpages in the correct place
Patch2: lensfun-0.3.0-mandir.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: cmake >= 2.8
BuildRequires: doxygen
BuildRequires: glib2-devel
BuildRequires: libpng-devel
BuildRequires: pkgconfig
BuildRequires: python-docutils
BuildRequires: zlib-devel

Distribution: Vine Linux
Vendor: Project Vine
Packager: iwaim

%description
The lensfun library provides an open source database of photographic lenses and
their characteristics. It not only provides a way to read and search the
database, but also provides a set of algorithms for correcting images based on
detailed knowledge of lens properties. Right now lensfun is designed to correct
distortion, transversal (also known as lateral) chromatic aberrations,
vignetting and color contribution of a lens.

%package devel
Summary: Development toolkit for %{name}
Group:   Development/Libraries
License: LGPLv3
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig

%description devel
This package contains library and header files needed to build applications
using lensfun.

%prep
%setup -q 
%patch1 -p1 -b .INSTALL_HELPER_SCRIPTS
%patch2 -p1 -b .mandir


%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%cmake \
    -DBUILD_DOC:BOOL=ON \
    -DBUILD_TESTS:BOOL=OFF \
    -DCMAKE_BUILD_TYPE:STRING=Release \
    %{?sse} %{?sse2} \
    ..
popd

make %{?_smp_mflags} -C %{_target_platform}
make doc -C %{_target_platform}

%install
rm -rf %{buildroot}
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}

## unpackaged files
# omit cmake-installed doxygen docs, we handle that manually
rm -rfv %{buildroot}%{_docdir}/%{name}-%{version}*
# omit g-lensfun-update-data because it needs gksudo which we don't ship
rm -fv %{buildroot}%{_bindir}/g-lensfun-update-data \
    %{buildroot}%{_mandir}/man1/g-lensfun-update-data.*

%clean
rm -rf %{buildroot}


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc README
%doc docs/cc-by-sa-3.0.txt docs/lgpl-3.0.txt
%doc docs/adobe-lens-profile.txt 
%{_bindir}/*
%{_libdir}/liblensfun.so.0*
%{_datadir}/lensfun/
%{_mandir}/man1/*

%files devel
%defattr(-,root,root,-)
%doc %{_target_platform}/doc_doxygen/*
%{_includedir}/lensfun/
%{_libdir}/liblensfun.so
%{_libdir}/pkgconfig/lensfun.pc


%changelog
* Fri Sep 02 2016 Toshiaki Ara <ara_t@384.jp> 0.3.0-2
- rebuild with gcc-5.4.0

* Sun Feb  1 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 0.3.0-1
- new upstream release
- added BR: cmake

* Sun Sep  4 2011 IWAI, Masaharu <iwai@alib.jp> 0.2.5-1
- build for Vine Linux: based Fedora 0.2.5-5

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Sep 29 2010 jkeating - 0.2.5-4
- Rebuilt for gcc bug 634757

* Mon Sep 20 2010 Nils Philippsen <nils@redhat.com> 0.2.5-3
- backport cpuid fixes (#631674)

* Mon Jul 26 2010 Dan Horák <dan[at]danny.cz> 0.2.5-2
- disable SSE vectorization on non x86 arches

* Mon Jun 07 2010 Nils Philippsen <nils@redhat.com> 0.2.5-1
- lensfun-0.2.5
- add CC-BY-SA to main package license tag for lens data
- don't ship GPLv3 text as nothing is licensed under it currently
- mark documentation files as such
- shorten summaries, expand package descriptions

* Sun Oct 18 2009 Rex Dieter <rdieter@fedoraproject.orG> 0.2.4-1
- lensfun-0.2.4 (#529506)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Dec 12 2008 Rex Dieter <rdieter@fedoraproject.org> 0.2.3-3
- rebuild for pkgconfig deps

* Mon Nov 10 2008 Rex Dieter <rdieter@fedoraproject.org> 0.2.3-2
- -devel: Requires: pkgconfig

* Mon Nov 10 2008 Rex Dieter <rdieter@fedoraproject.org> 0.2.3-1
- lensfun-0.2.3
- fix SOURCE Url
- configure --target=..generic

* Mon Oct 13 2008 Rex Dieter <rdieter@fedoraproject.org> 0.2.2b-3
- BR: doxygen

* Mon Oct 13 2008 Rex Dieter <rdieter@fedoraproject.org> 0.2.2b-2
- fix subpkg deps

* Sun Sep 28 2008 Rex Dieter <rdieter@fedoraproject.org> 0.2.2b-1
- adapt for fedora

* Tue Jun 24 2008 Helio Chissini de Castro <helio@mandriva.com> 0.2.2b-1mdv2009.0
+ Revision: 228769
- Added missing buildrequires
- import lensfun
