%bcond_with systemd

%define _unpackaged_files_terminate_build 1

Summary: Userland logical volume management tools
Summary(ja): 論理ボリューム管理ツール
Name: lvm2
Version: 2.03.11
%global lvm_version %{version}
%define device_mapper_version 1.02.175
# Do not reset Release to 1 unless both lvm2 and device-mapper 
# versions are increased together.
Release: 1%{?_dist_release}%{?with_systemd:.systemd}
Group: admin-tools
Distribution: Vine Linux
Vendor: Project Vine
Packager: daisuke

License: GPLv2
URL: http://sourceware.org/lvm2/
Source0: LVM2.%{version}.tgz
Patch0: lvm2-set-default-preferred_names.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires: libaio-devel
BuildRequires: libtermcap-devel
BuildRequires: ncurses-devel
BuildRequires: readline-devel
Requires: device-mapper >= %{device_mapper_version}-%{release}
Requires: device-mapper-event >= %{device_mapper_version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
%if %{with systemd}
BuildRequires: python3
BuildRequires: python3-pyudev
BuildRequires: dbus-python3
BuildRequires: systemd-devel
BuildRequires: systemd-units
%{?systemd_requires}
%else
BuildRequires: libudev-devel
%endif
Conflicts: lvm
Obsoletes: lvm

%define _exec_prefix /usr

%description
LVM2 includes all of the support for handling read/write operations on
physical volumes (hard disks, RAID-Systems, magneto optical, etc.,
multiple devices (MD), see mdadd(8) or even loop devices, see
losetup(8)), creating volume groups (kind of virtual disks) from one
or more physical volumes and creating one or more logical volumes
(kind of logical partitions) in volume groups.


%package devel
Summary: Development libraries and headers for lvm2
Summary(ja): LVM2 の開発用ライブラリ及びヘッダファイル
Group: programming
License: LGPLv2
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
Requires: device-mapper-devel >= %{device_mapper_version}-%{release}
Requires: device-mapper-event-devel >= %{device_mapper_version}-%{release}
Requires: pkgconfig

%description devel
This package contains files needed to develop applications that use
the lvm2 libraries.


%package libs
Summary: lvm2 shared libraries
Summary(ja): LVM2 の共有ライブラリ
License: LGPLv2
Group: system

%description libs
This package contains shared lvm2 libraries for applications.


%if %{with systemd}
%package dbusd
Summary: LVM2 D-Bus daemon
Summary(ja): LVM2 D-Bus デーモン
Group: system
License: GPLv2
BuildArch: noarch
Requires: lvm2 >= %{version}-%{release}
Requires: dbus
Requires: dbus-python3
Requires: python3-pyudev
Requires: python3-pygobject
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

%description dbusd
Daemon for access to LVM2 functionality through a D-Bus interface.
%endif


# device-mapper
%package -n device-mapper
Summary: Device mapper utility
Summary(ja): Device-mapper ユーティリティ集
Version: %{device_mapper_version}
Release: %{release}
License: GPLv2
Group: system
URL: http://sources.redhat.com/dm
Requires: device-mapper-libs = %{device_mapper_version}-%{release}
Requires: eudev-libudev
Requires: util-linux-ng >= 2.15

%description -n device-mapper
This package contains the supporting userspace utility, dmsetup,
for the kernel device-mapper.


# device-mapper-devel
%package -n device-mapper-devel
Summary: Development libraries and headers for device-mapper
Summary(ja): Device-mapper の開発用ライブラリ及びヘッダファイル
Version: %{device_mapper_version}
Release: %{release}
License: LGPLv2
Group: programming
Requires: device-mapper = %{device_mapper_version}-%{release}
Requires: device-mapper-libs = %{device_mapper_version}-%{release}

%description -n device-mapper-devel
This package contains files needed to develop applications that use
the device-mapper libraries.


%package -n device-mapper-libs
Summary: Device-mapper shared library
Summary(ja): Device-mapper の共有ライブラリ
Version: %{device_mapper_version}
Release: %{release}
License: LGPLv2
Group: system
Obsoletes: device-mapper < 1.02.30-1

%description -n device-mapper-libs
This package contains the device-mapper shared library, libdevmapper.


%package -n device-mapper-event
Summary: Device-mapper event daemon
Summary(ja): Device-mapper イベントデーモン
Version: %{device_mapper_version}
Release: %{release}
Group: system
Requires: device-mapper = %{device_mapper_version}-%{release}
Requires: device-mapper-event-libs = %{device_mapper_version}-%{release}

%description -n device-mapper-event
This package contains the dmeventd daemon for monitoring the state
of device-mapper devices.


%package -n device-mapper-event-libs
Summary: Device-mapper event daemon shared library
Summary(ja): Device-mapper イベントデーモン共有ライブラリ
Version: %{device_mapper_version}
Release: %{release}
Group: system
License: LGPLv2

%description -n device-mapper-event-libs
This package contains the device-mapper event daemon shared library,
libdevmapper-event.


%package -n device-mapper-event-devel
Summary: Development libraries and headers for the device-mapper event daemon
Summary(ja): Device-mapper イベントデーモンの開発用ライブラリ及びヘッダファイル
Version: %{device_mapper_version}
Release: %{release}
Group: programming
License: LGPLv2
Requires: device-mapper-event = %{device_mapper_version}-%{release}
Requires: pkgconfig

%description -n device-mapper-event-devel
This package contains files needed to develop applications that use
the device-mapper event library.


%debug_package


%prep
%setup -q -n LVM2.%{lvm_version}
%patch0 -p1 -b .preferred_names


%build
%define _exec_prefix /
%define _bindir /bin
%define _sbindir /sbin
%define _libdir /%{_lib}
%define _udevbasedir /lib/udev
%define _udevdir %{_udevbasedir}/rules.d
%if %{with systemd}
%global _default_pid_dir /run
%global _default_dm_run_dir /run
%global _default_run_dir /run/lvm
%global _default_locking_dir /run/lock/lvm
%endif

%configure \
  --enable-readline \
  --enable-lvm1_fallback \
  --enable-fsadm \
  --with-pool=internal \
  --with-staticdir=/sbin \
  --with-user= --with-group= \
  --with-usrlibdir=/usr/%{_lib} \
  --with-usrsbindir=/usr/sbin \
  --with-dmdir=device-mapper.%{device_mapper_version} \
  --with-udevdir=%{_udevdir} \
  --with-device-uid=0 --with-device-gid=6 \
  --with-device-mode=0660 \
  --enable-pkgconfig \
  --enable-applib \
  --enable-cmdlib \
  --enable-dmeventd \
  --enable-udev_sync \
%if %{with systemd}
  --with-default-dm-run-dir=%{_default_dm_run_dir} \
  --with-default-run-dir=%{_default_run_dir} \
  --with-default-pid-dir=%{_default_pid_dir} \
  --with-default-locking-dir=%{_default_locking_dir} \
  --enable-dmfilemapd \
  --enable-lvmpolld \
  --enable-dbus-service --enable-notify-dbus \
  --with-cache=internal \
  --with-writecache=internal \
  --with-vdo=internal --with-vdo-format=%{_bindir}/vdoformat \
%endif
  --disable-silent-rules

make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
%if %{with systemd}
make install_system_dirs DESTDIR=$RPM_BUILD_ROOT
make install_systemd_units DESTDIR=$RPM_BUILD_ROOT
make install_systemd_generators DESTDIR=$RPM_BUILD_ROOT
make install_tmpfiles_configuration DESTDIR=$RPM_BUILD_ROOT
%else
mkdir -p -m755 $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m 0755 scripts/lvm2_monitoring_init_red_hat $RPM_BUILD_ROOT/etc/rc.d/init.d/lvm2-monitor
%endif

install -m 0700 -d $RPM_BUILD_ROOT/etc/lvm/archive
install -m 0700 -d $RPM_BUILD_ROOT/etc/lvm/backup
install -m 0700 -d $RPM_BUILD_ROOT/etc/lvm/cache
install -m 0700 -d $RPM_BUILD_ROOT/var/lock/lvm
install -m 0600 /dev/null $RPM_BUILD_ROOT/etc/lvm/cache/.cache


%clean
rm -rf $RPM_BUILD_ROOT


%post
/sbin/ldconfig
%if %{with systemd}
%systemd_post blk-availability.service lvm2-monitor.service
if [ "$1" = "1" ] ; then
    # FIXME: what to do with this? We do not want to start it in a container/chroot
    # enable and start lvm2-monitor.service on completely new installation only, not on upgrades
    systemctl enable lvm2-monitor.service
    systemctl start lvm2-monitor.service >/dev/null 2>&1 || :
fi
%systemd_post lvm2-lvmpolld.socket
# lvm2-lvmpolld socket is always enabled and started and ready to serve if lvmpolld is used
# replace direct systemctl calls with systemd rpm macro once this is provided in the macro:
# http://cgit.freedesktop.org/systemd/systemd/commit/?id=57ab2eabb8f92fad5239c7d4492e9c6e23ee0678
systemctl enable lvm2-lvmpolld.socket
systemctl start lvm2-lvmpolld.socket >/dev/null 2>&1 || :
%else
/sbin/chkconfig --add lvm2-monitor
%endif

%preun
%if %{with systemd}
%systemd_preun blk-availability.service lvm2-monitor.service
%systemd_preun lvm2-lvmpolld.service lvm2-lvmpolld.socket
%else
if [ "$1" = 0 -o -x /bin/systemctl ]; then
	/sbin/chkconfig --del lvm2-monitor
fi
%endif

%if %{with systemd}
%postun
%systemd_postun lvm2-monitor.service
%systemd_postun_with_restart lvm2-lvmpolld.service
%endif

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%if %{with systemd}
%post dbusd
%systemd_post lvm2-lvmdbusd.service

%preun dbusd
%systemd_preun lvm2-lvmdbusd.service

%postun dbusd
%systemd_postun lvm2-lvmdbusd.service

%post -n device-mapper-event
%systemd_post dm-event.socket
# dm-event.socket is always enabled and started and ready to serve if dmeventd is used
# replace direct systemctl calls with systemd rpm macro once this is provided in the macro:
# http://cgit.freedesktop.org/systemd/systemd/commit/?id=57ab2eabb8f92fad5239c7d4492e9c6e23ee0678
systemctl enable dm-event.socket
systemctl start dm-event.socket >/dev/null 2>&1 || :
if [ -e %{_default_pid_dir}/dmeventd.pid ]; then
        %{_sbindir}/dmeventd -R || echo "Failed to restart dmeventd daemon. Please, try manual restart."
fi

%preun -n device-mapper-event
%systemd_preun dm-event.service dm-event.socket
%endif

%post -n device-mapper-libs -p /sbin/ldconfig

%postun -n device-mapper-libs -p /sbin/ldconfig

%post -n device-mapper-event-libs -p /sbin/ldconfig

%postun -n device-mapper-event-libs -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%license COPYING COPYING.LIB
%doc INSTALL README VERSION WHATS_NEW
%attr(555,root,root) %{_sbindir}/fsadm
%{_sbindir}/lvchange
%{_sbindir}/lvconvert
%{_sbindir}/lvcreate
%{_sbindir}/lvdisplay
%{_sbindir}/lvextend
%{_sbindir}/lvm
%{_sbindir}/lvmconfig
%{_sbindir}/lvmdiskscan
%{_sbindir}/lvmdump
%{_sbindir}/lvmsadc
%{_sbindir}/lvmsar
%{_sbindir}/lvreduce
%{_sbindir}/lvremove
%{_sbindir}/lvrename
%{_sbindir}/lvresize
%{_sbindir}/lvs
%{_sbindir}/lvscan
%{_sbindir}/pvchange
%{_sbindir}/pvck
%{_sbindir}/pvcreate
%{_sbindir}/pvdisplay
%{_sbindir}/pvmove
%{_sbindir}/pvremove
%{_sbindir}/pvresize
%{_sbindir}/pvs
%{_sbindir}/pvscan
%{_sbindir}/vgcfgbackup
%{_sbindir}/vgcfgrestore
%{_sbindir}/vgchange
%{_sbindir}/vgck
%{_sbindir}/vgconvert
%{_sbindir}/vgcreate
%{_sbindir}/vgdisplay
%{_sbindir}/vgexport
%{_sbindir}/vgextend
%{_sbindir}/vgimport
%{_sbindir}/vgimportclone
%{_sbindir}/vgmerge
%{_sbindir}/vgmknodes
%{_sbindir}/vgreduce
%{_sbindir}/vgremove
%{_sbindir}/vgrename
%{_sbindir}/vgs
%{_sbindir}/vgscan
%{_sbindir}/vgsplit
%{_mandir}/man5/lvm.conf.5.gz
%{_mandir}/man7/lvmcache.7.gz
%{_mandir}/man7/lvmraid.7.gz
%{_mandir}/man7/lvmreport.7.gz
%{_mandir}/man7/lvmsystemid.7.gz
%{_mandir}/man7/lvmthin.7.gz
%{_mandir}/man7/lvmvdo.7.gz
%{_mandir}/man8/fsadm.8.gz
%{_mandir}/man8/lvchange.8.gz
%{_mandir}/man8/lvconvert.8.gz
%{_mandir}/man8/lvcreate.8.gz
%{_mandir}/man8/lvdisplay.8.gz
%{_mandir}/man8/lvextend.8.gz
%{_mandir}/man8/lvm.8.gz
%{_mandir}/man8/lvm-config.8.gz
%{_mandir}/man8/lvm-dumpconfig.8.gz
%{_mandir}/man8/lvm-fullreport.8.gz
%{_mandir}/man8/lvm-lvpoll.8.gz
%{_mandir}/man8/lvmconfig.8.gz
%{_mandir}/man8/lvmdiskscan.8.gz
%{_mandir}/man8/lvmdump.8.gz
%{_mandir}/man8/lvmsadc.8.gz
%{_mandir}/man8/lvmsar.8.gz
%{_mandir}/man8/lvreduce.8.gz
%{_mandir}/man8/lvremove.8.gz
%{_mandir}/man8/lvrename.8.gz
%{_mandir}/man8/lvresize.8.gz
%{_mandir}/man8/lvs.8.gz
%{_mandir}/man8/lvscan.8.gz
%{_mandir}/man8/pvchange.8.gz
%{_mandir}/man8/pvck.8.gz
%{_mandir}/man8/pvcreate.8.gz
%{_mandir}/man8/pvdisplay.8.gz
%{_mandir}/man8/pvmove.8.gz
%{_mandir}/man8/pvremove.8.gz
%{_mandir}/man8/pvresize.8.gz
%{_mandir}/man8/pvs.8.gz
%{_mandir}/man8/pvscan.8.gz
%{_mandir}/man8/vgcfgbackup.8.gz
%{_mandir}/man8/vgcfgrestore.8.gz
%{_mandir}/man8/vgchange.8.gz
%{_mandir}/man8/vgck.8.gz
%{_mandir}/man8/vgconvert.8.gz
%{_mandir}/man8/vgcreate.8.gz
%{_mandir}/man8/vgdisplay.8.gz
%{_mandir}/man8/vgexport.8.gz
%{_mandir}/man8/vgextend.8.gz
%{_mandir}/man8/vgimport.8.gz
%{_mandir}/man8/vgimportclone.8.gz
%{_mandir}/man8/vgmerge.8.gz
%{_mandir}/man8/vgmknodes.8.gz
%{_mandir}/man8/vgreduce.8.gz
%{_mandir}/man8/vgremove.8.gz
%{_mandir}/man8/vgrename.8.gz
%{_mandir}/man8/vgs.8.gz
%{_mandir}/man8/vgscan.8.gz
%{_mandir}/man8/vgsplit.8.gz
%{_udevdir}/11-dm-lvm.rules
%{_udevdir}/69-dm-lvm-metad.rules
%dir /etc/lvm
%ghost /etc/lvm/cache/.cache
%config(noreplace) /etc/lvm/lvm.conf
%config(noreplace) /etc/lvm/lvmlocal.conf
%dir /etc/lvm/backup
%dir /etc/lvm/cache
%dir /etc/lvm/archive
%dir /var/lock/lvm
%dir /etc/lvm/profile
/etc/lvm/profile/*.profile
%if %{with systemd}
%{_sbindir}/lvmpolld
%{_mandir}/man8/lvmpolld.8*
%{_mandir}/man8/lvm2-activation-generator.8*
%{_tmpfilesdir}/lvm2.conf
%{_unitdir}/blk-availability.service
%{_unitdir}/lvm2-lvmpolld.service
%{_unitdir}/lvm2-lvmpolld.socket
%{_unitdir}/lvm2-monitor.service
%{_unitdir}/lvm2-pvscan@.service
%attr(555, -, -) /lib/systemd/system-generators/lvm2-activation-generator
%else
/etc/rc.d/init.d/lvm2-monitor
%endif

%files devel
%defattr(-,root,root,-)
/usr%{_libdir}/liblvm2cmd.so
%{_includedir}/lvm2cmd.h
/usr%{_libdir}/libdevmapper-event-lvm2.so

%files libs
%attr(755,root,root) %{_libdir}/liblvm2cmd.so.*
%attr(755,root,root) %{_libdir}/libdevmapper-event-lvm2.so.*
%dir %{_libdir}/device-mapper
%{_libdir}/device-mapper/libdevmapper-event-lvm2mirror.so
%{_libdir}/device-mapper/libdevmapper-event-lvm2snapshot.so
%{_libdir}/device-mapper/libdevmapper-event-lvm2raid.so
%{_libdir}/device-mapper/libdevmapper-event-lvm2thin.so
%{_libdir}/device-mapper/libdevmapper-event-lvm2vdo.so
%{_libdir}/libdevmapper-event-lvm2mirror.so
%{_libdir}/libdevmapper-event-lvm2snapshot.so
%{_libdir}/libdevmapper-event-lvm2raid.so
%{_libdir}/libdevmapper-event-lvm2thin.so
%{_libdir}/libdevmapper-event-lvm2vdo.so

%if %{with systemd}
%files dbusd
%defattr(555,root,root,-)
%{_sbindir}/lvmdbusd
%defattr(444,root,root,-)
%{_sysconfdir}/dbus-1/system.d/com.redhat.lvmdbus1.conf
%{_datadir}/dbus-1/system-services/com.redhat.lvmdbus1.service
%{_mandir}/man8/lvmdbusd.8*
%{_unitdir}/lvm2-lvmdbusd.service
%dir %{python3_sitelib}/lvmdbusd
%{python3_sitelib}/lvmdbusd/*
%endif

%files -n device-mapper
%defattr(-,root,root,-)
%license COPYING COPYING.LIB
%doc WHATS_NEW_DM VERSION_DM README INSTALL udev/12-dm-permissions.rules
%attr(755,root,root) /sbin/blkdeactivate
%attr(755,root,root) /sbin/dmsetup
/sbin/dmstats
%{_mandir}/man8/blkdeactivate.8.gz
%{_mandir}/man8/dmsetup.8.gz
%{_mandir}/man8/dmstats.8.gz
%dir %{_udevbasedir}
%dir %{_udevdir}
%{_udevdir}/10-dm.rules
%{_udevdir}/13-dm-disk.rules
%{_udevdir}/95-dm-notify.rules
%if %{with systemd}
/sbin/dmfilemapd
%{_mandir}/man8/dmfilemapd.8*
%endif

%files -n device-mapper-devel
%defattr(-,root,root,-)
/usr%{_libdir}/libdevmapper.so
%{_includedir}/libdevmapper.h
/usr%{_libdir}/pkgconfig/devmapper.pc

%files -n device-mapper-libs
%attr(755,root,root) %{_libdir}/libdevmapper.so.*

%files -n device-mapper-event
%defattr(-,root,root,-)
%{_sbindir}/dmeventd
%{_mandir}/man8/dmeventd.8.gz
%if %{with systemd}
%{_unitdir}/dm-event.service
%{_unitdir}/dm-event.socket
%endif

%files -n device-mapper-event-libs
%{_libdir}/libdevmapper-event.so.*

%files -n device-mapper-event-devel
%defattr(-,root,root,-)
/usr%{_libdir}/libdevmapper-event.so
%{_includedir}/libdevmapper-event.h
/usr%{_libdir}/pkgconfig/devmapper-event.pc

%changelog
* Thu Apr 08 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.03.11-1
- new upstream release.

* Wed May 20 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.03.09-2
- added systemd support (disabled as default).

* Sun Mar 29 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.03.09-1
- new upstream release.
- dropped Patch1, 2 and 10.

* Sat Feb 24 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 2.02.177-1
- updated to 2.02.177
- dropped Patch2: fixed in upstream.
- imported Patch1 and 2 from rawhide.

* Mon Jul 14 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 2.02.107-1
- add patch20 to fix duplicate 'const' in libdevmapper.h

* Mon Jul 07 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 2.02.107-1
- update to 2.02.107

* Tue Jun 17 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.02.98-3
- change BuildRequires: eudev-libudev-devel instead of libudev-devel

* Tue Dec 11 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.98-2
- add missing files to %%files

* Thu Nov 29 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.98-1
- new upstream release

* Mon Mar 21 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.84-1
- new upstream release
- enable static libs, add device-mapper-static subpackage

* Sat Feb 05 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.83-1
- new upstream release

* Sat Dec 25 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.02.79-1
- new upstream release

* Thu Dec 09 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.02.78-1
- new upstream release
- fix %%files

* Fri Oct 01 2010 Shu KONNO <owa@bg.wakwak.com> 2.02.62-3
- rebuilt with rpm-4.8.1 for pkg-config

* Sun Apr 11 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.62-2
- add missing file
  - %{_udevdir}/11-dm-lvm.rules

* Mon Mar 29 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.62-1
- new upstream release
- add libs,devel subpackage
  - liblvm2{app,cmd},libdevmapper-event-lvm2
- enable dmeventd
  - add device-mapper-event{,-libs,-devel}
- enable udev sync code
  - add BR: libudev-devel, R: libudev
- disable static libs and binaries

* Sun Feb 14 2010 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 2.02.60-1
- new upstream release

* Thu Jul 02 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.48-1
- new upstream release

* Tue Jun 02 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.47-1
- new upstream release

* Wed Feb 25 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.44-2
- add libdevmapper.a

* Thu Jan 29 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.44-1
- new upstream release
- upstream merge of device-mapper and lvm2 source.
- move all binaries to /sbin
- move libraries to /%%{_lib}

* Wed Oct 29 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.42-1
- new upstream release

* Sun Oct 19 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.41-1
- new upstream release

* Sat Sep 20 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.40-1
- new upstream release

* Sun Jul 06 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.39-1
- new upstream release

* Thu Jun 12 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.38-1
- new upstream release

* Thu Apr 17 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.35-1
- new upstream release

* Sat Dec 01 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.28-0vl1
- new upstream release

* Wed Nov 01 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.13-0vl1
- new upstream release

* Sat Aug 19 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 2.02.06-0vl1
- initial build for Vine Linux

* Tue Aug  1 2006 Jeremy Katz <katzj@redhat.com> - 2.02.06-3
- require new libselinux to avoid segfaults on xen (#200783)

* Thu Jul 27 2006 Jeremy Katz <katzj@redhat.com> - 2.02.06-2
- free trip through the buildsystem

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 2.02.06-1.2.1
- rebuild

* Tue Jun  6 2006 Stephen C. Tweedie <sct@redhat.com> - 2.02.06-1.2
- Rebuild to pick up new nosegneg libc.a for lvm.static

* Mon May 22 2006 Alasdair Kergon <agk@redhat.com> - 2.02.06-1.1
- Reinstate archs now build system is back.
- BuildRequires libsepol-devel.

* Fri May 12 2006 Alasdair Kergon <agk@redhat.com> - 2.02.06-1.0
- New upstream release.

* Sat Apr 22 2006 Alasdair Kergon <agk@redhat.com> - 2.02.05-1.1
- Exclude archs that aren't building.

* Fri Apr 21 2006 Alasdair Kergon <agk@redhat.com> - 2.02.05-1.0
- Fix VG uuid comparisons.

* Wed Apr 19 2006 Alasdair Kergon <agk@redhat.com> - 2.02.04-1.0
- New release upstream, including better handling of duplicated VG names.

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 2.02.01-1.2.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 2.02.01-1.2
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Fri Dec  2 2005 Peter Jones <pjones@redhat.com> - 2.02.01-1
- update to 2.02.01

* Tue Nov  8 2005 Jeremy Katz <katzj@redhat.com> - 2.01.14-4
- add patch for xen block devices

* Sat Oct 15 2005 Florian La Roche <laroche@redhat.com>
- add -lselinux -lsepol to the static linking -ldevice-mapper requires it

* Wed Sep 14 2005 Jeremy Katz <katzj@redhat.com> - 2.01.14-2
- the distro doesn't really work without a 2.6 kernel, so no need to require it

* Thu Aug 4 2005 Alasdair Kergon <agk@redhat.com> - 2.01.14-1.0
- And a few more bugs fixes.

* Wed Jul 13 2005 Alasdair Kergon <agk@redhat.com> - 2.01.13-1.0
- Fix several bugs discovered in the last release.

* Tue Jun 14 2005 Alasdair Kergon <agk@redhat.com> - 2.01.12-1.0
- New version upstream with a lot of fixes and enhancements.

* Wed Apr 27 2005 Alasdair Kergon <agk@redhat.com> - 2.01.08-2.1
- Add /etc/lvm

* Wed Apr 27 2005 Alasdair Kergon <agk@redhat.com> - 2.01.08-2.0
- No longer abort read operations if archive/backup directories aren't there.
- Add runtime directories and file to the package.

* Tue Mar 22 2005 Alasdair Kergon <agk@redhat.com> - 2.01.08-1.0
- Improve detection of external changes affecting internal cache.
- Add clustered VG attribute.
- Suppress rmdir opendir error message.

* Tue Mar 08 2005 Alasdair Kergon <agk@redhat.com> - 2.01.07-1.3
* Tue Mar 08 2005 Alasdair Kergon <agk@redhat.com> - 2.01.07-1.2
* Tue Mar 08 2005 Alasdair Kergon <agk@redhat.com> - 2.01.07-1.1
- Suppress some new compiler messages.

* Tue Mar 08 2005 Alasdair Kergon <agk@redhat.com> - 2.01.07-1.0
- Remove build directory from built-in path.
- Extra /dev scanning required for clustered operation.

* Thu Mar 03 2005 Alasdair Kergon <agk@redhat.com> - 2.01.06-1.0
- Allow anaconda to suppress warning messages.

* Fri Feb 18 2005 Alasdair Kergon <agk@redhat.com> - 2.01.05-1.0
- Upstream changes not affecting Fedora.

* Wed Feb 09 2005 Alasdair Kergon <agk@redhat.com> - 2.01.04-1.0
- Offset pool minors; lvm2cmd.so skips open fd check; pvmove -f gone.

* Tue Feb 01 2005 Alasdair Kergon <agk@redhat.com> - 2.01.03-1.0
- Fix snapshot device size & 64-bit display output.

* Fri Jan 21 2005 Alasdair Kergon <agk@redhat.com> - 2.01.02-1.0
- Minor fixes.

* Mon Jan 17 2005 Alasdair Kergon <agk@redhat.com> - 2.01.01-1.0
- Update vgcreate man page.  Preparation for snapshot origin extension fix.

* Mon Jan 17 2005 Alasdair Kergon <agk@redhat.com> - 2.01.00-1.0
- Fix metadata auto-correction. Only request open_count when needed.

* Wed Jan 12 2005 Tim Waugh <twaugh@redhat.com> - 2.00.33-2.0
- Rebuilt for new readline.

* Fri Jan 7 2005 Alasdair Kergon <agk@redhat.com> - 2.00.33-1.0
- pvcreate wipes ext label
- several clvm fixes

* Thu Jan 6 2005 Alasdair Kergon <agk@redhat.com> - 2.00.32-2.0
- Remove temporary /sbin symlinks no longer needed.
- Include read-only pool support in the build.

* Wed Dec 22 2004 Alasdair Kergon <agk@redhat.com> - 2.00.32-1.0
- More fixes (143501).

* Sun Dec 12 2004 Alasdair Kergon <agk@redhat.com> - 2.00.31-1.0
- Fix pvcreate install issues.

* Fri Dec 10 2004 Alasdair Kergon <agk@redhat.com> - 2.00.30-1.0
- Additional debugging code.
- Some trivial man page corrections.

* Tue Nov 30 2004 Alasdair Kergon <agk@redhat.com> - 2.00.29-1.3
- Reinstate all archs.

* Sun Nov 28 2004 Alasdair Kergon <agk@redhat.com> - 2.00.29-1.2
- Try excluding more archs.

* Sat Nov 27 2004 Alasdair Kergon <agk@redhat.com> - 2.00.29-1.1
- Exclude s390x which fails.

* Sat Nov 27 2004 Alasdair Kergon <agk@redhat.com> - 2.00.29-1
- Fix last fix.

* Sat Nov 27 2004 Alasdair Kergon <agk@redhat.com> - 2.00.28-1
- Endian fix to partition/md signature detection.

* Wed Nov 24 2004 Alasdair Kergon <agk@redhat.com> - 2.00.27-1
- Fix partition table detection & an out of memory segfault.

* Tue Nov 23 2004 Alasdair Kergon <agk@redhat.com> - 2.00.26-1
- Several installation-related fixes & man page updates.

* Mon Oct 25 2004 Elliot Lee <sopwith@redhat.com> - 2.00.25-1.01
- Fix 2.6 kernel requirement

* Wed Sep 29 2004 Alasdair Kergon <agk@redhat.com> - 2.00.25-1
- Fix vgmknodes return code & vgremove locking.

* Fri Sep 17 2004 Alasdair Kergon <agk@redhat.com> - 2.00.24-2
- Obsolete old lvm1 packages; refuse install if running kernel 2.4. [bz 128185]

* Thu Sep 16 2004 Alasdair Kergon <agk@redhat.com> - 2.00.24-1
- More upstream fixes.  (Always check WHATS_NEW file for details.)
- Add requested BuildRequires. [bz 124916, 132408]

* Wed Sep 15 2004 Alasdair Kergon <agk@redhat.com> - 2.00.23-1
- Various minor upstream fixes.

* Fri Sep  3 2004 Alasdair Kergon <agk@redhat.com> - 2.00.22-1
- Permission fix included upstream; use different endian conversion macros.

* Thu Sep  2 2004 Jeremy Katz <katzj@redhat.com> - 2.00.21-2
- fix permissions on vg dirs

* Thu Aug 19 2004 Alasdair Kergon <agk@redhat.com> - 2.00.21-1
- New upstream release incorporating fixes plus minor enhancements.

* Tue Aug 17 2004 Jeremy Katz <katzj@redhat.com> - 2.00.20-2
- add patch for iSeries viodasd support
- add patch to check file type using stat(2) if d_type == DT_UNKNOWN (#129674)

* Sat Jul 3 2004 Alasdair Kergon <agk@redhat.com> - 2.00.20-1
- New upstream release fixes 2.6 kernel device numbers.

* Tue Jun 29 2004 Alasdair Kergon <agk@redhat.com> - 2.00.19-1
- Latest upstream release.  Lots of changes (see WHATS_NEW).

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com> - 2.00.15-5
- rebuilt

* Wed May 26 2004 Alasdair Kergon <agk@redhat.com> - 2.00.15-4
- clone %description from LVM rpm

* Wed May 26 2004 Alasdair Kergon <agk@redhat.com> - 2.00.15-3
- vgscan shouldn't return error status when no VGs present

* Thu May 06 2004 Warren Togami <wtogami@redhat.com> - 2.00.15-2
- i2o patch from Markus Lidel

* Tue Apr 20 2004 Bill Nottingham <notting@redhat.com> - 2.00.15-1.1
- handle disabled SELinux correctly, so that LVMs can be detected in a
  non-SELinux context
  
* Mon Apr 19 2004 Alasdair Kergon <agk@redhat.com> - 2.00.15-1
- Fix non-root build with current version of 'install'.

* Fri Apr 16 2004 Alasdair Kergon <agk@redhat.com> - 2.00.14-1
- Use 64-bit file offsets.

* Fri Apr 16 2004 Alasdair Kergon <agk@redhat.com> - 2.00.13-1
- Avoid scanning devices containing md superblocks.
- Integrate ENOTSUP patch.

* Thu Apr 15 2004 Jeremy Katz <katzj@redhat.com> - 2.00.12-4
- don't die if we get ENOTSUP setting selinux contexts

* Thu Apr 15 2004 Alasdair Kergon <agk@redhat.com> 2.00.12-3
- Add temporary pvscan symlink for LVM1 until mkinitrd gets updated.

* Wed Apr 14 2004 Alasdair Kergon <agk@redhat.com> 2.00.12-2
- Mark config file noreplace.

* Wed Apr 14 2004 Alasdair Kergon <agk@redhat.com> 2.00.12-1
- Install default /etc/lvm/lvm.conf.
- Move non-static binaries to /usr/sbin.
- Add temporary links in /sbin to lvm.static until rc.sysinit gets updated.

* Thu Apr 08 2004 Alasdair Kergon <agk@redhat.com> 2.00.11-1
- Fallback to using LVM1 tools when using a 2.4 kernel without device-mapper.

* Wed Apr 07 2004 Alasdair Kergon <agk@redhat.com> 2.00.10-2
- Install the full toolset, not just 'lvm'.

* Wed Apr 07 2004 Alasdair Kergon <agk@redhat.com> 2.00.10-1
- Update to version 2.00.10, which incorporates the RH-specific patches
  and includes various fixes and enhancements detailed in WHATS_NEW.

* Wed Mar 17 2004 Jeremy Katz <katzj@redhat.com> 2.00.08-5
- Fix sysfs patch to find sysfs
- Take patch from dwalsh and tweak a little for setting SELinux contexts on
  device node creation and also do it on the symlink creation.  
  Part of this should probably be pushed down to device-mapper instead

* Thu Feb 19 2004 Stephen C. Tweedie <sct@redhat.com> 2.00.08-4
- Add sysfs filter patch
- Allow non-root users to build RPM

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Dec  5 2003 Jeremy Katz <katzj@redhat.com> 2.00.08-2
- add static lvm binary

* Tue Dec  2 2003 Jeremy Katz <katzj@redhat.com> 
- Initial build.


