%define build_compat32 %{?_with_compat32:1}%{!?_with_compat32:0}
%define snap 20210910

Summary:	The NetBSD Editline library
Summary(ja):	NetBSD Editline ライブラリ
Name:		libedit
Version:	3.1
Release:	7.%{snap}%{?_dist_release}
Group:		system

License:	BSD
URL:		http://thrysoee.dk/editline/
Source0:	http://thrysoee.dk/editline/%{name}-%{snap}-%{version}.tar.gz
# Version 20210419 changes internal symbols named libedit_strlcat and
# libedit_strlcpy to plain strlcat and strlcpy.  None of those symbols are
# mentioned in the public header files.  Many projects check for the existence
# of functions named strlcat and strlcpy.  I am not prepared to deal with the
# possible fallout of those functions suddenly existing in a low-level Fedora
# library, so restore the old names for now.
Patch0:         %{name}-strlcat.patch

BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires:	gawk
BuildRequires:	ncurses-devel

%description
Libedit is an autotool- and libtoolized port of the NetBSD Editline library.
It provides generic line editing, history, and tokenization functions, similar
to those found in GNU Readline.


%package devel
Summary:	Development files for %{name}
Summary(ja):	%{name} の開発ファイル
Group:		programming

Requires:	%{name} = %{version}-%{release}
Requires:	pkgconfig
Requires:	ncurses-devel

%description devel
This package contains development files for %{name}.


%package -n compat32-%{name}
Summary:	The NetBSD Editline library
Summary(ja):	NetBSD Editline ライブラリ
Group:		system,legacy
Requires: 	%{name} = %{version}-%{release}

%description -n compat32-%{name}
Libedit is an autotool- and libtoolized port of the NetBSD Editline library.
It provides generic line editing, history, and tokenization functions, similar
to those found in GNU Readline.


%package -n compat32-%{name}-devel
Summary:	Development files for %{name}
Summary(ja):	%{name} の開発ファイル
Group:		programming,legacy
Requires: 	%{name}-devel = %{version}-%{release}
Requires: 	compat32-%{name} = %{version}-%{release}
Requires: 	compat32-pkgconfig
Requires: 	compat32-ncurses-devel

%description -n compat32-%{name}-devel
This package contains development files for %{name}.


%debug_package


%prep
%setup -q -n %{name}-%{snap}-%{version}
%autopatch -p0

# Fix unused direct shared library dependencies.
sed -i "s/lncurses/ltinfo/" configure

# Suppress rpmlint error.
iconv --from-code ISO8859-1 --to-code UTF-8 ./ChangeLog \
  --output ChangeLog.utf-8 && mv ChangeLog.utf-8 ./ChangeLog


%build
%configure --disable-static --disable-silent-rules

# Trying to omit unused direct shared library dependencies leads to
# undefined non-weak symbols.

make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT

make install INSTALL="%{__install} -p" DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -type f -name "*.la" -delete

%__mv $RPM_BUILD_ROOT%{_mandir}/man3/history.3 $RPM_BUILD_ROOT%{_mandir}/man3/history_libedit.3


%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%license COPYING
%doc ChangeLog THANKS
%{_libdir}/%{name}.so.*
%{_mandir}/man5/editrc.5*
%{_mandir}/man7/editline.7*

%files devel
%defattr(-,root,root,-)
%doc examples/*.c 
%{_includedir}/histedit.h
%dir %{_includedir}/editline
%{_includedir}/editline/readline.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/*

%if %{build_compat32}
%files -n compat32-%{name}
%defattr(-,root,root)
%{_libdir}/%{name}.so.*

%files -n compat32-%{name}-devel
%defattr(-,root,root)
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%endif


%changelog
* Sun Oct 17 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 3.1-7.20210910
- updated to 3.1-20210910.

* Wed Sep 01 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 3.1-6.20210714
- updated to 3.1-20210714.
- dropped ldconfig scriptlets.

* Sun Feb 21 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 3.1-5.20210216
- updated to 3.1-20210216.

* Fri Mar 27 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 3.1-4.20191231
- updated to 3.1-20191231.

* Fri Feb 02 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 3.1-3.20170329
- updated to 3.1-20170329.

* Wed Mar 29 2017 IWAI, Masaharu <iwaim.sub@gmail.com> 3.1-2.20160903
- update to 20160903 snap
- drop SIGWINCH patch (Patch1); upstream fixed
- move editrc.5 to main package
- add editline.7

* Tue Mar 24 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 3.1-2.20140620
- added compat32 subpackage

* Sun Jul 06 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.1-1.20140620
- update to 20140620 snap

* Sat Nov 03 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.0-4.20120601
- update to 20120601 snap

* Sun Jan 16 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 3.0-3.20100424
- add --enable-widec to support wide-chat/UTF-8

* Sun Sep 26 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 3.0-2.20100424
- rebuild with rpm-4.8.1 for pkg-config file

* Wed May 19 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 	3.0-1.20100424
- initial build for Vine Linux
- update to 20100424 snap

* Tue Mar 30 2010 Kamil Dudka <kdudka@redhat.com> 3.0-2.20090923cvs
- eliminated compile-time warnings
- fix to not break the read loop on SIGWINCH, patch contributed
  by Edward Sheldrake (#575383)

* Fri Nov 27 2009 Tom "spot" Callaway <tcallawa@redhat.com> 3.0-1.20090923cvs
- Update to 3.0 (20090923 snap)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.11-4.20080712cvs
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.11-3.20080712cvs
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jan 22 2009 Jeffrey C. Ollie <jeff@ocjtech.us> - 2.11-2.20080712cvs
- Add ncurses-devel requires to -devel subpackage (BZ#481252)

* Mon Jul 28 2008 Debarshi Ray <rishi@fedoraproject.org> - 2.11-1.20080712cvs
- Version bump to 20080712-2.11.

* Sat Feb 16 2008 Debarshi Ray <rishi@fedoraproject.org> - 2.10-4.20070831cvs
- Rebuilding with gcc-4.3 in Rawhide.

* Sun Nov 04 2007 Debarshi Ray <rishi@fedoraproject.org> - 2.10-3.20070831cvs
- Removed 'Requires: ncurses-devel'.

* Sat Nov 03 2007 Debarshi Ray <rishi@fedoraproject.org> - 2.10-2.20070831cvs
- Changed character encoding of ChangeLog from ISO8859-1 to UTF-8.

* Mon Sep 03 2007 Debarshi Ray <rishi@fedoraproject.org> - 2.10-1.20070831cvs
- Initial build. Imported SPEC from Rawhide.
