%define build_compat32 %{?_with_compat32:1}%{!?_with_compat32:0}
# Disable static library creation by default.
%define with_static 0

Name: libidn
Summary: Internationalized Domain Name support library
Summary(ja): 国際化ドメイン名をサポートするためのライブラリ
Version: 1.38
Release: 1%{?_dist_release}
Group: system
Distribution: Vine Linux
Vendor: Project Vine

License: GPLv3+ and LGPLv3+
URL: https://www.gnu.org/software/libidn/
Source0: https://ftp.gnu.org/gnu/libidn/libidn-%{version}.tar.gz

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: gettext
BuildRequires: pkgconfig
Requires(post): /sbin/install-info
Requires(preun): /sbin/install-info

%global __provides_exclude_from ^%{_libdir}/pkgconfig/.*$

%description
GNU Libidn is an implementation of the Stringprep, Punycode and
IDNA specifications defined by the IETF Internationalized Domain
Names (IDN) working group, used for internationalized domain
names.


%package devel
Summary: Development files for the libidn library
Summary(ja): libidn ライブラリの開発用ファイル
Group: programming
License: GPLv3+, LGPLv3+ and GFDLv1.3+
Requires: %{name} = %{version}-%{release}
Provides: pkgconfig(libidn) = %{version}

%description devel
This package includes header files and libraries necessary for
developing programs which use the GNU libidn library.

# compat32
%package -n compat32-%{name}
Summary: Internationalized Domain Name support library
Summary(ja): 国際化ドメイン名をサポートするためのライブラリ
Group: system,legacy
Requires: %{name} = %{version}-%{release}

%description -n compat32-%{name}
GNU Libidn is an implementation of the Stringprep, Punycode and
IDNA specifications defined by the IETF Internationalized Domain
Names (IDN) working group, used for internationalized domain
names.

%package -n compat32-%{name}-devel
Summary: Development files for the libidn library
Summary(ja): libidn ライブラリの開発用ファイル
Group: programming,legacy
License: GPLv3+, LGPLv3+ and GFDLv1.3+
Requires: compat32-%{name} = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}

%description -n compat32-%{name}-devel
This package includes header files and libraries necessary for
developing programs which use the GNU libidn library.


%debug_package


%prep
%setup -q


%build
%configure --disable-csharp --disable-java \
%if ! %{with_static}
           --disable-static
%endif
make %{?_smp_mflags}
make %{?_smp_mflags} -C tests check


%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}
%makeinstall

rm -rf $RPM_BUILD_ROOT%{_libdir}/lib*.la

# provide more examples
make %{?_smp_mflags} -C examples distclean

# clean up docs
find doc -name "Makefile*" | xargs rm 
rm -rf $RPM_BUILD_ROOT%{_datadir}/info/dir

%find_lang %{name}


%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}


%post
/sbin/install-info %{_infodir}/%{name}.info.gz %{_infodir}/dir

%preun
if [ $1 = 0 ]; then
    /sbin/install-info --delete %{_infodir}/%{name}.info.gz %{_infodir}/dir
fi


%files -f %{name}.lang
%defattr(-,root,root)
%license COPYING*
%doc AUTHORS ChangeLog NEWS FAQ README THANKS
%{_bindir}/idn
%{_mandir}/man1/idn.1*
%{_datadir}/emacs/site-lisp
%{_libdir}/libidn.so.*
#{_libdir}/libidn.la
%{_infodir}/*

%files devel
%defattr(0644,root,root,755)
%doc doc/libidn-components.eps doc/libidn-components.png
%doc doc/reference doc/specifications
%{_libdir}/libidn.so
%if %{with_static}
%{_libdir}/libidn.a
%endif
%{_includedir}/*.h
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*

# compat32
%if %{build_compat32}
%files -n compat32-%{name}
%defattr(-,root,root)
%{_libdir}/libidn.so.*
#{_libdir}/libidn.la

%files -n compat32-%{name}-devel
%defattr(0644,root,root,755)
%{_libdir}/libidn.so
%if %{with_static}
%{_libdir}/libidn.a
%endif
#{_libdir}/pkgconfig/*.pc
%endif


%changelog
* Tue Jul 27 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.38-1
- new upstream release.

* Wed May 19 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.37-1
- new upstream release.
- dropped ldconfig scriptlets.

* Wed Feb 24 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.36-1
- new upstream release.

* Sun Mar 29 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.35-1
- new upstream release.

* Wed Feb 18 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 1.29-1
- new upstream release
- added Japanese summary

* Sat Oct  1 2011 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.22-1
- new upstream release

* Sat Sep 25 2010 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.19-1
- new upstream release
- built with rpm-4.8.1

* Sun Jun 28 2009 NAKAMURA Kenta <kenta@vinelinux.org> 1.11-2
- added compat32 package for x86_64 arch support.
- disabled static library creation by default.

* Mon Nov 24 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.11-1
- new upstream release

* Thu Jun 26 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.8-1
- new upstream release
- applied new versioning policy
- added --disable-csharp and --disable-java options to %%configure

* Wed Jul 11 2007 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 0.6.14-0vl1
- new upstream release

* Sun May 13 2007 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 0.6.9-0vl1
- new upstream release

* Wed Aug 31 2005 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 0.5.18-0vl2
- rebuild for VineSeed

* Wed Aug 31 2005 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 0.5.18-0vl1
- new upstream release

* Thu Dec 16 2004 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 0.5.12-0vl2
- rebuild for VineSeed

* Wed Dec 15 2004 AKIYAMA Kazuhito <akiyama@yb3.so-net.ne.jp> 0.5.12-0vl1
- new upstream release
- build for Vine Linux 3.1

* Thu Oct  7 2004 Joe Orton <jorton@redhat.com> 0.5.6-1
- update to 0.5.6 (#134343)

* Thu Sep 30 2004 Miloslav Trmac <mitr@redhat.com> - 0.5.4-3
- Fix Group: (#134068)

* Tue Aug 31 2004 Joe Orton <jorton@redhat.com> 0.5.4-2
- move ldconfig from preun to postun (#131280)

* Sun Aug  8 2004 Joe Orton <jorton@redhat.com> 0.5.4-1
- update to 0.5.4 (#129341)

* Thu Jul 15 2004 Robert Scheck <redhat@linuxnetz.de> 0.5.2-1
- upgrade to 0.5.2, enabled i18n support and info files (#127906)

* Fri Jul  9 2004 Joe Orton <jorton@redhat.com> 0.5.1-1
- update to 0.5.1 (#127496)

* Mon Jun 28 2004 Joe Orton <jorton@redhat.com> 0.5.0-1
- update to 0.5.0 (#126836)

* Tue Jun 22 2004 Than Ngo <than@redhat.com> 0.4.9-2
- add prereq: /sbin/ldconfig
- move la file in main package

* Tue Jun 15 2004 Robert Scheck <redhat@linuxnetz.de> 0.4.9-1
- upgrade to 0.4.9 (#126353)

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu Apr 29 2004 Joe Orton <jorton@redhat.com> 0.4.4-1
- update to 0.4.4; remove contrib from -devel docs

* Thu Apr 29 2004 Joe Orton <jorton@redhat.com> 0.4.3-1
- update to 0.4.3, remove -rpath patch

* Tue Jan 27 2004 Joe Orton <jorton@redhat.com> 0.3.7-1
- update to 0.3.7, simplify

* Wed Jan 07 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.3.6-1mdk
- 0.3.6

* Mon Dec 15 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.5-1mdk
- 0.3.5

* Sun Oct 19 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.3-2mdk
- drop the "soname fix" and use the correct way...

* Sat Oct 18 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.3-1mdk
- 0.3.3

* Mon Oct 13 2003 Oden Eriksson <oden.eriksson@kvikkjokk.net> 0.3.2-1mdk
- initial cooker contrib
- used the package from PLD as a start point
