Name:           libnice
Version:        0.1.16
Release:        1%{?_dist_release}
Summary:        GLib ICE implementation
Group:          System Environment/Libraries
Vendor:         Project Vine
Distribution:   Vine Linux

License:        LGPLv2 and MPLv1.1
URL:            https://libnice.freedesktop.org/
Source0:        https://libnice.freedesktop.org/releases/%{name}-%{version}.tar.gz
# make tests pass in Koji
Patch1:         libnice-0.1.14-tests-koji.patch
# Selected cherry-picks from upstream
# - make audio connection more reliable
# - issues #64 & #87
Patch2:         libnice-0.1.16-16-gb998547.patch
# upstream https://gitlab.freedesktop.org/libnice/libnice/-/merge_requests/66
# upstream https://gitlab.freedesktop.org/libnice/libnice/-/merge_requests/107
Patch3:         0001-interfaces-ignore-only-interfaces-we-really-want-to.patch
Patch4:         0002-interfaces-ignore-only-interfaces-we-really-want-to.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-root
BuildRequires:	glib2-devel >= 2.10
BuildRequires:  glib2-devel
BuildRequires:  gnutls-devel >= 2.12.0
BuildRequires:  gobject-introspection-devel
%if 0
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
%endif
BuildRequires:  gstreamer1-devel >= 0.11.91
BuildRequires:  gstreamer1-plugins-base-devel >= 0.11.91
BuildRequires:  gupnp-igd-devel >= 0.1.2

%description
%{name} is an implementation of the IETF's draft Interactive Connectivity
Establishment standard (ICE). ICE is useful for applications that want to
establish peer-to-peer UDP data streams. It automates the process of traversing
NATs and provides security against some attacks. Existing standards that use
ICE include the Session Initiation Protocol (SIP) and Jingle, XMPP extension
for audio/video calls.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       glib2-devel
Requires:       pkgconfig

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
chmod 0755 scripts/valgrind-test-driver

# disable test-new-trickle, which sometimes hangs indefinitely, and
# test-send-recv, which fails in Koji due to insufficiently configured network
sed -e 's/test-new-trickle/#&/' \
    -e 's/test-send-recv/#&/' \
    -i tests/Makefile.am

# needed for libnice-0.1.14-tests-koji.patch
autoreconf -fiv


%build
%configure \
 --enable-compile-warnings=yes \
 --disable-static \
 --with-ignored-network-interface-prefix=br-,docker,veth,virbr,vnet \
%if 0
 --with-gstreamer-0.10
%else
 --without-gstreamer-0.10
%endif
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
make %{?_smp_mflags} V=1


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'


%check
# Temporarily make the upstream test-suite run on Intel arches only because we
# are getting random crashes in Koji on secondary arches but I have not been
# able to reproduce them locally so far.
%ifarch x86_64 %{ix86}
export LD_LIBRARY_PATH="$PWD/nice/.libs"
make check
%endif


%clean
rm -rf $RPM_BUILD_ROOT


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%license COPYING COPYING.LGPL COPYING.MPL
%doc NEWS README
%{_bindir}/stunbdc
%{_bindir}/stund
%{_libdir}/*.so.*
%{_libdir}/girepository-1.0/Nice-0.1.typelib
%{_libdir}/gstreamer-1.0/libgstnice.so

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/nice.pc
%{_datadir}/gtk-doc/html/%{name}/
%{_datadir}/gir-1.0/Nice-0.1.gir


%changelog
* Sat Apr 25 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.1.16-1
- new upstream release.

* Sun Nov 01 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.1.13-1
- new upstream release

* Sun Oct 26 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.1.7-1
- new upstream release

* Sat Mar 29 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.1.5-1
- new upstream release

* Sat Jan 04 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.1.4-1
- update to 0.1.4

* Sat Sep 29 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.1.3-1
- new upstream release
- add BuildRequires: gstreamer1-devel, gstreamer1-plugins-base-devel

* Sat Apr 14 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.1.2-1
- new upstream release

* Thu Sep 29 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.1.1-1
- new upstream release

* Mon Aug 15 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.1.0-1
- new upstream release

* Sun Oct 03 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.0.13-1
- new upstream release

* Sun Oct 03 2010 Shu KONNO <owa@bg.wakwak.com> 0.0.9-4
- rebuilt with rpm-4.8.1 for pkg-config

* Sat Nov  7 2009 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 0.0.9-3
- initial build for Vine Linux

* Thu Sep 17 2009 Bastien Nocera <bnocera@redhat.com> 0.0.9-2
- Rebuild for new gupnp

* Sun Aug  2 2009 Brian Pepple <bpepple@fedoraproject.org> - 0.0.9-1
- Update to 0.0.9.
- Drop sha1 patch. Fixed upstream.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jul 21 2009 Warren Togami <wtogami@redhat.com> - 0.0.8-2
- stun sha1 patch from upstream to make it work at all

* Sun Jun 21 2009 Brian Pepple <bpepple@fedoraproject.org> - 0.0.8-1
- Update to 0.0.8.

* Sun Jun 14 2009 Brian Pepple <bpepple@fedoraproject.org> - 0.0.7-1
- Update to 0.0.7.
- Add BR on gupnp-igd-devel.

* Mon Apr 13 2009 Brian Pepple <bpepple@fedoraproject.org> - 0.0.6-1
- Update to 0.0.6.

* Wed Mar 18 2009 Brian Pepple <bpepple@fedoraproject.org> - 0.0.5-1
- Update to 0.0.5.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Dec 27 2008 Brian Pepple <bpepple@fedoraproject.org> - 0.0.4-1
- Initial Fedora spec.

