%global apiversion 0.1

Name: libvisio
Version: 0.1.7
Release: 4%{?_dist_release}
Summary: A library for import of Microsoft Visio diagrams
Summary(ja): Microsoft Visio ダイアグラムをインポートするためのライブラリ
Group: system
Vendor: Project Vine
Distribution: Vine Linux

License: MPLv2.0
URL: http://wiki.documentfoundation.org/DLP/Libraries/libvisio
Source: http://dev-www.libreoffice.org/src/%{name}/%{name}-%{version}.tar.xz

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: doxygen
BuildRequires: cppunit-devel
BuildRequires: gperf
BuildRequires: help2man
BuildRequires: libboost-devel
BuildRequires: libicu-devel
BuildRequires: librevenge-devel
BuildRequires: libxml2-devel
BuildRequires: perl
BuildRequires: zlib-devel

%description
%{name} is library providing ability to interpret and import
Microsoft Visio diagrams into various applications. You can find it
being used in libreoffice.

%package devel
Summary: Development files for %{name}
Summary(ja): %{name} の開発用ファイル
Group: programming
Requires: %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package doc
Summary: Documentation of %{name} API
Summary(ja): %{name} API のドキュメント
Group: documentation
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.


%package tools
Summary: Tools to transform Microsoft Visio diagrams into other formats
Summary(ja): Microsoft Visio ダイアグラムを他のフォーマットに変換するツール
Group: office
Requires: %{name} = %{version}-%{release}

%description tools
Tools to transform Microsoft Visio diagrams into other formats.
Currently supported: XHTML, raw, plain text.


%debug_package


%prep
%setup -q


%build
%configure --disable-static --disable-silent-rules
sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
make %{?_smp_mflags}

export LD_LIBRARY_PATH=`pwd`/src/lib/.libs${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
help2man -N -n 'debug the conversion library' -o vsd2raw.1 ./src/conv/raw/.libs/vsd2raw
help2man -N -n 'convert Visio document into SVG' -o vsd2xhtml.1 ./src/conv/svg/.libs/vsd2xhtml
help2man -N -n 'convert Visio document into plain text' -o vsd2text.1 ./src/conv/text/.libs/vsd2text
help2man -N -n 'debug the conversion library' -o vss2raw.1 ./src/conv/raw/.libs/vss2raw
help2man -N -n 'convert Visio stencil into SVG' -o vss2xhtml.1 ./src/conv/svg/.libs/vss2xhtml
help2man -N -n 'convert Visio stencil into plain text' -o vss2text.1 ./src/conv/text/.libs/vss2text


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
rm -f %{buildroot}/%{_libdir}/*.la
# rhbz#1001240 we install API docs directly from build
rm -rf %{buildroot}/%{_docdir}/%{name}

install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -m 0644 vsd2*.1 vss2*.1 %{buildroot}/%{_mandir}/man1


%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
# Workaround time formatting problem in the test
export TZ='CET'
make check %{?_smp_mflags}


%clean
rm -rf %{buildroot}


%files
%license COPYING.*
%doc AUTHORS
%{_libdir}/%{name}-%{apiversion}.so.*

%files devel
%doc ChangeLog
%{_includedir}/%{name}-%{apiversion}
%{_libdir}/%{name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{name}-%{apiversion}.pc

%files doc
%doc COPYING.*
%doc docs/doxygen/html

%files tools
%{_bindir}/vsd2raw
%{_bindir}/vsd2text
%{_bindir}/vsd2xhtml
%{_bindir}/vss2raw
%{_bindir}/vss2text
%{_bindir}/vss2xhtml
%{_mandir}/man1/vsd2raw.1*
%{_mandir}/man1/vsd2text.1*
%{_mandir}/man1/vsd2xhtml.1*
%{_mandir}/man1/vss2raw.1*
%{_mandir}/man1/vss2text.1*
%{_mandir}/man1/vss2xhtml.1*


%changelog
* Thu Apr 08 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 0.1.7-4
- rebuilt with icu-69.
- dropped ldconfig scriptlets.

* Fri Apr 24 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 0.1.7-3
- rebuilt with icu-67.

* Sat Mar 21 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> - 0.1.7-2
- rebuilt with icu-66.

* Sun Oct 13 2019 Toshiaki Ara <ara_t@384.jp> - 0.1.7-1
- new upstream release

* Tue Jan 16 2018 Toshiaki Ara <ara_t@384.jp> - 0.1.5-2
- rebuild under current VineSeed

* Sun Jul 03 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> - 0.1.5-1
- new upstream release
- remove Patch0 (0001-fix-test.patch)

* Tue Nov 03 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> - 0.1.3-1
- new upstream release
- add Patch0 (0001-fix-test.patch) from fedora

* Tue Jan 13 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> - 0.1.1-2
- Initial build for Vine Linux

* Fri Jan 02 2015 David Tardon <dtardon@redhat.com> - 0.1.1-1
- new upstream release

* Tue Aug 26 2014 David Tardon <dtardon@redhat.com> - 0.1.0-4
- rebuild for ICU 53.1

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon May 26 2014 David Tardon <dtardon@redhat.com> - 0.1.0-1
- new upstream release

* Thu May 22 2014 Petr Machata <pmachata@redhat.com> - 0.0.31-4
- Rebuild for boost 1.55.0

* Wed Apr 09 2014 David Tardon <dtardon@redhat.com> - 0.0.31-3
- generate man pages

* Wed Feb 12 2014 Rex Dieter <rdieter@fedoraproject.org> 0.0.31-2
- rebuild (libicu)

* Mon Sep 02 2013 David Tardon <dtardon@redhat.com> - 0.0.31-1
- new release

* Fri Aug 30 2013 David Tardon <dtardon@redhat.com> - 0.0.30-4
- Resolves: rhbz#1001240 duplicate documentation files / potentially conflicting

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.30-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 0.0.30-2
- Rebuild for boost 1.54.0

* Mon Jul 15 2013 David Tardon <dtardon@redhat.com> - 0.0.30-1
- new release

* Tue Jul 02 2013 David Tardon <dtardon@redhat.com> - 0.0.29-1
- new release

* Wed Jun 05 2013 David Tardon <dtardon@redhat.com> - 0.0.28-1
- new release

* Thu May 16 2013 David Tardon <dtardon@redhat.com> - 0.0.27-1
- new release

* Tue Apr 23 2013 David Tardon <dtardon@redhat.com> - 0.0.26-1
- new release

* Thu Feb 28 2013 David Tardon <dtardon@redhat.com> - 0.0.25-1
- new release

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.24-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Dec 18 2012 David Tardon <dtardon@redhat.com> - 0.0.24-1
- new release

* Mon Dec 03 2012 David Tardon <dtardon@redhat.com> - 0.0.23-1
- new release

* Thu Nov 29 2012 David Tardon <dtardon@redhat.com> - 0.0.22-1
- new upstream release

* Wed Nov 21 2012 David Tardon <dtardon@redhat.com> - 0.0.21-1
- new upstream release

* Tue Nov 06 2012 David Tardon <dtardon@redhat.com> - 0.0.20-1
- new upstream version

* Fri Jul 27 2012 David Tardon <dtardon@redhat.com> - 0.0.19-2
- rebuilt for boost 1.50

* Thu Jul 26 2012 David Tardon <dtardon@redhat.com> - 0.0.19-1
- new upstream version

* Tue Jul 24 2012 David Tardon <dtardon@redhat.com> - 0.0.18-3
- fix endless loop with text fields in VSD6

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.18-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jun 22 2012 David Tardon <dtardon@redhat.com> 0.0.18-1
- new upstream version

* Fri Jun 01 2012 David Tardon <dtardon@redhat.com> 0.0.17-1
- new upstream version

* Tue Apr 17 2012 David Tardon <dtardon@redhat.com> 0.0.16-1
- new upstream version

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.15-2
- Rebuilt for c++ ABI breakage

* Tue Feb 21 2012 David Tardon <dtardon@redhat.com> 0.0.15-1
- new upstream version

* Wed Jan 25 2012 David Tardon <dtardon@redhat.com> 0.0.14-1
- bump version

- initial import
* Wed Dec 21 2011 David Tardon <dtardon@redhat.com> 0.0.11-1
- initial import
