Name:		libwebp
Summary:	Library and tools for the WebP graphics format
Summary(ja):	WebP 画像フォーマットのためのライブラリとツール
Version:	1.1.0
Release:	1%{?_dist_release}
Group:		System Environment/Libraries
Vendor:		Project Vine
Distribution:	Vine Linux
Packager:	iwaim

# Additional IPR is licensed as well. See PATENTS file for details
License:	BSD
URL:		https://developers.google.com/speed/webp
Source0:	https://github.com/webmproject/libwebp/archive/v%{version}.tar.gz#/libwebp-%{version}.tar.gz
Source1:	libwebp_jni_example.java

BuildRoot:      %{_tmppath}/%{name}-%{version}-root
BuildRequires:	libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  java-1.8.0-openjdk-devel
BuildRequires:  jpackage-utils
BuildRequires:  swig
BuildRequires:  freeglut-devel

%description
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.

%package tools
Summary:	The WebP command line tools
Summary(ja):	WebP コマンドラインツール
Group:		Development/Tools

%description tools
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.

%package devel
Summary:	Development files for libwebp, a library for the WebP format
Summary(ja):	WebP フォーマットのためのライブラリ libwebp の開発ファイル
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.

%package java
Summary:	Java bindings for libwebp, a library for the WebP format
Summary(ja):	WebP フォーマットのためのライブラリ libwebp の Java バインディング
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	java
Requires:	jpackage-utils

%description java
Java bindings for libwebp.


%prep
%setup -q

%build
%global optflags %{optflags} -fPIC

mkdir -p m4
./autogen.sh
%configure --disable-static --enable-libwebpmux \
           --enable-libwebpdemux --enable-libwebpdecoder \
           --disable-neon
make %{?_smp_mflags}

# swig generated Java bindings
cp %{SOURCE1} .
cd swig
rm -rf libwebp.jar libwebp_java_wrap.c
mkdir -p java/com/google/webp
swig -ignoremissing -I../src -java \
    -package com.google.webp  \
    -outdir java/com/google/webp \
    -o libwebp_java_wrap.c libwebp.swig

gcc %{optflags} -shared \
    -I/usr/lib/jvm/java/include \
    -I/usr/lib/jvm/java/include/linux \
    -I../src \
    -L../src/.libs -lwebp libwebp_java_wrap.c \
    -o libwebp_jni.so

cd java
javac com/google/webp/libwebp.java
jar cvf ../libwebp.jar com/google/webp/*.class

%install
make install DESTDIR=%{buildroot}
find "%{buildroot}/%{_libdir}" -type f -name "*.la" -delete

# swig generated Java bindings
mkdir -p %{buildroot}/%{_libdir}/%{name}-java
cp swig/*.jar swig/*.so %{buildroot}/%{_libdir}/%{name}-java/

%post -n %{name} -p /sbin/ldconfig

%postun -n %{name} -p /sbin/ldconfig

%files tools
%{_bindir}/*
%{_mandir}/man*/*

%files -n %{name}
%license COPYING PATENTS
%doc README* NEWS AUTHORS
%{_libdir}/%{name}*.so.*

%files devel
%{_libdir}/%{name}*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*

%files java
%doc libwebp_jni_example.java
%{_libdir}/%{name}-java/

%changelog
* Fri Apr 17 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.1.0-1
- new upstream release.

* Thu Jan 03 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.0.1-1
- new upstream release.

* Sun Oct 12 2014 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 0.3.1-3
- moved libwebp to System Environment/Libraries Group

* Tue Jul 15 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.3.1-2
- rebuild with libpng-1.6.12

* Sat Oct 12 2013 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.3.1-1
- new upstream release

* Sat Jan 12 2013 IWAI, Masaharu <iwai@alib.jp> 0.2.1-1
- initial build for Vine Linux

* Thu Dec 27 2012 Rahul Sundaram <sundaram@fedoraproject.org> - 0.2.1-1
- new upstream release 0.2.1

* Fri Dec 21 2012 Adam Tkac <atkac redhat com> - 0.1.3-3
- rebuild against new libjpeg

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Feb 02 2012 Rahul Sundaram <sundaram@fedoraproject.org> - 0.1.3-1
- Several spec improvements by Scott Tsai <scottt.tw@gmail.com>

* Wed May 25 2011 Rahul Sundaram <sundaram@fedoraproject.org> - 0.1.2-1
- Initial spec. Based on openSUSE one

