# -*- mode: rpm-spec -*-

# By default, this spec file will generate RPMs for Clisp and SBCL.
# This can be changed by modifying the variables below.
%define enable_clisp 0
%define enable_sbcl 1

# Inhibit automatic compressing of info files. Compressed info
# files break maxima's internal help.
%define __spec_install_post /bin/true

Summary: Maxima Symbolic Computation Program
Summary(ja): 数式処理プログラム Maxima
Name: maxima
Version: 5.42.2
Release: 1%{?_dist_release}

License: GPL
Group:   Applications/Engineering
URL:     http://maxima.sourceforge.net
Source0: %{name}-%{version}.tar.gz

BuildRoot: %{_tmppath}/%{name}-%{version}-root

# Requires: maxima_exec = %{version}-%{release}
%if %{enable_clisp}
BuildRequires: clisp
Requires: clisp
%endif
%if %{enable_sbcl}
BuildRequires: sbcl
Requires: sbcl
%endif
BuildRequires: texinfo
Requires(post): /sbin/install-info
Requires(preun): /sbin/install-info

Obsoletes: %{name}-exec-clisp
Obsoletes: %{name}-exec-sbcl

Vendor:       Project Vine
Distribution: Vine Linux


%description
Maxima is a full symbolic computation program.  It is full featured
doing symbolic manipulation of polynomials, matrices, rational
functions, integration, Todd-coxeter, graphing, bigfloats.  It has a
symbolic debugger source level debugger for maxima code.  Maxima is
based on the original Macsyma developed at MIT in the 1970's.  It is
quite reliable, and has good garbage collection, and no memory leaks.
It comes with hundreds of self tests.
#'

%description -l ja
Maxima は高機能な数式処理プログラムです。Maximaを使えば、多項式、行列、
有理関数、積分、Todd-coxeter、グラフ描画、高精度浮動小数点といった演算
も簡単にこなせます。Maxima のコードに対応したソースレベルの数式デバッ
ガも備えています。Maxima は MIT で1970年台に開発されたオリジナルの
Macsyma がベースとなっています。Maxima はとても信頼性が高く、すぐれた
ガーベッジコレクションを搭載しており、メモリリークを起こしません。この
信頼性は、数百件に及ぶセルフテストによってもたらされたものです。
%if %{enable_sbcl}
SBCLではコマンドライン履歴を使用することができません。
コマンドライン履歴を使用する場合には rlwrap パッケージを
インストールして、
rlwrap maxima
のように起動して下さい。
%endif


%package xmaxima
Summary: Tcl/Tk interface to Maxima
Summary(ja): Maxima 用 Tcl/Tk インターフェース
Group: Applications/Engineering
Requires: %{name} = %{version}-%{release}
Requires: tk > 8.1
Provides: xmaxima

%description xmaxima
Tcl/Tk interface to Maxima.


%prep
%setup -q
%{configure} \
%if %{enable_clisp}
    --enable-clisp \
%endif
%if %{enable_sbcl}
    --enable-sbcl \
%endif
    ;

%build
%{__make} %{?_smp_mflags}

%install
%{__rm} -rf %{buildroot}
%{makeinstall}

%{__rm} -f $RPM_BUILD_ROOT%{_infodir}/dir

%post
/sbin/install-info %{_infodir}/maxima.info %{_infodir}/dir

%preun
if [ "$1" = 0 ]; then
    /sbin/install-info --delete %{_infodir}/maxima.info %{_infodir}/dir
fi

%clean
%{__rm} -rf %{buildroot}


%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog INSTALL* NEWS README*
%{_bindir}/maxima
%{_bindir}/rmaxima
%dir %{_libdir}/maxima/%{version}
%if %{enable_clisp}
%{_libdir}/maxima/%{version}/binary-clisp
%endif
%if %{enable_sbcl}
%{_libdir}/maxima/%{version}/binary-sbcl
%endif
%{_libexecdir}/maxima/%{version}
%{_datadir}/applications/xmaxima.desktop
%{_datadir}/bash-completion/completions/*
%{_datadir}/pixmaps/*
%{_datadir}/maxima/%{version}
%{_datadir}/mime/packages/*
%{_mandir}/man1/*
%{_infodir}/*

%files xmaxima
%{_bindir}/xmaxima


%changelog
* Tue Jan 29 2019 Toshiaki Ara <ara_t@384.jp> 5.42.2-1
- new upstream release

* Thu Dec 06 2018 Toshiaki Ara <ara_t@384.jp> 5.42.1-1
- new upstream release

* Fri Jun 01 2018 Toshiaki Ara <ara_t@384.jp> 5.41.0-2
- rebuild with sbcl-1.4.8

* Wed Nov 01 2017 Toshiaki Ara <ara_t@384.jp> 5.41.0-1
- new upstream release

* Sat Nov 05 2016 Toshiaki Ara <ara_t@384.jp> 5.38.1-2
- delete maxima-exec-{clisp,sbcl} subpackages
- add Vendor and Distribution

* Sat Nov 05 2016 Toshiaki Ara <ara_t@384.jp> 5.38.1-1
- New upstream release
- add build option (SBCL)
- delete build options (GCL and CMUCL)

* Fri Jul 31 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 5.36.1-1
- update to 5.36.1
- add BuildRequires: texinfo

* Sun Jun 17 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 5.16.3-3
- rebuild with Vine6 environment

* Sat Mar 06 2010 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 5.16.3-2
- rebuilt with new toolchain, libsigsev-2.8 and clisp-2.48

* Sun Oct 05 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 5.16.3-1vl5
- new upstream release

* Sat Oct 04 2008 Shu KONNO <owa@bg.wakwak.com> 5.11.0-1vl5
- applied new versioning policy, spec in utf-8

* Mon Mar 19 2007 USAMI Kosuke <usami-k@yc5.so-net.ne.jp> - 5.11.0-0vl1
- New upstream release
- Change Group

* Fri May 20 2005 USAMI Kosuke <usami-k@yc5.so-net.ne.jp> - 5.9.1-0vl2
- Japanese Summary and description by rpmSpecTranslate project

* Sat Apr 23 2005 USAMI Kosuke <usami-k@yc5.so-net.ne.jp> - 5.9.1-0vl1
- New upstream release (for diff() bug fix)
- Tidy up spec file

* Sun Feb  1 2004 USAMI Kosuke <usami-k@yc5.so-net.ne.jp> - 5.9.0-0vl4
- Change Requires and BuildPreReq clisp (= 2.29 -> >= 2.29)

* Sat Aug  2 2003 USAMI Kosuke <usami-k@yc5.so-net.ne.jp> - 5.9.0-0vl3
- Add exec-clisp BuildPreReq clisp
- Add xmaxima Requires tk > 8.1
- Remove xmaxima-olderTcl patch

* Fri Jun  6 2003 USAMI Kosuke <usami-k@yc5.so-net.ne.jp> 5.9.0-0vl2
- Rebuild for clisp-2.29-0vl1

* Fri May 30 2003 USAMI Kosuke <usami-k@yc5.so-net.ne.jp> 5.9.0-0vl1
- Enable clisp only, disable cmucl and gcl
- Add xmaxima-olderTcl patch (for tclversion older than 8.1)
- Remove %{_infodir}/dir file

* Sat Jan  4 2003 James Amundson <amundson@fnal.gov>
- Added doc files
- Added explicit clisp version
- Added conditional to postun
- Renamed exec_* packages to exec-*
- Use rpm macros instead of hard-coded paths
- Thanks to Rex Dieter for helpful suggestions

* Sun Sep  8 2002 James Amundson <amundson@fnal.gov> 
- Initial build.
