%bcond_with gtk2

Summary: Network exploration tool and security scanner
Summary(ja): 多機能なポートスキャナー
Name: nmap
Version: 7.92
Release: 1%{?_dist_release}
Group: network
Vendor: Project Vine
Distribution: Vine Linux

License: GPL
URL: https://nmap.org/
Source0: https://nmap.org/dist/%{name}-%{version}.tar.bz2
#Source1: zenmap.desktop

# Patches from Fedora rawhide
#prevent possible race condition for shtool, rhbz#158996
Patch1: nmap-4.03-mktemp.patch

#don't suggest to scan microsoft
Patch2: nmap-4.52-noms.patch

# upstream provided patch for rhbz#845005, not yet in upstream repository
Patch3: ncat_reg_stdin.diff
Patch4: nmap-6.25-displayerror.patch
# https://github.com/nmap/nmap/pull/2247
Patch7: nmap_resolve_config.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: libpcap-devel
BuildRequires: libssh2-devel
BuildRequires: lua-devel
BuildRequires: openssl-devel 
BuildRequires: pcre-devel 
BuildRequires: zlib-devel
%if %{with gtk2}
BuildRequires: python-devel
BuildRequires: pygtk2-devel 
%else
Obsoletes: nmap-frontend < 7.92
%endif

%description
Nmap is a utility for network exploration or security auditing. It
supports ping scanning (determine which hosts are up), many port
scanning techniques (determine what services the hosts are offering),
and TCP/IP fingerprinting (remote host operating system
identification). Nmap also offers flexible target and port
specification, decoy scanning, determination of TCP sequence
predictability characteristics, sunRPC scanning, reverse-identd
scanning, and more.

%description -l ja
Nmap はネットワークの調査やセキュリティ診断を行うユーティリティです。
ping によるスキャン(どのホストが稼働中かの調査)、様々なポートスキャン
技術(そのホストがどのサービスを提供しているかの調査)や、TCP/IP 指紋
の検査(そのホストの OS を特定)をサポートしています。Nmap は調査対象や
ポートを柔軟に設計することもでき、おとりスキャン、TCP シーケンスの
予測可能な性質の測定、Sun RPC スキャン、逆 identd スキャンなどの
機能も提供します。


%if %{with gtk2}
%package frontend
Summary: Gtk+ frontend for nmap
Summary(ja): Nmap の GTK+ フロントエンド
Group: Applications/System
Requires: nmap = %{version}-%{release}
Requires: python pygtk2 pysqlite
Provides: zenmap = %{version}-%{release}

%description frontend
This package includes zenmap, a GTK+ frontend for nmap. The nmap package must
be installed before installing nmap-frontend.

%description frontend -l ja
Nmap の GTK+ ベースのフロントエンド(zenmap)です。このパッケージをインストール
する前に、nmap パッケージをインストールする必要があります。
%endif


%debug_package


%prep
%setup -q
%autopatch -p1

#be sure we're not using tarballed copies of some libraries
#rm -rf liblua libpcap libpcre macosx mswin32 ###TODO###
rm -rf libpcap libpcre macosx mswin32 libssh2 libz


%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
%configure \
	--without-zenmap \
	--without-ndiff \
	--with-libpcap=yes \
	--with-liblua=included \
	--with-libssh2=yes \
	--enable-dbus
%make_build


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT STRIP=true

rm -f $RPM_BUILD_ROOT%{_bindir}/uninstall_ndiff

#do not include certificate bundle (#734389)
rm -f %{buildroot}%{_datadir}/ncat/ca-bundle.crt
rmdir %{buildroot}%{_datadir}/ncat

#we provide 'nc' replacement (#1653119)
touch %{buildroot}%{_mandir}/man1/nc.1.gz
touch %{buildroot}%{_bindir}/nc

%if %{with gtk2}
rm -f $RPM_BUILD_ROOT%{_bindir}/uninstall_zenmap
cp docs/zenmap.1 $RPM_BUILD_ROOT%{_mandir}/man1/
gzip $RPM_BUILD_ROOT%{_mandir}/man1/* || :
pushd $RPM_BUILD_ROOT%{_mandir}/man1
ln -s zenmap.1.gz nmapfe.1.gz
ln -s zenmap.1.gz xnmap.1.gz
popd

#desktop-file-install --vendor= \
#	--dir $RPM_BUILD_ROOT%{_datadir}/applications \
#	%{SOURCE1};
rm -f $RPM_BUILD_ROOT%{_datadir}/applications/zenmap-root.desktop
%endif

%find_lang %{name} --with-man


%clean
rm -rf %{buildroot}


%post
%{_sbindir}/alternatives --install %{_bindir}/nc nc %{_bindir}/ncat 10 \
  --slave %{_mandir}/man1/nc.1.gz nc-man %{_mandir}/man1/ncat.1.gz

%preun
if [ $1 -eq 0 ]; then
  %{_sbindir}/alternatives --remove nc %{_bindir}/ncat
fi


%files -f %{name}.lang
%defattr(-,root,root)
%license LICENSE
%doc CHANGELOG README.md
%doc docs/nmap.usage.txt docs/nmap.dtd
%{_bindir}/nmap
%{_bindir}/ncat
%{_bindir}/nping
%{_datadir}/nmap
%{_mandir}/man1/nmap.1*
%{_mandir}/man1/ncat.1*
%{_mandir}/man1/nping.1*
%ghost %{_bindir}/nc
%ghost %{_mandir}/man1/nc.1.gz


%if %{with gtk2}
%files frontend
%defattr(-,root,root)
%{_bindir}/nmapfe
%{_bindir}/xnmap
%{_bindir}/zenmap
%{python_sitelib}/*
%{_datadir}/applications/*.desktop
#%{_datadir}/icons/*
#%{_datadir}/pixmaps/zenmap
%{_datadir}/zenmap
%{_mandir}/man1/zenmap.1*
%{_mandir}/man1/nmapfe.1*
%{_mandir}/man1/xnmap.1*
%endif


%changelog
* Wed Oct 27 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.92-1
- new upstream release.
- built with openssl-3.0.0.

* Thu Apr 16 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 7.80-1
- new upstream release.

* Sat Nov 17 2018 Toshiaki Ara <ara_t@384.jp> 7.70-1
- update to 7.70
- add Patches from Fedora rawhide

* Sat Jul 02 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 7.12-2
- rebuild with gcc-5.4.0

* Thu Mar 31 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 7.12-1
- new upstream release

* Tue Mar 29 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 7.11-1
- new upstream release

* Thu Dec 17 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 7.01-1
- new upstream release

* Sun Aug 24 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 6.47-1
- new upstream release

* Mon Jan 07 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 6.25-1
- new upstream release

* Wed Oct 24 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 6.01-2
- rebuild with pcre-8.31

* Sun Oct 14 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 6.01-1
- new upstream release

* Sun Feb 19 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 5.51-2
- new upstream release

* Mon Feb 14 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 5.51-1
- new upstream release

* Sat Jan 29 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 5.50-1
- new upstream release
- fix %files to add nping

* Fri Jun 11 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 5.21-1
- new upstream release
- add BuildRequires: openssl-devel, lua-devel
- fix %files to add ncat and ndiff

* Fri Apr 24 2009 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 4.76-1
- new upstream release
- spec in UTF-8
- added BuildRequires: libpcap-devel instead of libpcap
- removed BuildRequires: desktop-file-utils

* Sat Nov 01 2008 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 4.60-4
- rebuilt with libpcap 1.0.0

* Sun Jul 20 2008 Shu KONNO <owa@bg.wakwak.com> 4.60-3
- rebuilt with python-2.5.2

* Mon Apr 28 2008 NAKAMURA Kenta <kenta@vinelinux.org> 4.60-2
- updated python sitelib files path

* Sat Apr 12 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 4.60-1vl5
- new upstream release

* Tue May 15 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 4.20-0vl1
- new upstream release
- rebuild with new environment/toolchain

* Sat Jun 17 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 4.10-0vl1
- new upstream release
- added BuildRequires: desktop-file-utils

* Sat Feb 11 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 4.01-0vl1
- new upstream release

* Sun Sep 18 2005 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.93-0vl2
- rebuild for VineSeed Plus

* Sun Sep 18 2005 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.93-0vl1
- new upstream release

* Fri Feb 18 2005 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.81-0vl1
- new upstream release

* Sun Oct 24 2004 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.75-0vl1
- new upstream release
- added Japanese summary to nmap-frontend

* Thu Sep 23 2004 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.70-0vl1
- new upstream release

* Sat Mar 27 2004 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.50-0vl2
- rebuild with new openssl

* Tue Mar 16 2004 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.50-0vl1
- new upstream release 

* Fri Oct 17 2003 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.48-0vl1
- new upstream release 

* Thu Sep 18 2003 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.45-0vl1
- new upstream release 

* Sun Jul 20 2003 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.30-0vl1
- new upstream release 

* Tue May 20 2003 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.27-0vl2
- merged Vine Plus specfile and VineSeed Plus specfile (sorry...)

* Sat May  3 2003 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 3.27-0vl1
- new upstream release
- rebuild with new toolchains

* Sun Sep 22 2002 Masaru Sato <masachan@mediaship.ne.jp> 3.00-0vl1
- new upstream release
- delete Version Tag from nmap-frontend package
- fix BuildRoot

* Sun May 26 2002 Daisuke SUZUKI <daisuke@linux.or.jp> 2.54BETA34-0vl1
- new upstream release
- 2.54BETA is developpment release, but it is more stable than 2.53.

* Fri Mar 08 2002 Toru Sagami <sagami@vinelinux.org> 2.53-1vl2
- unfortunately increase release: 1vl2 from 0vl2
  ( 2.53-1vl1 is found in VinePlus/2.1, also breaking our packaging rule)
- patch to build on current glibc22 system

* Thu Sep 06 2001 Toru Sagami <sagami@vinelinux.org>
- 2.53-0vl2: use better macros

* Thu Sep 21 2000 Yoshihiro Kajiki <kajiki@ylug.org>
- rebuild for VineSeed based on the original site's srpm
- add Japanese summary and description

* Thu Dec 30 1999 Fyodor <fyodor@insecure.org>
- Updated description
- Eliminated source1 (nmapfe.desktop) directive and simply packaged it with Nmap
- Fixed nmap distribution URL (source0)
- Added this .rpm to base Nmap distribution

* Mon Dec 13 1999 Tim Powers <timp@redhat.com>
- based on origional spec file from
	http://www.insecure.org/nmap/index.html#download
- general cleanups, removed lots of commenrts since it made the spec hard to
	read
- changed group to Applications/System
- quiet setup
- no need to create dirs in the install section, "make
	prefix=$RPM_BUILD_ROOT&{prefix} install" does this.
- using defined %{prefix}, %{version} etc. for easier/quicker maint.
- added docs
- gzip man pages
- strip after files have been installed into buildroot
- created separate package for the frontend so that Gtk+ isn't needed for the
	CLI nmap 
- not using -f in files section anymore, no need for it since there aren't that
	many files/dirs
- added desktop entry for gnome

* Sun Jan 10 1999 Fyodor <fyodor@dhp.com>
- Merged in spec file sent in by Ian Macdonald <ianmacd@xs4all.nl>

* Tue Dec 29 1998 Fyodor <fyodor@dhp.com>
- Made some changes, and merged in another .spec file sent in
  by Oren Tirosh <oren@hishome.net>

* Mon Dec 21 1998 Riku Meskanen <mesrik@cc.jyu.fi>
- initial build for RH 5.x
