%bcond_with test

%bcond_without gstreamer
#global indice   a

Name:           opencv
Version:        4.5.3
Release:        1%{?_dist_release}
Summary:        Collection of algorithms for computer vision
Summary(ja):    コンピュータビジョン用のアルゴリズム集
Group:          graphics
Vendor:         Project Vine
Distribution:   Vine Linux

# This is normal three clause BSD.
License:        BSD
URL:            https://opencv.org

# RUN opencv-clean.sh TO PREPARE TARBALLS
#
# Need to remove copyrighted lena.jpg images from tarball (rhbz#1295173)
# and SIFT/SURF from tarball, due to legal concerns.
#
#Source0:        https://github.com/opencv/opencv/archive/%{version}.tar.gz
Source0:        %{name}-clean-%{version}.tar.gz
Source1:        %{name}_contrib-clean-%{version}.tar.gz
Source2:        %{name}_extra-clean-%{version}.tar.gz
Source3:        face_landmark_model.dat.xz
# from https://github.com/opencv/ade/archive/v0.1.1f.zip
Source4:        b624b995ec9c439cbc2e9e6ee940d3a2-v0.1.1f.zip
Source5:        xorg.conf
Source100:      opencv-clean.sh

Patch0:         opencv-4.1.0-install_3rdparty_licenses.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-root
BuildRequires:  libtool
BuildRequires:  cmake >= 2.6.3
BuildRequires:  chrpath

BuildRequires:  eigen3-devel
BuildRequires:  libtheora-devel
BuildRequires:  libvorbis-devel
#BuildRequires:  libraw1394-devel
#BuildRequires:  libdc1394-devel
BuildRequires:  jasper-devel
BuildRequires:  libpng-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  libv4l-devel
BuildRequires:  libwebp-devel
BuildRequires:  mesa-libGL-devel
BuildRequires:  OpenEXR-devel
BuildRequires:  openjpeg2-devel
#ifarch %{ix86} x86_64
#BuildRequires:  openni-devel
#BuildRequires:  openni-primesense
#endif
BuildRequires:  tbb-devel

BuildRequires:  qt5-qtbase-devel
BuildRequires:  freetype2-devel
BuildRequires:  harfbuzz-devel

BuildRequires:  zlib-devel pkgconfig
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-rpm-macros
BuildRequires:  python3-numpy
BuildRequires:  swig >= 1.3.24
#BuildRequires:  python-sphinx
#BuildRequires:  ffmpeg-devel >= 0.4.9

BuildRequires:  gstreamer1-devel
BuildRequires:  gstreamer1-plugins-base-devel
#BuildRequires:  xine-lib-devel
#BuildRequires:  opencl-headers
BuildRequires:  vulkan-headers
BuildRequires:  mesa-dri-drivers
BuildRequires:  xorg-x11-drv-dummy

Requires:       opencv-core = %{version}-%{release}

%description
OpenCV means Intel® Open Source Computer Vision Library. It is a collection of
C functions and a few C++ classes that implement some popular Image Processing
and Computer Vision algorithms.


%package        core
Summary:        OpenCV core libraries
Summary(ja):    OpenCV コアライブラリ
Group:          graphics
Obsoletes:      %{name}-python < %{version}-%{release}

%description    core
This package contains the OpenCV C/C++ core libraries.


%package        devel
Summary:        Development files for using the OpenCV library
Summary(ja):    OpenCV ライブラリを使用するための開発用ファイル
Group:          programming
Requires:       opencv = %{version}-%{release}

%description    devel
This package contains the OpenCV C/C++ library and header files, as well as
documentation. It should be installed if you want to develop programs that
will use the OpenCV library. You should consider installing opencv-devel-docs
package.


%package -n     python3-opencv
Summary:        Python bindings for apps which use OpenCV
Summary(ja):    OpenCV を使用するアプリケーション用の Python バインディング
Group:          programming
Requires:       opencv = %{version}-%{release}
Requires:       python3-numpy

%description -n python3-opencv
This package contains Python bindings for the OpenCV library.


%package        contrib
Summary:        OpenCV contributed functionality
Summary(ja):    寄贈された OpenCV の追加機能
Group:          graphics

%description    contrib
This package is intended for development of so-called "extra" modules, contribut
ed
functionality. New modules quite often do not have stable API, and they are not
well-tested. Thus, they shouldn't be released as a part of official OpenCV
distribution, since the library maintains binary compatibility, and tries
to provide decent performance and stability.


%debug_package


%prep
%setup -q -a1 -a2
# we don't use pre-built contribs except quirc
pushd 3rdparty
shopt -s extglob
rm -r !(openexr|openvx|quirc)
shopt -u extglob
popd &>/dev/null

%patch0 -p1 -b .install_3rdparty_licenses

pushd %{name}_contrib-%{version}
popd

# Install face_landmark_model
mkdir -p .cache/data
install -pm 0644 %{SOURCE3} .cache/data
pushd .cache/data
  xz -d face_landmark_model.dat.xz
popd

# Install ADE, needed for opencv_gapi
mkdir -p .cache/ade
install -pm 0644 %{SOURCE4} .cache/ade/


%build
%cmake \
        -DWITH_IPP=OFF \
        -DWITH_ITT=OFF \
        -DWITH_QT=ON \
        -DWITH_OPENGL=ON \
        -DOpenGL_GL_PREFERENCE=GLVND \
        -DWITH_GDAL=ON \
        -DWITH_OPENEXR=ON \
        -DWITH_UNICAP=ON \
        -DCMAKE_SKIP_RPATH=ON \
        -DWITH_CAROTENE=OFF \
%ifnarch x86_64 ia64
        -DENABLE_SSE=0 \
        -DENABLE_SSE2=0 \
%else
        -DCPU_BASELINE=SSE2 \
%endif
        -DENABLE_PRECOMPILED_HEADERS=OFF \
        -DCMAKE_BUILD_TYPE=ReleaseWithDebInfo \
        -DBUILD_opencv_java=OFF \
        %{?with_tbb: -DWITH_TBB=ON } \
        %{!?with_gstreamer: -DWITH_GSTREAMER=OFF } \
        -DWITH_FFMPEG=OFF \
        %{?with_openni: -DWITH_OPENNI=ON } \
        -DWITH_XINE=OFF \
        -DBUILD_DOCS=OFF \
        -DBUILD_EXAMPLES=OFF \
        -DBUILD_opencv_python2=OFF \
        -DINSTALL_C_EXAMPLES=OFF \
        -DINSTALL_PYTHON_EXAMPLES=OFF \
        -DPYTHON3_EXECUTABLE=%{__python3} \
        -DPYTHON3_PACKAGES_PATH=%{python3_sitearch} \
        -DENABLE_PYLINT=ON \
        -DBUILD_PROTOBUF=OFF \
        -DPROTOBUF_UPDATE_FILES=ON \
        -DWITH_OPENCL=OFF \
        -DOPENCV_SKIP_PYTHON_LOADER=ON \
        -DOPENCV_EXTRA_MODULES_PATH=opencv_contrib-%{version}/modules \
        -DWITH_LIBV4L=ON \
        -DWITH_OPENMP=ON \
        -DOPENCV_CONFIG_INSTALL_PATH=%{_lib}/cmake/OpenCV \
        -DOPENCV_GENERATE_PKGCONFIG=ON \
        -DOPENCV_TEST_DATA_PATH=opencv_extra-%{version}/testdata \
        %{?with_gdcm: -DWITH_GDCM=ON } \
        %{?with_libmfx: -DWITH_MFX=ON } \
        %{?with_clp: -DWITH_CLP=ON } \
        %{?with_va: -DWITH_VA=ON } \
        -DWITH_VTK=OFF \
        -DWITH_TBB=1 -DTBB_LIB_DIR=%{_libdir} \
        -DWITH_VULKAN=ON -DVULKAN_INCLUDE_DIRS=%{_includedir}/vulkan

%cmake_build


%install
rm -rf %{buildroot}
%cmake_install
find %{buildroot} -name '*.la' -delete
rm -rf %{buildroot}%{_datadir}/OpenCV/licenses/


%if %{with test}
%check
# Check fails since we don't support most video
# read/write capability and we don't provide a display
# ARGS=-V increases output verbosity
pushd build
    cp %SOURCE5 .
    if [ -x /usr/libexec/Xorg ]; then
       Xorg=/usr/libexec/Xorg
    else
       Xorg=/usr/libexec/Xorg.bin
    fi
    $Xorg -noreset +extension GLX +extension RANDR +extension RENDER -logfile ./xorg.log -config ./xorg.conf -configdir . :99 &
    export DISPLAY=:99
    LD_LIBRARY_PATH=%{_builddir}/%{name}-%{version}/build/lib:$LD_LIBARY_PATH make test ARGS=-V || :
popd
%endif


%clean
rm -rf %{buildroot}


%files
%doc README.md
%{_bindir}/opencv_*
%dir %{_datadir}/opencv4
%{_datadir}/opencv4/haarcascades
%{_datadir}/opencv4/lbpcascades
%{_datadir}/opencv4/valgrind*
%{_datadir}/opencv4/quality

%files core
%license LICENSE
%{_datadir}/licenses/opencv4/
%{_libdir}/libopencv_alphamat.so.*
%{_libdir}/libopencv_core.so.*
%{_libdir}/libopencv_cvv.so.*
%{_libdir}/libopencv_features2d.so.*
%{_libdir}/libopencv_flann.so.*
%{_libdir}/libopencv_gapi.so.*
%{_libdir}/libopencv_hfs.so.*
%{_libdir}/libopencv_highgui.so.*
%{_libdir}/libopencv_imgcodecs.so.*
%{_libdir}/libopencv_imgproc.so.*
%{_libdir}/libopencv_intensity_transform.so.*
%{_libdir}/libopencv_ml.so.*
%{_libdir}/libopencv_objdetect.so.*
%{_libdir}/libopencv_photo.so.*
%{_libdir}/libopencv_rapid.so.*
%{_libdir}/libopencv_shape.so.*
%{_libdir}/libopencv_stitching.so.*
%{_libdir}/libopencv_superres.so.*
%{_libdir}/libopencv_video.so.*
%{_libdir}/libopencv_videoio.so.*
%{_libdir}/libopencv_videostab.so.*

%files devel
%dir %{_includedir}/opencv4
%{_includedir}/opencv4/opencv2
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/opencv*.pc
%{_libdir}/cmake/OpenCV/*.cmake

%files -n python3-opencv
%exclude %{_bindir}/setup_vars_opencv4.sh
%{python3_sitearch}/cv2.cpython-3*.so


%files contrib
%{_libdir}/libopencv_aruco.so.*
%{_libdir}/libopencv_bgsegm.so.*
%{_libdir}/libopencv_bioinspired.so.*
%{_libdir}/libopencv_calib3d.so.*
%{_libdir}/libopencv_ccalib.so.*
%{_libdir}/libopencv_datasets.so.*
# needs protobuf
#{_libdir}/libopencv_dnn.so.*
#{_libdir}/libopencv_dnn_objdetect.so.*
#{_libdir}/libopencv_dnn_superres.so.*
%{_libdir}/libopencv_dpm.so.*
%{_libdir}/libopencv_face.so.*
%{_libdir}/libopencv_freetype.so.*
%{_libdir}/libopencv_fuzzy.so.*
# needs hdf5
#{_libdir}/libopencv_hdf.so.*
%{_libdir}/libopencv_img_hash.so.*
%{_libdir}/libopencv_line_descriptor.so.*
%{_libdir}/libopencv_optflow.so.*
%{_libdir}/libopencv_phase_unwrapping.so.*
%{_libdir}/libopencv_plot.so.*
%{_libdir}/libopencv_reg.so.*
%{_libdir}/libopencv_rgbd.so.*
%{_libdir}/libopencv_quality.so.*
%{_libdir}/libopencv_saliency.so.*
%{_libdir}/libopencv_stereo.so.*
%{_libdir}/libopencv_structured_light.so.*
%{_libdir}/libopencv_surface_matching.so.*
# needs tesseract
#{_libdir}/libopencv_text.so.*
%{_libdir}/libopencv_tracking.so.*
%{_libdir}/libopencv_ximgproc.so.*
%{_libdir}/libopencv_xobjdetect.so.*
%{_libdir}/libopencv_xphoto.so.*


%changelog
* Thu Sep 02 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 4.5.3-1
- new upstream release.
- dropped ldconfig scriptlets.

* Sat Dec 12 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 4.5.0-1
- new upstream release.

* Sun Aug 16 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 4.4.0-1
- new upstream release.
- enabled vulkan compute backend

* Tue Jun 30 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 4.3.0-1
- new upstream release.

* Mon Mar 27 2017 Daisuke SUZUKI <daisuke@vinelinux.org> 2.4.9-8
- use eigen2 on Vine Linux 6.x
- disable tbb/v4l on Vine Linux 6.x

* Fri Sep 02 2016 Toshiaki Ara <ara_t@384.jp> 2.4.9-7
- rebuild with gcc-5.4.0

* Wed Mar  4 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 2.4.9-6
- built with tbb
- moved main package to System Environment/Libraries Group

* Fri Feb 20 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 2.4.9-5
- Initial build for Vine Linux

* Tue Nov 25 2014 Rex Dieter <rdieter@fedoraproject.org> 2.4.9-4
- rebuild (openexr)

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.9-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jul 25 2014 Rex Dieter <rdieter@fedoraproject.org> 2.4.9-2
- backport support for GStreamer 1 (#1123078)

* Thu Jul 03 2014 Nicolas Chauvet <kwizart@gmail.com> - 2.4.9-1
- Update to 2.4.9

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.7-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Apr 26 2014 Rex Dieter <rdieter@fedoraproject.org> 2.4.7-6
- revert pkgcmake2 patch (#1070428)

* Fri Jan 17 2014 Nicolas Chauvet <kwizart@gmail.com> - 2.4.7-5
- Fix opencv_ocl isn't part of -core

* Thu Jan 16 2014 Christopher Meng <rpm@cicku.me> - 2.4.7-4
- Enable OpenCL support.
- SPEC small cleanup.

* Wed Nov 27 2013 Rex Dieter <rdieter@fedoraproject.org> 2.4.7-3
- rebuild (openexr)

* Mon Nov 18 2013 Rex Dieter <rdieter@fedoraproject.org> 2.4.7-2
- OpenCV cmake configuration broken (#1031312)

* Wed Nov 13 2013 Nicolas Chauvet <kwizart@gmail.com> - 2.4.7-1
- Update to 2.4.7

* Sun Sep 08 2013 Rex Dieter <rdieter@fedoraproject.org> 2.4.6.1-2
- rebuild (openexr)

* Wed Jul 24 2013 Nicolas Chauvet <kwizart@gmail.com> - 2.4.6.1-1
- Update to 2.4.6.1

* Thu May 23 2013 Nicolas Chauvet <kwizart@gmail.com> - 2.4.5-1
- Update to 2.4.5-clean
- Spec file clean-up
- Split core libraries into a sub-package

* Sat May 11 2013 François Cami <fcami@fedoraproject.org> - 2.4.4-3
- change project URL.

* Tue Apr 02 2013 Tom Callaway <spot@fedoraproject.org> - 2.4.4-2
- make clean source without SIFT/SURF

* Sat Mar 23 2013 Nicolas Chauvet <kwizart@gmail.com> - 2.4.4-1
- Update to 2.4.4a
- Fix ttb-devel architecture conditionals

* Sun Mar 10 2013 Rex Dieter <rdieter@fedoraproject.org> 2.4.4-0.2.beta
- rebuild (OpenEXR)

* Mon Feb 18 2013 Nicolas Chauvet <kwizart@gmail.com> - 2.4.4-0.1.beta
- Update to 2.4.4 beta
- Drop python-imaging also from requires
- Drop merged patch for additionals codecs
- Disable the java binding for now (untested)

* Fri Jan 25 2013 Honza Horak <hhorak@redhat.com> - 2.4.3-7
- Do not build with 1394 libs in rhel

* Mon Jan 21 2013 Adam Tkac <atkac redhat com> - 2.4.3-6
- rebuild due to "jpeg8-ABI" feature drop

* Sun Jan 20 2013 Nicolas Chauvet <kwizart@gmail.com> - 2.4.3-5
- Add more FourCC for gstreamer - rhbz#812628
- Allow to use python-pillow - rhbz#895767

* Mon Nov 12 2012 Nicolas Chauvet <kwizart@gmail.com> - 2.4.3-3
- Switch Build Type to ReleaseWithDebInfo to avoid -03

* Sun Nov 04 2012 Nicolas Chauvet <kwizart@gmail.com> - 2.4.3-2
- Disable SSE3 and allow --with sse3 build conditional.
- Disable gpu module as we don't build cuda
- Update to 2.4.3

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jul 09 2012 Honza Horak <hhorak@redhat.com> - 2.4.2-1
- Update to 2.4.2

* Fri Jun 29 2012 Honza Horak <hhorak@redhat.com> - 2.4.1-2
- Fixed cmake script for generating opencv.pc file
- Fixed OpenCVConfig script file

* Mon Jun 04 2012 Nicolas Chauvet <kwizart@gmail.com> - 2.4.1-1
- Update to 2.4.1
- Rework dependencies - rhbz#828087
  Re-enable using --with tbb,opennpi,eigen2,eigen3

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-8
- Rebuilt for c++ ABI breakage

* Mon Jan 16 2012 Nicolas Chauvet <kwizart@gmail.com> - 2.3.1-7
- Update gcc46 patch for ARM FTBFS

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Dec 05 2011 Adam Jackson <ajax@redhat.com> 2.3.1-5
- Rebuild for new libpng

* Thu Oct 20 2011 Nicolas Chauvet <kwizart@gmail.com> - 2.3.1-4
- Rebuilt for tbb silent ABI change

* Mon Oct 10 2011 Nicolas Chauvet <kwizart@gmail.com> - 2.3.1-3
- Update to 2.3.1a

* Mon Sep 26 2011 Dan Horák <dan[at]danny.cz> - 2.3.1-2
- openni is exclusive for x86/x86_64

* Fri Aug 19 2011 Nicolas Chauvet <kwizart@gmail.com> - 2.3.1-1
- Update to 2.3.1
- Add BR openni-devel python-sphinx
- Remove deprecated cmake options
- Add --with cuda conditional (wip)
- Disable make test (unavailable)

* Thu May 26 2011 Nicolas Chauvet <kwizart@gmail.com> - 2.2.0-6
- Backport fixes from branch 2.2 to date

* Tue May 17 2011 Nicolas Chauvet <kwizart@gmail.com> - 2.2.0-5
- Re-enable v4l on f15
- Remove unused cmake options

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Feb 02 2011 Nicolas Chauvet <kwizart@gmail.com> - 2.2.0-2
- Fix with gcc46
- Disable V4L as V4L1 is disabled for Fedora 15

* Thu Jan 06 2011 Nicolas Chauvet <kwizart@gmail.com> - 2.2.0-1
- Update to 2.2.0
- Disable -msse and -msse2 on x86_32

* Wed Aug 25 2010 Rex Dieter <rdieter@fedoraproject.org> - 2.1.0-5
- -devel: include OpenCVConfig.cmake (#627359)

* Thu Jul 22 2010 Dan Horák <dan[at]danny.cz> - 2.1.0-4
- TBB is available only on x86/x86_64 and ia64

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 2.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri Jun 25 2010 Nicolas Chauvet <kwizart@gmail.com> - 2.1.0-2
- Move samples from main to -devel
- Fix spurious permission
- Add BR tbb-devel
- Fix CFLAGS

* Fri Apr 23 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 2.1.0-1
- Update to 2.1.0
- Update libdir patch

* Tue Apr 13 2010 Karel Klic <kklic@redhat.com> - 2.0.0-10
- Fix nonstandard executable permissions

* Tue Mar 09 2010 Karel Klic <kklic@redhat.com> - 2.0.0-9
- apply the previously added patch

* Mon Mar 08 2010 Karel Klic <kklic@redhat.com> - 2.0.0-8
- re-enable testing on CMake build system
- fix memory corruption in the gaussian random number generator

* Sat Feb 27 2010 Haïkel Guémar <karlthered@gmail.com> - 2.0.0-7
- replaced BR unicap-devel by libucil-devel (unicap split)

* Thu Feb 25 2010 Haïkel Guémar <karlthered@gmail.com> - 2.0.0-6
- use cmake build system
- applications renamed to opencv_xxx instead of opencv-xxx
- add devel-docs subpackage #546605
- add OpenCVConfig.cmake
- enable openmp build
- enable old SWIG based python wrappers
- opencv package is a good boy and use global instead of define

* Tue Feb 16 2010 Karel Klic <kklic@redhat.com> - 2.0.0-5
- Set CXXFLAXS without -match=i386 for i386 architecture #565074

* Sat Jan 09 2010 Rakesh Pandit <rakesh@fedoraproject.org> - 2.0.0-4
- Updated opencv-samples-Makefile (Thanks Scott Tsai) #553697

* Wed Jan 06 2010 Karel Klic <kklic@redhat.com> - 2.0.0-3
- Fixed spec file issues detected by rpmlint

* Sun Dec 06 2009 Haïkel Guémar <karlthered@gmail.com> - 2.0.0-2
- Fix autotools scripts (missing LBP features) - #544167

* Fri Nov 27 2009 Haïkel Guémar <karlthered@gmail.com> - 2.0.0-1
- Updated to 2.0.0
- Removed upstream-ed patches
- Ugly hack (added cvconfig.h)
- Disable %%check on ppc64

* Thu Sep 10 2009 Karsten Hopp <karsten@redhat.com> - 1.1.0-0.7.pre1
- fix build on s390x where we don't have libraw1394 and devel

* Thu Jul 30 2009 Haïkel Guémar <karlthered@gmail.com> - 1.1.0.0.6.pre1
- Fix typo I introduced that prevented build on i386/i586

* Thu Jul 30 2009 Haïkel Guémar <karlthered@gmail.com> - 1.1.0.0.5.pre1
- Added 1394 libs and unicap support

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-0.4.pre1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jul 16 2009 kwizart < kwizart at gmail.com > - 1.1.0-0.3.pre1
- Build with gstreamer support - #491223
- Backport gcc43 fix from trunk

* Thu Jul 16 2009 kwizart < kwizart at gmail.com > - 1.1.0-0.2.pre1
- Fix FTBFS #511705

* Fri Apr 24 2009 kwizart < kwizart at gmail.com > - 1.1.0-0.1.pre1
- Update to 1.1pre1
- Disable CXXFLAGS hardcoded optimization
- Add BR: python-imaging, numpy
- Disable make check failure for now

* Wed Apr 22 2009 kwizart < kwizart at gmail.com > - 1.0.0-14
- Fix for gcc44
- Enable BR jasper-devel
- Disable ldconfig run on python modules (uneeded)
- Prevent timestamp change on install

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.0-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Dec 29 2008 Rakesh Pandit <rakesh@fedoraproject.org> - 1.0.0-12
- fix URL field

* Fri Dec 19 2008 Ralf Corsépius <corsepiu@fedoraproject.org> - 1.0.0-11
- Adopt latest python spec rules.
- Rebuild for Python 2.6 once again.

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.0.0-10
- Rebuild for Python 2.6

* Thu May 22 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.0.0-9
- fix license tag

* Sun May 11 2008 Ralf Corsépius <rc040203@freenet.de> - 1.0.0-8
- Adjust library order in opencv.pc.in (BZ 445937).

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.0.0-7
- Autorebuild for GCC 4.3

* Sun Feb 10 2008 Ralf Corsépius <rc040203@freenet.de> - 1.0.0-6
- Rebuild for gcc43.

* Tue Aug 28 2007 Fedora Release Engineering <rel-eng at fedoraproject dot org> - 1.0.0-5
- Rebuild for selinux ppc32 issue.

* Wed Aug 22 2007 Ralf Corsépius <rc040203@freenet.de> - 1.0.0-4
- Mass rebuild.

* Thu Mar 22 2007 Ralf Corsépius <rc040203@freenet.de> - 1.0.0-3
- Fix %%{_datadir}/opencv/samples ownership.
- Adjust timestamp of cvconfig.h.in to avoid re-running autoheader.

* Thu Mar 22 2007 Ralf Corsépius <rc040203@freenet.de> - 1.0.0-2
- Move all of the python module to pyexecdir (BZ 233128).
- Activate the testsuite.

* Mon Dec 11 2006 Ralf Corsépius <rc040203@freenet.de> - 1.0.0-1
- Upstream update.

* Mon Dec 11 2006 Ralf Corsépius <rc040203@freenet.de> - 0.9.9-4
- Remove python-abi.

* Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 0.9.9-3
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Thu Sep 21 2006 Ralf Corsépius <rc040203@freenet.de> - 0.9.9-2
- Stop configure.in from hacking CXXFLAGS.
- Activate testsuite.
- Let *-devel require pkgconfig.

* Thu Sep 21 2006 Ralf Corsépius <rc040203@freenet.de> - 0.9.9-1
- Upstream update.
- Don't BR: autotools.
- Install samples' Makefile as GNUmakefile.

* Thu Sep 21 2006 Ralf Corsépius <rc040203@freenet.de> - 0.9.7-18
- Un'%%ghost *.pyo.
- Separate %%{pythondir} from %%{pyexecdir}.

* Thu Sep 21 2006 Ralf Corsépius <rc040203@freenet.de> - 0.9.7-17
- Rebuild for FC6.
- BR: libtool.

* Fri Mar 17 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-16
- Rebuild.

* Wed Mar  8 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-15
- Force a re-run of Autotools by calling autoreconf.

* Wed Mar  8 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-14
- Added build dependency on Autotools.

* Tue Mar  7 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-13
- Changed intrinsics patch so that it matches upstream.

* Tue Mar  7 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-12
- More intrinsics patch fixing.

* Tue Mar  7 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-11
- Don't do "make check" because it doesn't run any tests anyway.
- Back to main intrinsics patch.

* Tue Mar  7 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-10
- Using simple intrinsincs patch.

* Tue Mar  7 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-9
- Still more fixing of intrinsics patch for Python bindings on x86_64.

* Tue Mar  7 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-8
- Again fixed intrinsics patch so that Python modules build on x86_64.

* Tue Mar  7 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-7
- Fixed intrinsics patch so that it works.

* Tue Mar  7 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-6
- Fixed Python bindings location on x86_64.

* Mon Mar  6 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-5
- SSE2 support on x86_64.

* Mon Mar  6 2006 Simon Perreault <nomis80@nomis80.org> - 0.9.7-4
- Rebuild

* Sun Oct 16 2005 Simon Perreault <nomis80@nomis80.org> - 0.9.7-3
- Removed useless sample compilation makefiles/project files and replaced them
  with one that works on Fedora Core.
- Removed shellbang from Python modules.

* Mon Oct 10 2005 Simon Perreault <nomis80@nomis80.org> - 0.9.7-2
- Made FFMPEG dependency optional (needs to be disabled for inclusion in FE).

* Mon Oct 10 2005 Simon Perreault <nomis80@nomis80.org> - 0.9.7-1
- Initial package.
