Summary: Open implementation of Service Location Protocol V2
Summary(ja): SLP (Service Location Protocol) V2 のオープンな実装
Name:    openslp
Version: 2.0.0
Release: 1%{_dist_release}

Group:   System Environment/Libraries
License: BSD
URL:     http://sourceforge.net/projects/%{name}/
Source:  http://dl.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Source1: slpd.init
Patch1:  openslp-1.2.1-optflags.patch

BuildRequires: automake
BuildRequires: libtool
BuildRequires: bison
BuildRequires: flex 
BuildRequires: openssl-devel

%description
Service Location Protocol is an IETF standards track protocol that
provides a framework to allow networking applications to discover the
existence, location, and configuration of networked services in
enterprise networks.

OpenSLP is an open source implementation of the SLPv2 protocol as defined
by RFC 2608 and RFC 2614.

%description -l ja
SLP (Service Location Protocol) は IETF ドキュメントによって標準化された、
ネットワーク上の各種サービス発見のためのプロトコルです。

この OpenSLP は、RFC 2608 および RFC 2614 で規定された SLP バージョン 2
のオープンソース版実装です。


%package devel
Summary: OpenSLP headers and libraries
Summary(ja): OpenSLP ヘッダファイルとライブラリ
Group:   Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
OpenSLP header files and libraries.

%description devel -l ja
OpenSLP のヘッダファイルとライブラリファイルが収録されています。


%package server
Summary: OpenSLP server daemon
Summary(ja): OpenSLP サーバデーモン
Group:   System Environment/Daemons
Requires: %{name} = %{version}-%{release}
Requires(preun): chkconfig, /sbin/service
Requires(post): chkconfig
Requires(postun): /sbin/service

%description server
OpenSLP server daemon to dynamically register services.

%description server -l ja
OpenSLP サーバデーモンが収録されています。


%prep
%setup -q

#%patch1 -p1 -b .optflags

# tarball goof (?), it wants to re-automake anyway, so let's do it right.
libtoolize --force
aclocal
autoconf
automake --add-missing

# remove CVS leftovers...
find . -name "CVS" | xargs rm -rf


%build

# for x86_64
export CFLAGS="-fPIC $RPM_OPT_FLAGS"
# for slpd
export LDFLAGS="-pie"

%configure \
  --disable-dependency-tracking \
  --disable-static \
  --enable-slpv2-security
# --enable-async-api

make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT

make install DESTDIR=$RPM_BUILD_ROOT

install -p -D -m755  %{SOURCE1} $RPM_BUILD_ROOT%{_initrddir}/slpd

# nuke unpackaged/unwanted files
rm -rf $RPM_BUILD_ROOT/usr/doc
rm -f  $RPM_BUILD_ROOT%{_libdir}/lib*.la


%clean
rm -rf $RPM_BUILD_ROOT


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post server
/sbin/chkconfig --add slpd

%preun server
# on remove
if [ $1 -eq 0 ]; then
  /sbin/service slpd stop >/dev/null 2>&1 ||:
  /sbin/chkconfig --del slpd
fi

%postun server
# on upgrade
if [ $1 -gt 0 ]; then
  /sbin/service slpd condrestart >/dev/null 2>&1 ||:
fi


%files
%defattr(-,root,root)
%doc AUTHORS COPYING FAQ NEWS README THANKS
%config(noreplace) %{_sysconfdir}/slp.conf
%{_bindir}/*
%{_libdir}/lib*.so.*

%files server
%defattr(-,root,root)
%doc doc/html/IntroductionToSLP
%doc doc/html/UsersGuide
%doc doc/html/faq*
%{_sbindir}/*
%config(noreplace) %{_sysconfdir}/slp.reg
%config(noreplace) %{_sysconfdir}/slp.spi
%config(noreplace) %{_initrddir}/slpd

%files devel
%defattr(-,root,root)
%doc doc/html/ProgrammersGuide
%doc doc/rfc
%{_includedir}/*
%{_libdir}/lib*.so


%changelog
* Mon Jan 12 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.0.0-1
- update to 2.0.0

* Thu Jan 13 2011 Shu KONNO <owa@bg.wakwak.com> 1.2.1-3
- rebuilt with openssl-1.0.0c

* Fri Feb 13 2009 Shu KONNO <owa@bg.wakwak.com> 1.2.1-2
- spec in utf-8

* Tue Apr 15 2008 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 1.2.1-1
- initial build for Vine Linux (based on FC8 1.2.1-7)
- add Japanese summary and description

* Tue Aug 21 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 1.2.1-7
- respin (buildID)

* Tue Aug 29 2006 Rex Dieter <rexdieter[AT]users.sf.net> 1.2.1-6
- fc6 respin

* Wed Aug 09 2006 Rex Dieter <rexdieter[AT]users.sf.net> 1.2.1-5
- fc6 respin

* Wed Mar 1 2006 Rex Dieter <rexdieter[AT]users.sf.net> 
- fc5: gcc/glibc respin

* Mon Dec 19 2005 Rex Dieter <rexdieter[AT]users.sf.net> 1.2.1-4
- make %%postun safer

* Wed Nov 16 2005 Rex Dieter <rexdieter[AT]users.sf.net> 1.2.1-3
- rebuild (for new openssl)
- make %%postun safer

* Fri Oct 21 2005 Rex Dieter <rexdieter[AT]users.sf.net> 1.2.1-2
- -fPIC (for x86_64)

* Fri Oct 21 2005 Rex Dieter <rexdieter[AT]users.sf.net> 1.2.1-1
- 1.2.1
- move most docs to -server
- --enable-slpv2-security
- --disable-dependency-tracking

* Sun May 22 2005 Jeremy Katz <katzj@redhat.com> - 1.2.0
- rebuild on all arches

* Thu Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- rebuilt

* Mon Jul 19 2004 Rex Dieter <rexdieter at sf.net> 0:1.2.0-0.fdr.4
- BR: flex

* Fri Jul 16 2004 Rex Dieter <rexdieter at sf.net> 0:1.2.0-0.fdr.3
- BR: bison

* Thu Jul 15 2004 Rex Dieter <rexdieter at sf.net> 0:1.2.0-0.fdr.2
- fix/add condrestart to init script

* Thu Jul 15 2004 Rex Dieter <rexdieter at sf.net> 0:1.2.0-0.fdr.1
- 1.2.0
- use -pie
- don't use Requires(post,postun)

* Fri Oct 24 2003 Rex Dieter <rexdieter af sf.net> 0:1.0.11-0.fdr.7
- fix for Fedora Core
- fix description (main package does *not* include daemon and header files).

* Fri May 30 2003 Rex Dieter <rexdieter at sf.net> 0:1.0.11-0.fdr.6
- -server: Requires(preun,postun): /sbin/service
- add a few more %%doc files to base pkg.
- initscript: add (real) 'reload' action.
- initscript: use $prog instead of hardcoded slpd.

* Fri May 16 2003 Rex Dieter <rexdieter at sf.net> 0:1.0.11-0.fdr.5
- -server: fix %postun on uninstall

* Fri May 2 2003 Rex Dieter <rexdieter at sf.net> 0:1.0.11-0.fdr.4
- *really* do %%config(noreplace) slp.conf

* Thu May 1 2003 Rex Dieter <rexdieter at sf.net> 0:1.0.11-0.fdr.3
- capitalize Summary's.
- %%config(noreplace) slp.conf

* Thu May 1 2003 Rex Dieter <rexdieter at sf.net> 0:1.0.11-0.fdr.2
- docs: remove CVS files, include rfc, move ProgrammersGuide to -devel.
- improve sub-pkg descriptions.
- improve server %%preun,%%postun scripts: condrestart on upgrade,
  suppress output of server shutdown,restarts.

* Thu May 1 2003 Rex Dieter <rexdieter at sf.net> 0:1.0.11-0.fdr.1
- specfile cleanups for fedora packaging.

* Tue Apr 29 2003 Rex Dieter <rexdieter at sf.net> 0:1.0.11-0.fdr.0
- 1.0.11 release.
- fedorize things

* Mon Feb 03 2003 Rex Dieter <rexdieter at sf.net> 0:1.0.10-1.0
- sanitize specfile
- -devel,-server subpkgs.
