%bcond_with systemd
%bcond_with quota_enables_tcpwrappers

Name: quota
Summary: System administration tools for monitoring users' disk usage.
Summary(ja): ユーザのディスク使用量をモニタするシステム管理ツール
Version: 4.06
Release: 1%{?_dist_release}%{?with_systemd:.systemd}
Group: system
Vendor: Project Vine
Distribution: Vine Linux

License: GPLv2 and GPLv2+
URL: https://sourceforge.net/projects/linuxquota/
Source0: http://downloads.sourceforge.net/linuxquota/quota-%{version}.tar.gz
Source1: quota_nld.init
Source2: quota_nld.sysconfig

Source101: quota_nld.service
Source103: rpc-rquotad.service
Source104: rpc-rquotad.sysconfig

# Not accepted changes (378a64006bb1e818e84a1c77808563b802b028fa), bug #680919
Patch0:     quota-4.06-warnquota-configuration-tunes.patch
# Fix parsing a TCP port number
Patch1:     quota-4.03-Validate-upper-bound-of-RPC-port.patch
# Remove a dead code from process_file(), in upstream after 4.06,
# <https://sourceforge.net/p/linuxquota/patches/54/>
Patch2:     quota-4.06-quotacheck-Remove-a-dead-code-from-process_file.patch
# Fix a compilation warning in quotaops.c, in upstream after 4.06
Patch3:     quota-4.06-quotaops-fix-compilation-warning.patch
# Warn when kernel XFS large time stamp does fit into (32-bit) user-space
# time_t, in upstream after 4.06
Patch4:     quota-4.06-quotaio_xfs-Warn-when-large-kernel-timestamps-cannot.patch
# Do not use a pointless compiler-internal __P() macro, in upstream after 4.06
Patch5:     quota-4.06-Drop-sys-cdefs.h-usage.patch

BuildRoot: %{_tmppath}/%{name}-root
BuildRequires: e2fsprogs-devel, gettext
BuildRequires: nss-devel
BuildRequires: openldap-devel, openssl-devel, dbus-devel, libnl3-devel
BuildRequires: rpcgen
BuildRequires: pkgconfig(libtirpc)
%if %{with quota_enables_tcpwrappers}
BuildRequires: tcp_wrappers
Requires: tcp_wrappers
%endif
Conflicts: nfs-utils < 1.0.1
%if %{with systemd}
BuildRequires:  systemd
Requires: kernel >= 4.0
%{?systemd_requires}
%else
Requires: kernel >= 4.0, initscripts >= 6.38
Requires(post): chkconfig
Requires(preun): chkconfig
%endif

%description
The quota package contains system administration tools for monitoring
and limiting user and or group disk usage per filesystem.

%description -l ja
quota パッケージには，ユーザやグループのディスク使用量を監視したり
制限したりできるシステム管理ツールが収録されています．これらの操作
はファイルシステム単位で行うことが出来ます．
ユーザやグループのディスク使用量を監視/制限した場合は quota をイン
ストールして下さい．


%debug_package


%prep
%setup -q
%autopatch -p1
# Regenerate build scripts
autoreconf -f -i


%build
%configure \
    --enable-bsd-behaviour \
    --enable-ext2direct=yes \
    --enable-ldapmail=yes \
%if %{with quota_enables_tcpwrappers}
    --enable-libwrap=yes \
%else
    --disable-libwrap \
%endif
    --enable-netlink=yes \
    --enable-nls \
    --with-pid-dir=/run \
    --disable-rpath \
    --enable-rpc=yes \
    --enable-rpcsetquota=yes \
    --disable-silent-rules \
    --disable-xfs-roothack \
    --enable-rootsbin=yes \
    --enable-strip-binaries=no
make %{?_smp_mflags}


%install
rm -fr %{buildroot}
mkdir -p %{buildroot}/sbin
mkdir -p %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/{man1,man3,man8}

make install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_datadir}/doc/%{name}

install -p -m644 -D %{SOURCE2} \
    $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/quota_nld
install -m 644 warnquota.conf %{buildroot}%{_sysconfdir}
%if %{with systemd}
install -p -m644 -D %{SOURCE101} $RPM_BUILD_ROOT%{_unitdir}/quota_nld.service
install -p -m644 -D %{SOURCE103} $RPM_BUILD_ROOT%{_unitdir}/rpc-rquotad.service
install -p -m644 -D %{SOURCE104} \
    $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/rpc-rquotad
%else
install -p -m755 -D %{SOURCE1} $RPM_BUILD_ROOT%{_initrddir}/quota_nld
%endif

mv %{buildroot}%{_sbindir}/quota{check,off,on} %{buildroot}/sbin/

%find_lang %{name}


%check
make check


%clean
rm -rf %{buildroot}


%post
%if %{with systemd}
%systemd_post quota_nld.service
%systemd_post rpc-rquotad.service
%else
/sbin/chkconfig --add quota_nld
%endif

%preun
%if %{with systemd}
%systemd_preun quota_nld.service
%systemd_preun rpc-rquotad.service
%else
if [ $1 = 0 -o -x /bin/systemctl ] ; then
    /sbin/service quota_nld stop >/dev/null 2>&1
    /sbin/chkconfig --del quota_nld
fi
%endif

%if %{with systemd}
%postun
%systemd_postun_with_restart quota_nld.service
%systemd_postun_with_restart rpc-rquotad.service
%endif


%files -f %{name}.lang
%defattr(-,root,root)
%license COPYING
%doc Changelog doc/ README*
%config(noreplace) %{_sysconfdir}/warnquota.conf
%config(noreplace) %{_sysconfdir}/quotagrpadmins
%config(noreplace) %{_sysconfdir}/quotatab
/sbin/*
%{_bindir}/*
%{_sbindir}/*
%{_includedir}/rpcsvc/*
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/sysconfig/quota_nld
%if %{with systemd}
%{_unitdir}/quota_nld.service
%{_unitdir}/rpc-rquotad.service
%config(noreplace) %{_sysconfdir}/sysconfig/rpc-rquotad
%else
%{_initrddir}/quota_nld
%endif


%changelog
* Thu Mar 04 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 4.06-1
- new upstram release.
- updated all patches.

* Thu Aug 13 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 4.05-1
- new upstram release.
- updated all patches.
- disabled tcp_wrappers as default.
- added systemd support (disabled as default).

* Thu Nov 29 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 4.04-1
- new upstram release.
- dropped BR:libnl-devel.
- added BR:libnl3-devel.
- dropped all patches.
- imported patched from rawhide.

* Mon Mar 12 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 4.00-1
- new upstram release
- add BR: tcp_wrappers, nss-devel, openldap-devel, 
  openssl-devel, dbus-devel, libnl-devel

* Sun Apr 17 2011 Shu KONNO <owa@bg.wakwak.com> 3.15-2
- rebuilt with rpm-4.8.1-3

* Fri Aug 15 2008 Shu KONNO <owa@bg.wakwak.com> 3.15-1vl5
- applied new versioning policy, spec in utf-8

* Thu Dec 20 2007 Shu KONNO <owa@bg.wakwak.com> 3.15-0vl1
- updated quota to 3.15

* Wed Apr 27 2005 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 3.12-5vl2
- oops, removed unnecessary Patch3

* Tue Apr 26 2005 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 3.12-5vl1
- based on 3.12-5, being merged into 3.06-7vl1

  - Sun Sep 26 2004 Rik van Riel <riel@redhat.com> 3.12-5
  - add URL (bz# 131862)

  - Fri Sep 24 2004 Steve Dickson <SteveD@RedHat.com>
  - Fixed typos in warnquota.conf patch
    (bz# 82250 and bz# 83974)

  - Mon Sep 13 2004 Steve Dickson <SteveD@RedHat.com>
  - upgraded to 3.12

  - Tue Jan 27 2004 Florian La Roche <Florian.LaRoche@redhat.de>
  - add -pie support
  - update to 3.10

  - Sat Aug 16 2003  Steve Dickson <SteveD@RedHat.com>
  - upgraded to 3.0.9
  - added quota-3.09-root_sbindir.patch

* Sun Feb  9 2003 Daisuke SUZUKI <daisuke@linux.or.jp> 3.06-7vl1
- merged with Vine Linux package (quota-2.00stable-0vl1)
- based on rawhide release 3.06-7
 * Wed May 30 2001 Jun Nishii <jun@vinelinux.org>
 - 2.00stable-0vl1
 - ver.up
 * Wed May 30 2001 Jun Nishii <jun@vinelinux.org>
 - 2.00pre3-8vl2
 - added documents
 * Tue Jan 09 2001 MATSUBAYASHI 'Shaolin' Kohji <shaolin@rhythmaning.org>
 - 2.00pre3-8vl1
 - based on 2.00pre3-8 from Rawhide
 - added Japanese summary and description

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Mon Nov 18 2002 Tim Powers <timp@redhat.com>
- rebuild on all arches


* Fri Sep 6 2002 Philip Copeland <bryce@redhat.com> 3.06-5
- added --with-ext2direct=no to fix #73244
  without this users with UID's > 65535 will not
  be able to exist on a quota enabled FS

* Wed Aug 7 2002 Philip Copeland <bryce@redhat.com> 3.06-4
- Man page change. #60108

* Tue Aug 6 2002 Philip Copeland <bryce@redhat.com> 3.06-3
- Bah, I'd dropped epoch from the spec file but seems
  we need this if you want to upgrade as the epoch
  number has precedence over the version/release
  numbers.

* Wed Jul 17 2002 Philip Copeland <bryce@redhat.com> 3.06-2
- Lets stop the makefile from stripping the
  binaries as thats rpms job (apparently)

* Mon Jul 01 2002 Philip Copeland <bryce@redhat.com> 3.06-1
- Ditched the 3.01-pre9 src base for 3.06
  Rebuilt without any patchs

============================================================

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Mon Feb 25 2002 Elliot Lee <sopwith@redhat.com>
- IfArch the badkernelinclude patch for ppc-only.
- Update to 3.03

* Wed Dec 12 2001 Guy Streeter <streeter@redhat.com>
- Make #include of kernel header file work on non-x86

* Wed Sep  5 2001 Preston Brown <pbrown@redhat.com>
- require new initscripts

* Thu Aug 30 2001 Preston Brown <pbrown@redhat.com>
- fixed bug #52075 (problem with ext2 labels)
- backup data files off by default in quotacheck, optional backup flag added
- fix bug where giving a bad directory or device would cause 
  quotaon/quotacheck to simulate "-a" behaviour
- if a device name (i.e /dev/hda1) is passed, look up the corresponding mount
  point

* Wed Aug 29 2001 Preston Brown <pbrown@redhat.com>
- return an error code in more cases in convertquota

* Tue Aug 28 2001 Preston Brown <pbrown@redhat.com>
- 3.01pre9

* Fri Jul 20 2001 Preston Brown <pbrown@redhat.com>
- more cleanups on 3.01pre8

* Mon Jul  2 2001 Preston Brown <pbrown@redhat.com>
- 3.01 version, everything has changed again. :(

* Sun Jun 24 2001 Elliot Lee <sopwith@redhat.com>
- Bump release + rebuild.

* Fri Mar 30 2001 Preston Brown <pbrown@redhat.com>
- use rpc.rquotad from here again (#33738)

* Thu Mar 15 2001 Preston Brown <pbrown@redhat.com>
- enable ALT_FORMAT for edquota

* Tue Mar 13 2001 Preston Brown <pbrown@redhat.com>
- I broke passing devices on the cmd line.  Fixed.

* Fri Mar 09 2001 Preston Brown <pbrown@redhat.com>
- quota 3.00 is required by recent kernel 2.4 changes
- no warnquota included this time, not yet ported
- quite a bit of work on quotacheck to make is backwards compatible
- we will likely go back to "quota 2.00" as these projects merge...

* Fri Feb 09 2001 Florian La Roche <Florian.LaRoche@redhat.de>
- use "rm -f" instead of only "rm"

* Wed Feb  7 2001 Preston Brown <pbrown@redhat.com>
- fix quotacheck man page for -a option (#26380)

* Thu Feb  1 2001 Preston Brown <pbrown@redhat.com>
- 2.00 final, rolls in pretty much all our patches. :)
- fix reporting of in use dquot entries from quotastats
- change repquota man page to fix documentation of -v (#10330)
- include warnquota.conf

* Mon Nov 20 2000 Bill Nottingham <notting@redhat.com>
- fix ia64 build

* Mon Aug 21 2000 Jeff Johnson <jbj@redhat.com>
- add LABEL=foo support (#16390).

* Thu Jul 27 2000 Jeff Johnson <jbj@redhat.com>
- remote NFS quotas with different blocksize converted incorrectly (#11932).

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Thu Jun 15 2000 Jeff Johnson <jbj@redhat.com>
- FHS packaging.

* Wed May 10 2000 Jeff Johnson <jbj@redhat.com>
- apply patch5 (H.J. Lu)

* Wed Feb 02 2000 Cristian Gafton <gafton@redhat.com>
- fix description
- man pages are compressed

* Tue Jan 18 2000 Preston Brown <pbrown@redhat.com>
- quota 2.00 series
- removed unnecessary patches

* Thu Aug  5 1999 Jeff Johnson <jbj@redhat.com>
- fix man page FUD (#4369).

* Thu May 13 1999 Peter Hanecak <hanecak@megaloman.sk>
- changes to allow non-root users to build too (Makefile patch, %attr)

* Tue Apr 13 1999 Jeff Johnson <jbj@redhat.com>
- fix for sparc64 quotas (#2147)

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 5)

* Mon Dec 28 1998 Cristian Gafton <gafton@redhat.com>
- don't install rpc.rquotad - we will use the one from the knfsd package
  instead

* Thu Dec 17 1998 Jeff Johnson <jbj@redhat.com>
- merge ultrapenguin 1.1.9 changes.

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Thu Apr 30 1998 Cristian Gafton <gafton@redhat.com>
- removed patch for mntent

* Fri Mar 27 1998 Jakub Jelinek <jj@ultra.linux.cz>
- updated to quota 1.66

* Tue Jan 13 1998 Erik Troan <ewt@redhat.com>
- builds rquotad
- installs rpc.rquotad.8 symlink

* Mon Oct 20 1997 Erik Troan <ewt@redhat.com>
- removed /usr/include/rpcsvc/* from filelist
- uses a buildroot and %attr

* Thu Jun 19 1997 Erik Troan <ewt@redhat.com>
- built against glibc

* Tue Mar 25 1997 Erik Troan <ewt@redhat.com>
- Moved /usr/sbin/quota to /usr/bin/quota
