Name: time
Summary: A GNU utility for monitoring a program's use of system resources.
Summary(ja): プログラムのシステムリソース使用をモニタする GNU ユーティリティ
Version: 1.9
Release: 1%{?_dist_release}
Group: system
Vendor: Project Vine
Distribution: Vine Linux

License: GPLv3+ and GFDL
URL: http://www.gnu.org/software/time/
Source0: https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz
# Fix measuring time when a clock experiences a jump, bug #1004416,
# <http://lists.gnu.org/archive/html/bug-gnu-utils/2013-09/msg00003.html>
Patch0:     time-1.8-Prefer-clock_gettime-CLOCK_MONOTONIC.patch
# Fix info directory entry
Patch1:     time-1.9-Improve-info-directory-index-entry-description.patch
# Clarify RSS size as kibibytes in a documentation, proposed to an upstream,
# <https://lists.gnu.org/archive/html/bug-time/2020-07/msg00000.html>
Patch2:     time-1.9-Use-kibibytes-instead-of-kilobytes-in-a-documentatio.patch
# Do not leak a file descriptor of the --output argument to a command,
# proposed to an upstream,
# <https://lists.gnu.org/archive/html/bug-time/2020-11/msg00001.html>
Patch3:     time-1.9-Close-outfp-before-exec.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: texinfo
Requires(post): /sbin/install-info
Requires(preun): /sbin/install-info

%description
The GNU time utility runs another program, collects information about
the resources used by that program while it is running, and displays
the results.

%description -l ja
GNU time ユーティリティは，他のプログラムを実行し，そのプログラムが
実行される際にシステムリソースをどの程度使用したかの情報を表示します．


%debug_package


%prep
%setup -q
%autopatch -p1
# Set time stamp stored in an info page to the latest patch
touch -d "$(sed -n -e '/^Date: /{s/^[^:]*: //;p}' %{PATCH2})" doc/time.texi
# Correct version VERSION flag for doc/time.texi
# <https://lists.gnu.org/archive/html/bug-time/2021-01/msg00000.html>
printf '%{version}\n' > .tarball-version
autoreconf -fi


%build
%configure
make %{?_smp_mflags}


%install
rm -rf %{buildroot}
make install DESTDIR=$RPM_BUILD_ROOT
# Remove info index, it's updated by file triggers
rm -f $RPM_BUILD_ROOT%{_infodir}/dir


%check
%{make_build} check


%post
/sbin/install-info %{_infodir}/time.info.gz %{_infodir}/dir \
    --entry="* time: (time).        GNU time Utility" || :

%preun
if [ "$1" = 0 ]; then
    /sbin/install-info --delete %{_infodir}/time.info.gz %{_infodir}/dir \
    --entry="* time: (time).        GNU time Utility" || :
fi


%files
%defattr(-,root,root)
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/time
%{_infodir}/time.info*


%changelog
* Sat Mar 20 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.9-1
- new upstream release.
- dropped all patches.
- imported Patch0-3 from rawhide.

* Wed Jan 15 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.7-24
- rebuild with VineSeed environment

* Sun Apr 10 2011 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.7-23
- rebuilt with current VineSeed

* Thu Oct 23 2008 Shu KONNO <owa@bg.wakwak.com> 1.7-22
- spec in utf-8

* Tue Apr 29 2008 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.7-21
- applied new versioning policy
- added Patches from Fedora
  * Tue Mar  4 2008 Roman Rakus <rrakus@redhat.cz> - 1.7-33
  - Added patch from JW (redhat@zacglen.com), less nonverbose output
  * Tue Feb 27 2007 Karsten Hopp <karsten@redhat.com> 1.7-29
  - use make install DESTDIR=

* Wed Jun 07 2006 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 1.7-20vl2
- rebuilt with new toolchains
- updated source URL

* Wed Dec 04 2002 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 1.7-20vl1
- based on 1.7-20 from Rawhide and built for Vine Linux
- added Japanese summary and description

* Tue Nov 19 2002 Tim Powers <timp@redhat.com>
- rebuild on all arches

* Fri Jun 21 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Wed Jun 19 2002 Florian La Roche <Florian.LaRoche@redhat.de>
- do not strip apps, do not compress info page

* Thu May 23 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Mon Feb 25 2002 Elliot Lee <sopwith@redhat.com>
- Remove HAVE_WAIT3 hack, tried to replace it with a requirement for an 
autoconf with the fixed test, didn't work, put in another less-bad hack 
instead.

* Wed Dec 05 2001 Tom Tromey <tromey@redhat.com>
- Bump release, force HAVE_WAIT3 to be defined at build time

* Sun Jun 24 2001 Elliot Lee <sopwith@redhat.com>
- Bump release + rebuild.

* Wed Jan 31 2001 Preston Brown <pbrown@redhat.com>
- prereq install-info (#24715)

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Thu Jun 29 2000 Preston Brown <pbrown@redhat.com>
- using / as the file manifesto has weird results.

* Sun Jun  4 2000 Jeff Johnson <jbj@redhat.com>
- FHS packaging.

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 9)

* Mon Aug 10 1998 Erik Troan <ewt@redhat.com>
- buildrooted and defattr'd

* Mon Apr 27 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Mon Oct 27 1997 Cristian Gafton <gafton@redhat.com>
- fixed info handling

* Thu Oct 23 1997 Cristian Gafton <gafton@redhat.com>
- updated the spec file; added info file handling

* Mon Jun 02 1997 Erik Troan <ewt@redhat.com>
- built against glibc
