%bcond_with systemd

Summary:	Daemon for communicating with Apple's iPod Touch and iPhone
Summary(ja):	Apple の iPod Touch や iPhone と通信するためのデーモン
Name:		usbmuxd
Version:	1.1.1
Release:	1%{?_dist_release}%{?with_systemd:.systemd}
Vendor:		Project Vine
Distribution:	Vine Linux
Packager:	daisuke

# All code is dual licenses as GPLv3+ or GPLv2+
License:	GPLv3+ or GPLv2+
URL:           	https://libimobiledevice.org/
Source0:       	https://github.com/libimobiledevice/usbmuxd/releases/download/%{version}/%{name}-%{version}.tar.bz2

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires:	libusb1-devel
BuildRequires:  libimobiledevice-devel
BuildRequires:  libplist-devel
Requires(pre):  shadow-utils
Obsoletes:      usbmuxd-devel < 1.0.9

%if %{with systemd}
BuildRequires:  systemd-devel
%{?systemd_requires}
%else
BuildRequires:  eudev-libgudev1-devel
Requires:       eudev
%endif

%description
usbmuxd is a daemon used for communicating with Apple's iPod Touch and iPhone
devices. It allows multiple services on the device to be accessed
simultaneously.


%prep
%setup -q

# Set the owner of the device node to be usbmuxd
sed -i.owner 's/OWNER="usbmux"/OWNER="usbmuxd"/' udev/39-usbmuxd.rules.in
sed -i.user 's/-U usbmux/-U usbmuxd/' udev/39-usbmuxd.rules.in


%build
#NOCONFIGURE=1 ./autogen.sh
%configure \
    --with-udevrulesdir=/lib/udev/rules.d \
%if !%{with systemd}
    --without-systemd
%endif
    %{nil}

make %{?_smp_mflags}


%install
make install DESTDIR=$RPM_BUILD_ROOT
rm -f %{buildroot}/usr/lib/udev/rules.d/39-usbmuxd.rules


%clean
rm -rf $RPM_BUILD_ROOT


%pre
getent group usbmuxd >/dev/null || groupadd -r usbmuxd
getent passwd usbmuxd >/dev/null || \
useradd -r -g usbmuxd -d / -s /sbin/nologin \
	-c "usbmuxd user" usbmuxd
exit 0

%if %{with systemd}
%post
%systemd_post usbmuxd.service

%preun
%systemd_preun usbmuxd.service

%postun
%systemd_postun_with_restart usbmuxd.service
%endif


%files
%defattr(-,root,root,-)
%license COPYING.GPLv2 COPYING.GPLv3
%doc AUTHORS README.md
/lib/udev/rules.d/39-usbmuxd.rules
%{_sbindir}/usbmuxd
%{_mandir}/man*/*
%if %{with systemd}
%{_unitdir}/usbmuxd.service
%endif


%changelog
* Sun Aug 02 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 1.1.1-1
- new upstream release.
- added systemd support (disabled as default).

* Thu May 21 2015 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 1.0.9-2
- rebuilt with libimobiledevice 1.2.0 and libplist 1.12
- added --without-systemd option

* Wed Jul 09 2014 Daisuke SUZUKI <daisuke@vinelinux.org> 1.0.9-1
- update to 1.0.9

* Sat Jan 04 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp>  1.0.8-2
- rebuild with VineSeed environment

* Sat Apr 14 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp>  1.0.8-1
- new upstream release

* Fri Apr 15 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 	1.0.7-1
- new upstream release

* Tue Dec 28 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.6-1
- new upstream release

* Thu Sep 30 2010 Shu KONNO <owa@bg.wakwak.com> 1.0.4-3
- rebuilt with rpm-4.8.1 for pkg-config

* Sun Jun 27 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.4-2
- set the owner of the device node to be usbmuxd

* Sat Jun 26 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.4-1
- new upstream release

* Thu Apr 29 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.0.3-1
- initial build for Vine Linux

* Mon Mar 22 2010 Peter Robinson <pbrobinson@gmail.com> 1.0.3-1
- New stable 1.0.3 release

* Thu Feb 11 2010 Peter Robinson <pbrobinson@gmail.com> 1.0.2-1
- New stable 1.0.2 release

* Tue Feb 09 2010 Bastien Nocera <bnocera@redhat.com> 1.0.0-3
- Use the gid/uid reserved for usbmuxd in setup 2.8.15 and above

* Fri Jan 29 2010 Peter Robinson <pbrobinson@gmail.com> 1.0.0-2
- Run deamon under the usbmuxd user

* Mon Dec  7 2009 Peter Robinson <pbrobinson@gmail.com> 1.0.0-1
- New stable 1.0.0 release

* Sat Oct 31 2009 Peter Robinson <pbrobinson@gmail.com> 1.0.0-0.1.rc2
- New 1.0.0-rc2 test release

* Thu Oct 29 2009 Peter Robinson <pbrobinson@gmail.com> 1.0.0-0.2.rc1
- Add patch to fix install of 64 bit libs

* Tue Oct 27 2009 Peter Robinson <pbrobinson@gmail.com> 1.0.0-0.1.rc1
- New 1.0.0-rc1 test release

* Fri Aug 14 2009 Bastien Nocera <bnocera@redhat.com> 0.1.4-2
- Make usbmuxd autostart on newer kernels
- (Still doesn't exit properly though)

* Mon Aug 10 2009 Peter Robinson <pbrobinson@gmail.com> 0.1.4-1
- Update to 0.1.4

* Tue Aug  4 2009 Peter Robinson <pbrobinson@gmail.com> 0.1.3-1
- Update to 0.1.3, review input

* Mon Aug  3 2009 Peter Robinson <pbrobinson@gmail.com> 0.1.2-1
- Update to 0.1.2

* Mon Aug  3 2009 Peter Robinson <pbrobinson@gmail.com> 0.1.1-1
- Initial packaging
