%global api_ver 0.48
%define _unpackaged_files_terminate_build 1

Summary:        A modern programming language for GNOME
Summary(ja):    GNOME 用のモダンなプログラミング言語

Name:           vala
# LTS 0.48
Version:        0.48.19
Release:        1%{?_dist_release}
Group:          programming
Vendor:         Project Vine
Distribution:   Vine Linux

# Most files are LGPLv2.1+, curses.vapi is 2-clause BSD
License:        LGPLv2+ and BSD
URL:            https://wiki.gnome.org/Projects/Vala
%global         shortver %(echo %{version} | sed -e 's/\.[0-9]*$//')
Source0:        https://download.gnome.org/sources/vala/%{shortver}/vala-%{version}.tar.xz

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires:	glib2-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  libxslt
BuildRequires:  graphviz-devel
Requires:       %{name}-libs = %{version}-%{release}
Obsoletes:      %{name}-tools < 0.48.15
Provides:       %{name}-tools = %{version}-%{release}
Provides:       vala(api) = %{api_ver}

%description
Vala is a new programming language that aims to bring modern programming
language features to GNOME developers without imposing any additional
runtime requirements and without using a different ABI compared to
applications and libraries written in C.

valac, the Vala compiler, is a self-hosting compiler that translates
Vala source code into C source and header files. It uses the GObject
type system to create classes and interfaces declared in the Vala source
code. It's also planned to generate GIDL files when gobject-
introspection is ready.

The syntax of Vala is similar to C#, modified to better fit the GObject
type system.


%package        libs
Summary:        Vala compiler library
Summary(ja):    Valaコンパイラの共有ライブラリ
Group:          system,programming
Provides:       libvala = %{version}-%{release}

%description    libs
Vala is a new programming language that aims to bring modern programming
language features to GNOME developers without imposing any additional
runtime requirements and without using a different ABI compared to
applications and libraries written in C.

This package contains the shared libvala library.


%package        devel
Summary:        Development files for %{name}
Summary(ja):    %{name} の開発用ファイル
Group:          programming
Requires:       %{name}-libs = %{version}-%{release}
Requires:       pkgconfig
Provides:       libvala-devel = %{version}-%{release}

%description    devel
Vala is a new programming language that aims to bring modern programming
language features to GNOME developers without imposing any additional
runtime requirements and without using a different ABI compared to
applications and libraries written in C.

This package contains development files for %{name}. This is not necessary for
using the %{name} compiler.


%package        doc
Summary:        Documentation for %{name}
Summary(ja):    %{name} のドキュメント
Group:          documentation
License:        LGPLv2+

BuildArch:	noarch
Requires:       %{name} = %{version}-%{release}
Requires:       devhelp
Provides:       %{name}-docs = %{version}-%{release}
Obsoletes:      %{name}-docs < %{version}-%{release}

%description    doc
Vala is a new programming language that aims to bring modern programming
language features to GNOME developers without imposing any additional
runtime requirements and without using a different ABI compared to
applications and libraries written in C.

This package contains documentation in a devhelp HTML book.


%package -n     valadoc
Summary:        Vala documentation generator
Summary(ja):    Valaのドキュメントジェネレータ
Group:          programming
License:        LGPLv2+
Requires:       vala = %{version}-%{release}

%description -n valadoc
Valadoc is a documentation generator for generating API documentation from Vala
source code.


%package -n     valadoc-devel
Summary:        Development files for valadoc
Summary(ja):    valadocを利用した開発のためのファイル群
Group:          programming
License:        LGPLv2+
Requires:       valadoc = %{version}-%{release}

%description -n valadoc-devel
Valadoc is a documentation generator for generating API documentation from Vala
source code.

The valadoc-devel package contains libraries and header files for
developing applications that use valadoc.


%debug_package


%prep
%setup -q

%build
%configure --enable-vapigen
# Don't use rpath!
sed -i 's|/lib /usr/lib|/lib /usr/lib /lib64 /usr/lib64|' libtool
make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
find %{buildroot}%{_libdir} -type f -name 'lib*.la' | xargs rm -f

%check
make check


%files
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS ChangeLog NEWS README THANKS
%{_bindir}/vala
%{_bindir}/valac
%{_bindir}/vala-%{api_ver}
%{_bindir}/valac-%{api_ver}
%{_bindir}/vala-gen-introspect
%{_bindir}/vala-gen-introspect-%{api_ver}
%{_bindir}/vapigen
%{_bindir}/vapigen-%{api_ver}
%{_datadir}/aclocal/vala.m4
%{_datadir}/aclocal/vapigen.m4
%{_datadir}/vala
%{_datadir}/vala-%{api_ver}
%{_libdir}/pkgconfig/vapigen.pc
%{_libdir}/pkgconfig/vapigen-%{api_ver}.pc
%{_libdir}/vala-%{api_ver}
%{_mandir}/*/valac*
%{_mandir}/*/*gen*

%files libs
%{_libdir}/libvala-%{api_ver}.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/vala-%{api_ver}
%{_libdir}/libvala-%{api_ver}.so
%{_libdir}/pkgconfig/libvala-%{api_ver}.pc

%files doc
%defattr(-,root,root,-)
%{_datadir}/devhelp/books/vala-%{api_ver}

%files -n valadoc
%defattr(-,root,root,-)
%{_bindir}/valadoc*
%{_libdir}/libvaladoc-%{api_ver}.so.*
%{_libdir}/valadoc-%{api_ver}
%{_datadir}/valadoc-%{api_ver}
%{_mandir}/*/valadoc*

%files -n valadoc-devel
%{_libdir}/libvaladoc-%{api_ver}.so
%{_libdir}/pkgconfig/valadoc-%{api_ver}.pc
%{_includedir}/valadoc-%{api_ver}


%changelog
* Fri Aug 27 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.48.19-1
- new upstream release.

* Thu Apr 15 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.48.17-1
- new upstream release.

* Sun Apr 11 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.48.16-1
- new upstream release.

* Tue Mar 23 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.48.15-1
- new upstream release.
- dropped ldconfig scriptlets.
- unified vala-tools into main package.
- separated libvala as vala-libs.

* Thu Feb 25 2021 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.48.13-1
- new upstream release.

* Mon Aug 03 2020 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.48.8-1
- new upstream release.

* Sun Sep 01 2019 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.44.7-1
- new upstream release.

* Mon Dec 10 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.40.11-1
- new upstream release (LTS 0.40).

* Sat Jan 06 2018 Tomohiro "Tomo-p" KATO <tomop@teamgedoh.net> 0.38.4-1
- new upstream release.
- added subpackages "valadoc" and "valadoc-devel".

* Thu Jul 14 2016 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.32.1-1
- new upstream release

* Thu Oct 29 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.30.0-1
- new upstream release

* Sun Aug 30 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.28.1-1
- new upstream release

* Sat Mar 28 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.28.0-1
- new upstream release

* Wed Jan 28 2015 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.26.2-1
- new upstream release

* Sat Nov  8 2014 Ryoichi INAGAKI <ryo1@toki.waseda.jp> 0.26.1-1
- new upstream release
- moved tools subpackage to Development/Tools Group

* Fri Mar 28 2014 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.24.0-1
- new upstream release

* Sun Nov 24 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.22.1-1
- new upstream release

* Sat Oct 26 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.22.0-1
- new upstream release

* Wed Apr 17 2013 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.20.1-1
- new upstream release

* Wed Nov 14 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.18.1-1
- new upstream release

* Sat Sep 29 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.18.0-1
- new upstream release

* Mon Jun 25 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.16.1-1
- new upstream release

* Sun Apr 01 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.16.0-1
- new upstream release

* Wed Feb 15 2012 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.14.2-1
- new upstream release

* Fri Dec 23 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.14.1-1
- new upstream release

* Fri Sep 23 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.14.0-1
- new upstream release
- remove BuildRequires: gtk2-devel, xulrunner-devel
- add BuildRequires: glib2-devel, libxslt

* Sun Aug 14 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.12.1-1
- new upstream release
- remove BuildRequires: devhelp

* Mon Jan 3 2011 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.10.2-1
- new upstream release

* Thu Oct 28 2010 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.10.1-1
- new upstream release

* Sun Oct 03 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.10.0-1
- new upstream release

* Mon Sep 27 2010 Shu KONNO <owa@bg.wakwak.com> 0.9.8-2
- rebuilt with rpm-4.8.1 for pkg-config

* Tue Sep 14 2010 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.9.8-1
- new upstream release
- made -doc subpackage noarch

* Sun Aug 22 2010 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.9.7-1
- new upstream release

* Wed Aug 11 2010 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.9.5-1
- new upstream release

* Fri Aug 6 2010 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.9.4-1
- new upstream release

* Wed May 12 2010 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.8.1-1
- new upstream release

* Sun Apr 04 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 0.8.0-1
- new upstream release
- change BuildRequires: gecko-libs -> xulrunner-devel

* Wed Feb 17 2010 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.7.10-1
- new upstream release

* Wed Dec 30 2009 Toshiharu Kudoh <toshi.kd2@gmail.com> 0.7.9-1
- new upstream release

* Mon Oct 19 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 0.7.7-1
- new upstream release

* Mon Oct 19 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 0.7.5-1
- initial build for Vine Linux

* Thu Aug 20 2009 Michel Salim <salimma@fedoraproject.org> - 0.7.5-1
- Update to 0.7.5

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jul 14 2009 Michel Salim <salimma@fedoraproject.org> - 0.7.4-2
- Patch broken ModuleInit attribute (upstream bug 587444)

* Tue Jul  7 2009 Michel Salim <salimma@fedoraproject.org> - 0.7.4-1
- Update to 0.7.4

* Wed Jun  3 2009 Peter Robinson <pbrobinson@gmail.com> - 0.7.3-1
- Update to 0.7.3

* Sat Apr 18 2009 Michel Salim <salimma@fedoraproject.org> - 0.6.1-1
- Update to 0.6.1

* Mon Feb 23 2009 Michel Salim <salimma@fedoraproject.org> - 0.5.7-1
- Update to 0.5.7

* Tue Jan 27 2009 Michel Salim <salimma@fedoraproject.org> - 0.5.6-1
- Update to 0.5.6

* Tue Dec 16 2008 Michel Salim <salimma@fedoraproject.org> - 0.5.3-1
- Update to 0.5.3

* Mon Dec 15 2008 Michel Salim <salimma@fedoraproject.org> - 0.5.2-3
- Fix bug in Emacs version detection

* Sat Dec 13 2008 Michel Salim <salimma@fedoraproject.org> - 0.5.2-2
- Use buildsystem variables to determine available Emacs version
- BR on gecko-devel >= 1.9, since older version is also in RHEL repo

* Sat Dec 13 2008 Michel Salim <salimma@fedoraproject.org> - 0.5.2-1
- Update to 0.5.2

* Sun Nov 23 2008 Michel Salim <salimma@fedoraproject.org> - 0.5.1-1
- Update to 0.5.1

* Fri Aug 22 2008 Michel Salim <salimma@fedoraproject.org> - 0.3.5-1
- Update to 0.3.5

* Tue Jul 15 2008 Michel Salim <salimma@fedoraproject.org> - 0.3.4-2
- Add vala-mode for editing Vala code in Emacs

* Tue Jul  1 2008 Lennart Poettering <lpoetter@redhat.com> - 0.3.4-1
- Update to 0.3.4

* Wed Jun  4 2008 Michel Salim <salimma@fedoraproject.org> - 0.3.3-1
- Update to 0.3.3

* Fri May 16 2008 Michel Salim <salimma@fedoraproject.org> - 0.3.2-1
- Update to 0.3.2

* Thu Apr 10 2008 Michel Salim <salimma@fedoraproject.org> - 0.2.0-1
- Update to 0.2.0

* Wed Mar  5 2008 Michel Salim <salimma@fedoraproject.org> - 0.1.7-1
- Update to 0.1.7
- -tool subpackage now requires gnome-common, intltool and libtoolize
  for out-of-the-box vala-gen-project support

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.1.6-2
- Autorebuild for GCC 4.3

* Sat Jan 19 2008 Michel Salim <salimma@fedoraproject.org> - 0.1.6-1
- Update to 0.1.6
- Revert vapi addition, needed declarations have been inlined (r846)
- Rename -docs subpackage to -doc, to comply with guidelines

* Tue Jan 15 2008 Michel Salim <salimma@fedoraproject.org> - 0.1.5-5
- Manually add Gee vapi file to package (bz #428692)

* Tue Dec  4 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.5-4
- Backport patch to autodetect location of automake shared files

* Tue Dec  4 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.5-3
- Add build dependency on gtk2-devel

* Tue Dec  4 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.5-2
- Enable project generator tool

* Tue Nov 27 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.5-1
- Update to 0.1.5

* Sun Nov 11 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.4-2
- Add build dependency on devhelp

* Fri Oct 19 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.4-1
- Update to 0.1.4
- Put newly-added documentation in its own subpackage (depends on devhelp)

* Mon Sep 17 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.3-5
- vapigen subpackage: add missing Require: on perl-XML-Twig

* Sat Sep  8 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.3-4
- Split -vapigen subpackage. It is functionally self-contained and the license
  is more restricted
- Updated license declarations

* Wed Sep  5 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.3-3
- Licensing and URL updates

* Tue Sep  4 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.3-2
- Enable binding generation tools

* Sun Sep  2 2007 Michel Salim <salimma@fedoraproject.org> - 0.1.3-1
- Update to 0.1.3

* Sun Mar 25 2007 Michel Salim <salimma@fedoraproject.org> - 0.0.8-1
- Update to 0.0.8

* Wed Mar  7 2007 Michel Salim <salimma@fedoraproject.org> - 0.0.7-1
- Update to 0.0.7

* Wed Feb 28 2007 Michel Salim <salimma@fedoraproject.org> - 0.0.6-1
- Update to 0.0.6

* Mon Nov  6 2006 Michel Salim <salimma@fedoraproject.org> - 0.0.5-1
- Initial package
